﻿using System;
using Kreta.BusinessLogic.HelperClasses.ApaczaiProgramCOs;
using Kreta.Enums.ManualEnums;

namespace Kreta.Web.Areas.Tanulo.Models
{
    public class TanuloApaczaiPalyazatAllapotaModel
    {
        public TanuloApaczaiPalyazatAllapotaModel(PalyazatCo co, DokumentumCo palyazatiDontesDokumentum, DokumentumCo tamogatoiOkiratDokumentum)
        {
            ErkeztetesiSzam = co.ErkeztetesiSzam;
            Iktatoszam = co.Iktatoszam;
            Komment = co.Komment;
            Statusz = co.Statusz;
            FellebbezesHatarido = co.FellebbezesHatarido;
            PalyazatiDontesFajlnev = palyazatiDontesDokumentum?.Nev;
            PalyazatiDontesGuid = palyazatiDontesDokumentum?.Azonosito;
            TamogatoiOkiratFajlnev = tamogatoiOkiratDokumentum?.Nev;
            TamogatoiOkiratGuid = tamogatoiOkiratDokumentum?.Azonosito;
            MegNincsBiralatAlatt = co.StatuszId == (int)KgrPalyazatStatuszEnum.Uj;
        }

        public bool MegNincsBiralatAlatt { get; private set; }

        public string ErkeztetesiSzam { get; set; }

        public string Iktatoszam { get; set; }

        public ApaczaiPalyazatStatuszEnum? Statusz { get; set; }

        public DateTime? FellebbezesHatarido { get; set; }

        public string StatuszColor
        {
            get
            {
                if (Statusz.HasValue)
                {
                    return Helper.ApaczaiPalyazatStatuszExtensions.GetColor(Statusz.Value);
                }

                return string.Empty;
            }
        }

        public string StatuszIcon
        {
            get
            {
                if (Statusz.HasValue)
                {
                    return Helper.ApaczaiPalyazatStatuszExtensions.GetIcon(Statusz.Value);
                }

                return string.Empty;
            }
        }

        public string StatuszText
        {
            get
            {
                if (Statusz.HasValue)
                {
                    return Helper.ApaczaiPalyazatStatuszExtensions.GetText(Statusz.Value);
                }

                return string.Empty;
            }
        }

        public string Komment { get; set; }

        public bool IsKommentVisible => !string.IsNullOrWhiteSpace(Komment);

        public bool IsFellebbezesiIdoszakban => DateTime.Now <= FellebbezesHatarido;

        public string PalyazatiDontesFajlnev { get; set; }

        public Guid? PalyazatiDontesGuid { get; set; }

        public string TamogatoiOkiratFajlnev { get; set; }

        public Guid? TamogatoiOkiratGuid { get; set; }

        public PalyazatCo ConvertToCo()
        {
            return new PalyazatCo
            {
                ErkeztetesiSzam = ErkeztetesiSzam,
                Iktatoszam = Iktatoszam,
                Komment = Komment,
                Statusz = Statusz,
                FellebbezesHatarido = FellebbezesHatarido
            };
        }
    }
}
