﻿using System;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;
using Foolproof;
using Kreta.BusinessLogic.Classes;
using Kreta.BusinessLogic.HelperClasses;
using Kreta.BusinessLogic.Helpers;
using Kreta.BusinessLogic.Helpers.SystemSettings;
using Kreta.BusinessLogic.Interfaces;
using Kreta.BusinessLogic.Security;
using Kreta.Core;
using Kreta.Core.CustomAttributes;
using Kreta.Enums;
using Kreta.Enums.ManualEnums;
using Kreta.Resources;
using Kreta.Web.Helpers;
using Kreta.Web.Models;
using Kreta.Web.Security;
using static Kreta.Core.Constants;

namespace Kreta.Web.Areas.Tanulo.Models
{
    public class TanuloDetailModel
    {
        public int TanuloId { get; set; }

        public int? OsztalycsoportId { get; set; }

        public string OsztalycsoportMev { get; set; }

        public int? TanevId { get; set; }

        public string GridNamePrefix { get; set; }

        public bool GridUseToolBar { get; set; } = true;

        [Display(Name = nameof(FeljegyzesekResource.OsszesOraszam), ResourceType = typeof(FeljegyzesekResource))]
        public double KozossegiSzolgalatOsszesOraszam { get; set; } = 0;

        [Display(Name = nameof(TanuloResource.MegNemAktivOsztalyokMegjelen), ResourceType = typeof(TanuloResource))]
        public bool MegNemAktivOsztalyok { get; set; }

        [Display(Name = nameof(TanuloResource.TanuloUtolsoBelepes), ResourceType = typeof(TanuloResource))]
        public string TanuloUtolsoBelepes { get; set; }

        public SzemelyesAdatokModel SzemelyesAdatokModel { get; set; }

        public TanugyiModel TanugyiModel { get; set; }

        public SzocialisModel SzocialisModel { get; set; }

        public SNIBTNModel SNIBTNModel { get; set; }

        public SportVallasModel SportVallasModel { get; set; }

        public ErtekelesModel ErtekelesModel { get; set; }

        public ElozmenyekModel ElozmenyekModel { get; set; }

        public KozossegiSzolgalatModel KozossegiSzolgalatModel { get; set; }

        public ZaradekModel ZaradekModel { get; set; }

        public TanuloFelmentesGridModel TanuloFelmentesModel { get; set; }

        public TanuloJuttatasModel TanuloJuttatasModel { get; set; }
        public ApaczaiJuttatasModel ApaczaiJuttatasModel { get; set; }

        public TanuloDetailSzirBeallitasokModel TanuloDetailSzirBeallitasokModel { get; set; }

        public EgyszeriPalyakezdesiModel TanuloEgyszeriPalyakezdesiModel { get; set; }

        public bool IsNszfhUjSzkt => ClaimData.IsSelectedTanev20_21OrLater && ClaimData.IsSzakkepzoIntezmeny;
        public string TanuloApiControllerName { get; set; } = Constants.ApiControllers.TanuloApi;
        public bool IsFromSzervezet { get; set; }

        public int? FeladatKategoriaId => OsztalycsoportId.IsEntityId()
                    ? new OsztalyCsoportHelper(ConnectionTypeExtensions.GetSessionConnectionType()).GetOsztalyCsoportFeladatKategoria(OsztalycsoportId.Value)
                    : (int?)null;

        public bool IsApaczaiEnabled { get; set; }

        public bool ManageSportoloiAdatok
        {
            get
            {
                return new SystemSettingsHelper(ConnectionTypeExtensions.GetSessionConnectionType()).GetSystemSettingValue<bool>(RendszerBeallitasTipusEnum.Tanulo_sportoloi_adatainak_kezelese);
            }
        }

        public bool ManageVallasiAdatok
        {
            get
            {
                return new SystemSettingsHelper(ConnectionTypeExtensions.GetSessionConnectionType()).GetSystemSettingValue<bool>(RendszerBeallitasTipusEnum.Tanulo_vallasi_adatainak_kezelese);
            }
        }

        public static TanuloDetailModel ConvertCoToModel(TanuloAdatCO co)
        {
            var szemelyesAdatokModel = new SzemelyesAdatokModel
            {
                AdoazonositoJel = co.AdoazonositoJel,
                Allampolgarsag = co.Allampolgarsag.GetDisplayName<AllampolgarsagEnum>(ClaimData.SelectedTanevID.Value),
                Allampolgarsag2 = co.Allampolgarsag2.GetDisplayName<AllampolgarsagEnum>(ClaimData.SelectedTanevID.Value),
                TartozkodasJogcimTipus = co.TartozkodasJogcimTipusId.GetDisplayName<TartozkodasJogcimTipusEnum>(ClaimData.SelectedTanevID.Value),
                OkiratSzam = co.OkiratSzam,
                Anyanyelv = co.Anyanyelv.GetDisplayName<AnyanyelvEnum>(ClaimData.SelectedTanevID.Value),
                AnyjaCsaladiNeve = co.AnyjaCsaladiNev,
                AnyjaUtonev = co.AnyjaUtoNev,
                AnyjaElotag = co.AnyjaNeveElotag,
                //Bankszamlaszam = co.BankszamlaSzam,
                CsaladiNev = co.CsaladiNev,
                DiakIgazolvany = co.DiakigazolvanySzam,
                DiakIgazolvanyKelete = co.DiakigazolvanyKelte.HasValue ? co.DiakigazolvanyKelte.ToShortDateString() : string.Empty,
                Igazolvanyszam = co.Igazolvanyszam,
                Igazolvanytipus = co.IgazolvanyTipus.GetDisplayName<IgazolvanyTipusEnum>(ClaimData.SelectedTanevID.Value),
                Megjegyzes = co.Megjegyzes,
                SzuletesiCsaladNev = co.SzuletesiCsaladiNev,
                SzuletesiUtonev = co.SzuletesiUtoNev,
                SzuletesiElotag = co.SzuletesiNevElotag,
                SzuletesiHely = co.SzuletesiHely,
                SzuletesiIdo = co.SzuletesiIdo.ToShortDateString(),
                SzuletesiOrszag = co.SzuletesiOrszag.GetDisplayName<OrszagTipusEnum>(ClaimData.SelectedTanevID.Value),
                Tajszam = co.TajSzam,
                Utonev = co.UtoNev,
                BelepesiNev = co.BelepesiNev,
                EloTag = co.Elotag,
                TartozkodasiJogotIgazoloOkmanyTipus = co.TartozkodasiJogotIgazoloOkmanyId.GetDisplayName<TartJogOkmanyTipusEnum>(ClaimData.SelectedTanevID.Value),
                TartozkodasiJogotIgazoloOkmanySzama = co.TartozkodasiJogotIgazoloOkmanySzama,
                NemzetkoziBiztositasiOkmanySzama = co.NemzetkoziBiztositasiOkmanySzama,
                Neme = co.Neme.GetDisplayName<NemEnum>(ClaimData.SelectedTanevID.Value),
                OktatasiAzonosito = co.OktatasiAzonosito,
            };

            var tanugyiModel = new TanugyiModel
            {
                Tanterv = co.Tanterv,
                IsOsszevontOsztaly = co.IsOsszevontOsztaly,
                TanuloEvfolyamTipus = co.TanuloEvfolyamTipus.GetDisplayName<EvfolyamTipusEnum>(ClaimData.SelectedTanevID.Value),
                NaploSorszam = co.NaploSorszam?.ToString(),
                BizonyitvanySorszama = co.BizonyitvanySorszama,
                NyilvantartasiSzam = co.NyilvantartasiSzam,
                BeirasiSorszam = co.BeirasiSorszam,
                FelvetelTaneve = co.FelvetelTaneve,
                KifirAlapjanImportalt = co.KifirAlapjanImportalt.GetDisplayName(),
                NyilvantartastartasKezdete = co.NyilvantartastartasKezdete.ToShortDateString(),
                JogviszonyVarhatoBefejezese = co.JogviszonyBefejezese?.ToShortDateString(),
                JogviszonySzuneteltetese = co.JogviszonySzuneteltetese.GetDisplayName(),
                TankotelezettsegetTeljesito = co.TankotelezettsegetTeljesito.GetDisplayName(),
                TankotelezettsegVege = co.TankotelezettsegVege?.ToShortDateString(),
                Bejaro = co.Bejaro.GetDisplayName(),
                SzakmaiGyakorlaton = co.SzakmaiGyakorlaton.GetDisplayName(),
                Magantanulo = co.Magantanulo.GetDisplayName(),
                MagantanulosagOka = co.MagantanulosagOka?.GetDisplayName<MagantanulosagOkaEnum>(ClaimData.SelectedTanevID.Value),
                MagantanulosagKezdete = co.MagantanulosagKezdete?.ToShortDateString(),
                MagantanulosagVege = co.MagantanulosagVege?.ToShortDateString(),
                Vendegtanulo = co.Vendeg.GetDisplayName(),
                TandijatFizet = co.TandijatFizeto.GetDisplayName(),
                TeritesiDijatFizet = co.TeritestFizeto.GetDisplayName(),
                Tanuloszerzodeses = co.Tanuloszerzodeses.GetDisplayName(),
                PolgariSzerzodeses = co.PolgariSzerzodeses.GetDisplayName(),
                Diaksportkor = co.DiaksportkorTag.GetDisplayName(),
                Evismetlo = co.Evismetlo.GetDisplayName(),
                ElozoIntezmeny = co.ElozoIntezmeny,
                Szakmacsoport = co.SzakmacsoportId.GetDisplayName<SzakmacsoportTipusEnum>(ClaimData.SelectedTanevID.Value),
                Agazat = co.AgazatId.GetDisplayName<AgazatTipusEnum>(ClaimData.SelectedTanevID.Value),
                Szakkepsites = co.SzakkepesitesId.GetDisplayName<SzakkepesitesTipusEnum>(ClaimData.SelectedTanevID.Value),
                ReszSzakkepesites = co.ReszSzakkepesitesId.GetDisplayName<ReszszakkepesitesTipusEnum>(ClaimData.SelectedTanevID.Value),
                AgazatUjSzktTipus = co.AgazatUjSzktTipusId.GetDisplayName<AgazatUjSzktTipusEnum>(ClaimData.SelectedTanevID.Value),
                SzakmaTipus = co.SzakmaTipusId.GetDisplayName<SzakmaTipusEnum>(ClaimData.SelectedTanevID.Value),
                SzakmairanyTipus = co.SzakmairanyTipusId.GetDisplayName<SzakmairanyTipusEnum>(ClaimData.SelectedTanevID.Value),
                EgyuttmukodesiMegallapodasos = co.EgyuttmukodesiMegallapodasos.GetDisplayName(),
                KizarolagIskolaiKeretekKozott = co.KizarolagIskolaiKeretekKozott.GetDisplayName(),
                SZKTV = co.SZKTV.GetDisplayName(),
                SZETV = co.SZETV.GetDisplayName(),
                OSZTV = co.OSZTV.GetDisplayName(),
                EgyebOrszagosDonto = co.EgyebOrszagosDonto.GetDisplayName(),
                OsztalyNev = co.OsztalyNev,
                IsSzakmaiGyakorlatHiany = co.IsSzakmaiGyakorlatHiany.GetDisplayName(),
                IsESL16EvesUtanBelepett = co.IsESL16EvesUtanBelepett.GetDisplayName(),
                TanterviJellemzo = co.TanterviJellemzoId.GetDisplayName<TanterviJellemzoTipusEnum>(ClaimData.SelectedTanevID.Value),
                AgazatAlapOktMegnevezesTipus = co.AgazatAlapOktMegnevTipusId?.GetDisplayName<AgazatAlapOktMegnevTipusEnum>(ClaimData.SelectedTanevID.Value),
                AgazatAlapVizsgaEredmenyTipus = co.AgazatAlapVizsgaEredTipusId?.GetDisplayName<AgazatAlapVizsgaEredTipusEnum>(ClaimData.SelectedTanevID.Value),
                AgazatiAlapvizsgaDatuma = co.AgazatiAlapvizsgaDatuma?.ToShortDateString(),
                AgazatiAlapvizsgaEredmenye = co.AgazatiAlapvizsgaEredmenye?.ToString(),
                AgazatiAlapvizsgaEredmenyeSzazalek = co.AgazatiAlapvizsgaEredmenyeSzazalek?.ToString(),
                IsSzakkepzesiMunkaszerzodessel = co.IsSzakkepzesiMunkaszerzodessel.GetDisplayName(),
                DualisKepzohelyNeveEsAdoszama = co.DualisKepzohelyNeveEsAdoszama,
                SzervezetId = co.SzervezetId,
                DualisKepzohelyNeve = co.DualisKepzohelyNeve,                
                DualisKepzohelyAdoszama = co.DualisKepzohelyAdoszama,
                SzakiranyNktTipus = co.SzakiranyNktTipusId.GetDisplayName<SzakiranyNktTipusEnum>(ClaimData.SelectedTanevID.Value),
                SzakkepesitesNktTipus = co.SzakkepesitesNktTipusId.GetDisplayName<SzakkepesitesNktTipusEnum>(ClaimData.SelectedTanevID.Value),
                TanulmanyiTeruletNktTipus = co.TanulmanyiTeruletNktTipusId.GetDisplayName<TanulmanyiTeruletNktTipusEnum>(ClaimData.SelectedTanevID.Value),
                Is9kozul8ElozotanevbenVegezte = co.Is9kozul8ElozotanevbenVegezte.GetDisplayName(),
                IsKiemeltenTehetseges = co.IsKiemeltenTehetseges.GetDisplayName(),
                IsSzamitogepetOktCelraHasznal = co.IsSzamitogepetOktCelraHasznal.GetDisplayName(),
                IsSzabokyAdolfSzakkepODReszesul = co.IsSzabokyAdolfSzakkepODReszesul.GetDisplayName(),
                IsEgesznaposIskOktReszesul = co.IsEgesznaposIskOktReszesul.GetDisplayName(),
                IsAltalanosIskolaFeladatEllatasiHely = co.IsAltalanosIskolaFeladatEllatasiHely,
                TanterviJellegId = co.TanterviJellegId.GetDisplayName<TanterviJellegEnum>(ClaimData.SelectedTanevID.Value),
                AgazatReszSzakmaTipusId = co.AgazatReszSzakmaTipusId.GetDisplayName<AgazatReszSzakmaTipusEnum>(ClaimData.SelectedTanevID.Value),
                ReszSzakmaTipusId = co.ReszSzakmaTipusId.GetDisplayName<ReszSzakmaTipusEnum>(ClaimData.SelectedTanevID.Value),
                SzakmaReszSzakmaTipusId = co.SzakmaReszSzakmaTipusId.GetDisplayName<SzakmaReszSzakmaTipusEnum>(ClaimData.SelectedTanevID.Value),
                IsSzakkepzesenKivulrolJott = co.IsSzakkepzesenKivulrolJott
            };

            tanugyiModel.AmiKepzesiJellemzokModel = new AmiKepzesiJellemzokModelForTanulo
            {
                MuveszetiAgId = co.MuveszetiAgId,
                MufajTipusId = co.MufajTipusId,
                TanszakTipusId = co.TanszakTipusId
            };

            var helper = new FeladatEllatasiHelyHelper(ConnectionTypeExtensions.GetSessionConnectionType());
            var osztalyJellemzoi = helper.GetOsztalyJellemzoi(tanulocsoportId: co.Zaradek.TanuloCsoportId, osztalyId: co.OsztalyId);
            tanugyiModel.IsSzakkepzeses = osztalyJellemzoi[OsztalyJellemzoEnum.IsSzakkepzeses];
            tanugyiModel.IsNKTSzakkepzeses = osztalyJellemzoi[OsztalyJellemzoEnum.IsNKTSzakkepzeses] && ClaimData.IsSelectedTanev20_21OrLater;

            var szocialisModel = new SzocialisModel()
            {
                IngyenesTankonyv = co.IngyenesTankonyvEllatas.GetDisplayName<IngyenesTankonyvEllatasEnum>(ClaimData.SelectedTanevID.Value),
                SzocialisTamogatas = co.SzocialisTamogatas.GetDisplayName(),
                TestnevelesTipus = co.TestnevelesTipusa.GetDisplayName<TestnevelesTipusEnum>(ClaimData.SelectedTanevID.Value),
                KollegiumiElletas = co.KollegiumiEllatasu.GetDisplayName(),
                EtkezesiKedvezmeny = co.EtkezesiKedvezmeny.GetDisplayName<EtkezesiKedvezmenyTipusEnum>(ClaimData.SelectedTanevID.Value),
                IntezetiAllamiNevelt = co.IntezetiNevelt.GetDisplayName(),
                HatranyosHelyzet = co.HatranyosHelyzet.GetDisplayName<HatranyosHelyzetTipusEnum>(ClaimData.SelectedTanevID.Value),
                Veszelyeztetett = co.Veszelyeztetett.GetDisplayName(),
                TartosGyogykezelesSzama = co.TartosGyogykezelesSzama,
                BeilleszkedisNehezseg = co.BeilleszkedesiNehezseg.GetDisplayName(),
                GyermekvedelmiKedvezmeny = co.RendszeresGyermekvedelmiKedvezmeny,
                JogviszonnyalRendelkezoEltartott = co.TanuloiJogviszonnyalEltartott?.ToString(),
                HaromGyerekOkmanyszam = co.TobbGyermnekIgazolasSzama,
                SzakkepesitesekSzama = co.SzakkepesitesenekSzama?.ToString(),
                MenedekJoggalRendelkezo = co.MenedekJoggalRendelkezo.GetDisplayName(),
                IsExternatusiEllatasban = co.IsExternatusiEllatasban.GetDisplayName(),
                IsNapkoziotthoniEllatasban = co.IsNapkoziotthoniEllatasban.GetDisplayName(),
                IsRendszeresGyermekvedelmi = co.IsRendszeresGyermekvedelmi.GetDisplayName(),
                IsOtthonNyujtottEllatas = co.IsOtthonNyujtottEllatas.GetDisplayName()
            };

            var snibtmmodel = new SNIBTNModel()
            {
                //BeilleszkedesProblema = co.BeilleszkedesiProblema.GetStringResourcesValue(),
                BeilleszkedesTanulasMagatartasiProblema = co.BTMProblema.GetDisplayName(),
                //BeszedfogyatekosOkmanyszam = co.BeszedfogyatekosOkmanyszam,
                //BNO = co.BNOKod,
                //BTMHatarozatOkmanyszama = co.BTMHatarozatOkmanyszama,
                //Diszgrafia = co.DiszgrafiaOkmanyszam,
                //Diszkalkulia = co.DiszkalkuliaOkmanyszam,
                //Diszlexia = co.DiszlexiaOkmanyszam,
                //ErtelmiFogyatekos = co.ErtelmiFogyatekos.GetStringResourcesValue(),
                //ErtelmiFogyatekosOkamnyszam = co.ErtelmiFogyatekosOkamnyszam,
                //FejlesztesreForditandoOraszam = co.FejlesztesreForditandoOraszam,
                //FejlesztesreKijelolt = co.FejlesztesreKijelolt,
                //FejlesztoFoglalkozas = co.FejlesztoFoglalkozas,
                //Hallasserult = co.Hallasserult.GetStringResourcesValue(),
                //HallasserultOkmanyszam = co.HallasserultOkmanyszam,
                //Latasserult = co.Latasserult.GetStringResourcesValue(),
                //LatasserultOkmanyszam = co.LatasserultOkmanyszam,
                //ProblemaKiallitoIntezmenyMegnevezese = co.SNIKiallitoIntezmeny,
                //ProblemaOkmanyErvenyessegenekKezdete = co.BTMOkmanyErvenyessegKezdete.HasValue ? co.BTMOkmanyErvenyessegKezdete.ToShortDateString() : string.Empty,
                //ProblemaOkmanyErvenyessegenekVege = co.BTMOkmanyErvenyessegVege.HasValue ? co.BTMOkmanyErvenyessegVege.ToShortDateString() : string.Empty,
                //HalmozottanFogyatekos = co.HalmozottanFogyatekos.GetStringResourcesValue(),
                //HatarozatTartalma = co.BTMHatarozatTartalma,
                //KiallitoIntezmenyMegnevezese = co.BTMKiallitoIntezmeny,
                //KontrollIdopontja = co.BTMKontrollIdopont.HasValue ? co.BTMKontrollIdopont.ToShortDateString() : string.Empty,
                Letszamsuly = co.SNILetszamsuly,
                //MagatartasiProblema = co.MagatartasiProblema.GetStringResourcesValue(),
                //Meghatarozas = co.SNIMeghatarozas,
                //MegismeroFunkcioNemVisszavezetheto = co.MegismeroFunkcioNemVisszavezetheto,
                //MegismeroFunkcioVisszavezetheto = co.MegismeroFunkcioVisszavezetheto,
                //MozgasserultOkmanyszam = co.MozgasserultOkmanyszam,
                //OkmanyErvenyessegenekKezdete = co.SNIOkmanyErvenyessegKezdete.HasValue ? co.SNIOkmanyErvenyessegKezdete.ToShortDateString() : string.Empty,
                //OkmanyErvenyessegenekVege = co.SNIOkmanyErvenyessegVege.HasValue ? co.SNIOkmanyErvenyessegVege.ToShortDateString() : string.Empty,
                SajatosNevelesiIgenyu = co.SajatosNevelesiIgenyu.GetDisplayName(),
                //SNIKontrollIdopontja = co.SNIKontrollIdopontja.HasValue ? co.SNIKontrollIdopontja.ToShortDateString() : string.Empty,
                //TanulasiProblema = co.TanulasiProblema.GetStringResourcesValue(),
                //ViselekdesNemVisszavezetheto = co.ViselekdesNemVisszavezetheto,
                //ViselekdesVisszavezetheto = co.ViselekdesVisszavezetheto
                KiallitoSzakertoiBizottsagNeve = co.KiallitoSzakertoiBizottsagNeve,
                KiallitoSzakertoiBizottsagCime = co.KiallitoSzakertoiBizottsagCime,
                SzakvelemenySzama = co.SzakvelemenySzama,
                KiallitasDatuma = co.KiallitasDatuma?.ToShortDateString(),
                FelulvizsgalatTaneve = co.FelulvizsgalatTaneve,
                FogyatekossagTipus = co.FogyatekossagTipusId.GetDisplayName<FogyatekossagTipusEnum>(ClaimData.SelectedTanevID.Value)
            };

            var sportVallasModel = new SportVallasModel()
            {
                Egyhazkozossege = co.Egyhazkozossege,
                Sportag = co.Sportag,
                Sportklub = co.Sportklub,
                Vallasa = co.Vallasa.GetDisplayName<VallasEnum>(ClaimData.SelectedTanevID.Value),
                SportedzoElerhetoseg = co.SportedzoElerhetoseg,
            };

            var kozossegiSzolgalatModel = new KozossegiSzolgalatModel()
            {
                OsszKozossegiSzolgalatOraszam = co.OsszKozossegiSzolgalatOraszam
            };

            var model = new TanuloDetailModel
            {
                SzemelyesAdatokModel = szemelyesAdatokModel,
                TanugyiModel = tanugyiModel,
                SzocialisModel = szocialisModel,
                SNIBTNModel = snibtmmodel,
                SportVallasModel = sportVallasModel,
                ZaradekModel = co.Zaradek.TanuloCsoportId.HasValue ? new ZaradekModel(co.Zaradek.TanuloCsoportId.Value, co.ID ?? default) : new ZaradekModel(),
                KozossegiSzolgalatModel = kozossegiSzolgalatModel,
                TanuloId = co.ID ?? default,
                OsztalycsoportId = co.OsztalyId,
                KozossegiSzolgalatOsszesOraszam = co.KozossegiSzolgalatOsszesOraszam
            };

            var tanuloJuttatasokModel = new TanuloJuttatasModel()
            {
                Bankszamlaszam = co.BankszamlaSzam,
                Jogviszony = co.Jogviszony,
                Jogviszony_DNAME = co.Jogviszony.GetDisplayName<JogviszonyTipusEnum>(ClaimData.SelectedTanevID.Value),
                BankszamlaTulajdonos = co.BankszamlaTulajdonos,
                BankszamlaTulajdonos_DNAME = co.BankszamlaTulajdonos.GetDisplayName<BankszamlaTulajdonosTipusEnum>(ClaimData.SelectedTanevID.Value),
                BankszamlaTulajdonosNeve = co.BankszamlaTulajdonosNeve,
                IsMasodikVagyTobbedikSzakmatSzerzo = co.IsMasodikVagyTobbedikSzakmatSzerzo,
                SzamitottAtlag = co.SzamitottAtlag,
                KeziAtlag = co.KeziAtlag,
                Evismetlo = co.Evismetlo,
                TanuloTAJSzama = co.TajSzam,
                IsJogosult = co.IsJogosult,
                //IsEvvegiJegybol = co.IsEvvegiJegybol,
                OsztondijAlapSzazalek = co.OsztondijAlapSzazalek,
                IsAtlagNelkuli = co.IsAtlagNelkuli,
                IsAtlagFuggoSzazalek = co.IsAtlagFuggoSzazalek,
                IsDualisKepzesbenTanuloszerzodeses = co.Tanuloszerzodeses,
                IsDualisKepzesbenSzakkepzesiMunkaszerzodeses = co.IsSzakkepzesiMunkaszerzodessel,
                IsBeszamitasosTanulo = co.IsBeszamitasosTanulo,
                IsSikeresAgazatiVizsga = co.IsSikeresAgazatiVizsga,
                IsFelevnelValtos = co.IsFelevnelValtos,
                IsAtlagSzakkepzesi = co.IsAtlagSzakkepzesi,
                IsBeszamitasosFixSzazalek = co.IsBeszamitasosFixSzazalek,
                IsApaczaiIgenylo = co.IsApaczaiIgenylo,
                IsApaczaiSzerzodeses = co.IsApaczaiSzerzodeses,
                ElutasitasOkok = string.Join("; ", co.OsztondijElutasitasOkaList),
                IsIngyenesKepzes = co.IsIngyenesKepzes,
            };
            model.TanuloJuttatasModel = tanuloJuttatasokModel;

            model.ApaczaiJuttatasModel = new ApaczaiJuttatasModel()
            {
                SzamitottAtlag = co.SzamitottAtlag,
                KeziAtlag = co.KeziAtlag,
                OsztondijAlapSzazalek = co.OsztondijAlapSzazalek,
                BankszamlaTulajdonos = co.BankszamlaTulajdonos,
                Bankszamlaszam = co.BankszamlaSzam,
                BankszamlaTulajdonosNeve = co.BankszamlaTulajdonosNeve,
                Evismetlo = co.Evismetlo,
                IsMasodikVagyTobbedikSzakmatSzerzo = co.IsMasodikVagyTobbedikSzakmatSzerzo,
                Jogviszony = co.Jogviszony,
                Jogviszony_DNAME = co.Jogviszony.GetDisplayName<JogviszonyTipusEnum>(ClaimData.SelectedTanevID.Value),
                TanuloTAJSzama = co.TajSzam,
                IsJogosult = co.IsJogosult,
                //IsEvvegiJegybol = co.IsEvvegiJegybol,
                IsAtlagFuggoSzazalek = co.IsAtlagFuggoSzazalek,
                IsDualisKepzesbenTanuloszerzodeses = co.Tanuloszerzodeses,
                IsDualisKepzesbenSzakkepzesiMunkaszerzodeses = co.IsSzakkepzesiMunkaszerzodessel,
                IsBeszamitasosTanulo = co.IsBeszamitasosTanulo,
                IsSikeresAgazatiVizsga = co.IsSikeresAgazatiVizsga,
                IsFelevnelValtos = co.IsFelevnelValtos,
                IsAtlagSzakkepzesi = co.IsAtlagSzakkepzesi,
                IsBeszamitasosFixSzazalek = co.IsBeszamitasosFixSzazalek,
                IsApaczaiIgenylo = co.IsApaczaiIgenylo,
                IsApaczaiSzerzodeses = co.IsApaczaiSzerzodeses,
                ElutasitasOkok = string.Join("; ", co.OsztondijElutasitasOkaList),
                IsIngyenesKepzes = co.IsIngyenesKepzes,
                IsAtlagNelkuli = co.IsAtlagNelkuli,
                MentorId = co.MentorId
            };

            var tanuloBankszamlaModel = new TanuloBankszamlaModel()
            {
                BankszamlaSzam = co.BankszamlaSzam,
                BankszamlaTulajdonos = co.BankszamlaTulajdonos,
                BankszamlaTulajdonos_DNAME = co.BankszamlaTulajdonos.GetDisplayName<BankszamlaTulajdonosTipusEnum>(ClaimData.SelectedTanevID.Value),
                BankszamlaTulajdonosNeve = co.BankszamlaTulajdonosNeve,
                //Note: mert az üres string-gel nem generálja bele a label-t, de később kap csak értéket
                SzamlavezetoBank = string.IsNullOrWhiteSpace(co.SzamlavezetoBank) ? "-" : co.SzamlavezetoBank,
            };
            model.SzemelyesAdatokModel.BankszamlaModel = tanuloBankszamlaModel;

            if (co.UtolsoBelepes.HasValue)
            {
                model.TanuloUtolsoBelepes = co.UtolsoBelepes.Value.ToShortDateString();
            }

            model.TanuloDetailSzirBeallitasokModel = new TanuloDetailSzirBeallitasokModel
            {
                IsKuldhetoErettsegiSzRnek = co.IsKuldhetoErettsegiSzRnek.GetDisplayName(),
                IsKuldhetoMeresiSzRnek = co.IsKuldhetoMeresiSzRnek.GetDisplayName(),
                IsKuldhetoKozepFelveteliSzRnek = co.IsKuldhetoKozepFelveteliSzRnek.GetDisplayName(),
                IsDiakigazolvanyAtadhatoSzRnek = co.IsDiakigazolvanyAtadhatoSzRnek.GetDisplayName()
            };

            model.TanuloEgyszeriPalyakezdesiModel = new EgyszeriPalyakezdesiModel
            {
                Erdemjegy = co.EPJErdemjegy,
                JavitoVizsga = co.IsEPJJavitoVizsga.GetDisplayName(),
                JuttatasSzazalek = co.EPJJuttatasSzazalek,
                PotloVizsga = co.IsEPJPotloVizsga.GetDisplayName(),
                SzakkepesitesAzonosito = co.EPJSzakkepesitesAzonosito,
                SzakkepesitesMegnevezes = co.EPJSzakkepesitesMegnevezes,
                VizsgaDatum = co.EPJVizsgaDatum?.ToString(ToStringPattern.HungarianDateWithSpaces),
                ElutasitasOka = co.EPJElutasitasOka,
                BizonyitvanySzama = co.EPJBizonyitvanySzama,
                ElutasitasOkok = string.Join("; ", co.EPJElutasitasOkaList),
            };

            return model;
        }
    }

    public class SzemelyesAdatokModel
    {
        [Display(Name = nameof(TanuloResource.Elotag), ResourceType = typeof(TanuloResource))]
        public string EloTag { get; set; }

        [Display(Name = nameof(TanuloResource.CsaladiNev), ResourceType = typeof(TanuloResource))]
        public string CsaladiNev { get; set; }

        [Display(Name = nameof(TanuloResource.UtoNev), ResourceType = typeof(TanuloResource))]
        public string Utonev { get; set; }

        [Display(Name = nameof(TanuloResource.AnyjaCsaladiNev), ResourceType = typeof(TanuloResource))]
        public string AnyjaCsaladiNeve { get; set; }

        [Display(Name = nameof(TanuloResource.AnyjaUtonev), ResourceType = typeof(TanuloResource))]
        public string AnyjaUtonev { get; set; }

        [Display(Name = nameof(TanuloResource.AnyjaElotag), ResourceType = typeof(TanuloResource))]
        public string AnyjaElotag { get; set; }

        [Display(Name = nameof(TanuloResource.SzuletesiCsaladNev), ResourceType = typeof(TanuloResource))]
        public string SzuletesiCsaladNev { get; set; }

        [Display(Name = nameof(TanuloResource.SzuletesiUtonev), ResourceType = typeof(TanuloResource))]
        public string SzuletesiUtonev { get; set; }

        [Display(Name = nameof(TanuloResource.SzuletesiElotag), ResourceType = typeof(TanuloResource))]
        public string SzuletesiElotag { get; set; }

        [Display(Name = nameof(TanuloResource.SzuletesiOrszag), ResourceType = typeof(TanuloResource))]
        public string SzuletesiOrszag { get; set; }

        [Display(Name = nameof(TanuloResource.SzuletesiHely), ResourceType = typeof(TanuloResource))]
        public string SzuletesiHely { get; set; }

        [Display(Name = nameof(TanuloResource.SzuletesiIdo), ResourceType = typeof(TanuloResource))]
        public string SzuletesiIdo { get; set; }

        [Display(Name = nameof(TanuloResource.Allampolgarsag), ResourceType = typeof(TanuloResource))]
        public string Allampolgarsag { get; set; }

        [Display(Name = nameof(TanuloResource.Allampolgarsag2), ResourceType = typeof(TanuloResource))]
        public string Allampolgarsag2 { get; set; }

        [Display(Name = nameof(TanuloResource.Anyanyelv), ResourceType = typeof(TanuloResource))]
        public string Anyanyelv { get; set; }

        [Display(Name = nameof(TanuloResource.TartozkodasJogcime), ResourceType = typeof(TanuloResource))]
        public string TartozkodasJogcimTipus { get; set; }

        [Display(Name = nameof(TanuloResource.OkiratSzama), ResourceType = typeof(TanuloResource))]
        public string OkiratSzam { get; set; }

        [Display(Name = nameof(TanuloResource.IgazolvanyTipus), ResourceType = typeof(TanuloResource))]
        public string Igazolvanytipus { get; set; }

        [Display(Name = nameof(TanuloResource.IgazolvanySzam), ResourceType = typeof(TanuloResource))]
        public string Igazolvanyszam { get; set; }

        [Display(Name = nameof(TanuloResource.DiakigazolvanySzam), ResourceType = typeof(TanuloResource))]
        public string DiakIgazolvany { get; set; }

        [Display(Name = nameof(TanuloResource.DiakigazolvanyKelte), ResourceType = typeof(TanuloResource))]
        public string DiakIgazolvanyKelete { get; set; }

        [Display(Name = nameof(TanuloResource.TajSzam), ResourceType = typeof(TanuloResource))]
        public string Tajszam { get; set; }

        [Display(Name = nameof(TanuloResource.AdoazonositoJel), ResourceType = typeof(TanuloResource))]
        public string AdoazonositoJel { get; set; }

        [Display(Name = nameof(TanuloResource.NemzetkoziBiztositasiOkmanySzama), ResourceType = typeof(TanuloResource))]
        public string NemzetkoziBiztositasiOkmanySzama { get; set; }

        //[Display(Name = nameof(TanuloResource.BankszamlaSzam), ResourceType = typeof(TanuloResource))]
        //public string Bankszamlaszam { get; set; }

        [Display(Name = nameof(TanuloResource.Megjegyzes), ResourceType = typeof(TanuloResource))]
        public string Megjegyzes { get; set; }

        [Display(Name = nameof(TanuloResource.BelepesiNev), ResourceType = typeof(TanuloResource))]
        public string BelepesiNev { get; set; }

        [Display(Name = nameof(TanuloResource.TartozkodasiJogotIgazoloOkmany), ResourceType = typeof(TanuloResource))]
        public string TartozkodasiJogotIgazoloOkmanyTipus { get; set; }

        [Display(Name = nameof(TanuloResource.TartozkodasiJogotIgazoloOkmanySzama), ResourceType = typeof(TanuloResource))]
        public string TartozkodasiJogotIgazoloOkmanySzama { get; set; }

        [Display(Name = nameof(TanuloResource.OktatasiAzonosito), ResourceType = typeof(TanuloResource))]
        public string OktatasiAzonosito { get; set; }

        [Display(Name = nameof(TanuloResource.Neme), ResourceType = typeof(TanuloResource))]
        public string Neme { get; set; }

        public TanuloBankszamlaModel BankszamlaModel { get; set; }

        public string TeljesExportNev
        {
            get
            {
                return $"{EloTag + (!string.IsNullOrWhiteSpace(EloTag) ? "_" : "")}{CsaladiNev.Replace(" ", "_")}_{Utonev.Replace(" ", "_")}";
            }
        }
    }

    public class TanugyiModel
    {
        public TanugyiModel()
        {
            AmiKepzesiJellemzokModel = new AmiKepzesiJellemzokModelForTanulo();
        }
        string osztalyNev;
        public string OsztalyNev { get { return !string.IsNullOrWhiteSpace(osztalyNev) ? osztalyNev : TanuloResource.Alap; } set { osztalyNev = value; } }

        [Display(Name = nameof(TanuloResource.Tanterv), ResourceType = typeof(TanuloResource))]
        public string Tanterv { get; set; }

        [Display(Name = nameof(OsztalyCsoportResource.NevelesiTerv), ResourceType = typeof(OsztalyCsoportResource))]
        public string NevelesiTerv
        {
            get { return Tanterv; }
            set { Tanterv = value; }
        }

        [Display(Name = nameof(TanuloResource.NaploSorszam), ResourceType = typeof(TanuloResource))]
        public string NaploSorszam { get; set; }

        [Display(Name = nameof(TanuloResource.BizonyitvanySorszama), ResourceType = typeof(TanuloResource))]
        public string BizonyitvanySorszama { get; set; }

        [Display(Name = nameof(TanuloResource.Torzslapszam), ResourceType = typeof(TanuloResource))]
        public string NyilvantartasiSzam { get; set; }

        [Display(Name = nameof(TanuloResource.BeirasiNaploSorszam), ResourceType = typeof(TanuloResource))]
        public string BeirasiSorszam { get; set; }

        [Display(Name = nameof(TanuloResource.FelvetelTaneve), ResourceType = typeof(TanuloResource))]
        public string FelvetelTaneve { get; set; }

        [Display(Name = nameof(TanuloResource.KifirAlapjanImportalt), ResourceType = typeof(TanuloResource))]
        public string KifirAlapjanImportalt { get; set; }

        [Display(Name = nameof(TanuloResource.JogviszonyKezdete), ResourceType = typeof(TanuloResource))]
        public string NyilvantartastartasKezdete { get; set; }

        [Display(Name = nameof(TanuloResource.JogviszonyVarhatoBefejezese), ResourceType = typeof(TanuloResource))]
        public string JogviszonyVarhatoBefejezese { get; set; }

        [Display(Name = nameof(TanuloResource.JogviszonySzunteteltetese), ResourceType = typeof(TanuloResource))]
        public string JogviszonySzuneteltetese { get; set; }

        [Display(Name = nameof(TanuloResource.TankotelezettsegetTeljesito), ResourceType = typeof(TanuloResource))]
        public string TankotelezettsegetTeljesito { get; set; }

        [Display(Name = nameof(TanuloResource.TankotelezettsegVege), ResourceType = typeof(TanuloResource))]
        public string TankotelezettsegVege { get; set; }

        [Display(Name = nameof(TanuloResource.Bejaro), ResourceType = typeof(TanuloResource))]
        public string Bejaro { get; set; }

        [Display(Name = nameof(OsztalyCsoportResource.IsESL16EvesUtanBelepett), ResourceType = typeof(OsztalyCsoportResource))]
        public string IsESL16EvesUtanBelepett { get; set; }

        [Display(Name = nameof(TanuloResource.SzakmaiGyakorlatonTartozkodik), ResourceType = typeof(TanuloResource))]
        public string SzakmaiGyakorlaton { get; set; }

        [Display(Name = nameof(TanuloResource.Magantanulo), ResourceType = typeof(TanuloResource))]
        public string Magantanulo { get; set; }

        [Display(Name = nameof(TanuloResource.MagantanulosagOka), ResourceType = typeof(TanuloResource))]
        public string MagantanulosagOka { get; set; }

        [Display(Name = nameof(TanuloResource.MagantanulosagKezdete), ResourceType = typeof(TanuloResource))]
        public string MagantanulosagKezdete { get; set; }

        [Display(Name = nameof(TanuloResource.EgyeniMunkarendVege), ResourceType = typeof(TanuloResource))]
        public string MagantanulosagVege { get; set; }

        [Display(Name = nameof(TanuloResource.Vendegtanulo), ResourceType = typeof(TanuloResource))]
        public string Vendegtanulo { get; set; }

        [Display(Name = nameof(TanuloResource.TandijatFizeto), ResourceType = typeof(TanuloResource))]
        public string TandijatFizet { get; set; }

        [Display(Name = nameof(TanuloResource.TeritesiDijatFizeto), ResourceType = typeof(TanuloResource))]
        public string TeritesiDijatFizet { get; set; }

        [Display(Name = nameof(TanuloResource.Tanuloszerzodeses), ResourceType = typeof(TanuloResource))]
        public string Tanuloszerzodeses { get; set; }

        [Display(Name = nameof(TanuloResource.PolgariSzerzodeses), ResourceType = typeof(TanuloResource))]
        public string PolgariSzerzodeses { get; set; }

        [Display(Name = nameof(TanuloResource.DiaksportkorTagja), ResourceType = typeof(TanuloResource))]
        public string Diaksportkor { get; set; }

        [Display(Name = nameof(TanuloResource.Evismetlo), ResourceType = typeof(TanuloResource))]
        public string Evismetlo { get; set; }

        [Display(Name = nameof(TanuloResource.ElozoIntezmeny), ResourceType = typeof(TanuloResource))]
        public string ElozoIntezmeny { get; set; }

        public bool IsSzakkepzeses { get; set; }

        public bool IsNKTSzakkepzeses { get; set; }

        [Display(Name = nameof(TanuloResource.Szakmacsoport), ResourceType = typeof(TanuloResource))]
        public string Szakmacsoport { get; set; }

        [Display(Name = nameof(TanuloResource.Agazat), ResourceType = typeof(TanuloResource))]
        public string Agazat { get; set; }

        [Display(Name = nameof(TanuloResource.Szakkepesites), ResourceType = typeof(TanuloResource))]
        public string Szakkepsites { get; set; }

        [Display(Name = nameof(TanuloResource.ReszSzakkepesites), ResourceType = typeof(TanuloResource))]
        public string ReszSzakkepesites { get; set; }

        [Display(Name = nameof(OsztalyCsoportResource.Agazat), ResourceType = typeof(OsztalyCsoportResource))]
        public string AgazatUjSzktTipus { get; set; }

        [Display(Name = nameof(OsztalyCsoportResource.Szakma), ResourceType = typeof(OsztalyCsoportResource))]
        public string SzakmaTipus { get; set; }

        [Display(Name = nameof(OsztalyCsoportResource.Szakmairany), ResourceType = typeof(OsztalyCsoportResource))]
        public string SzakmairanyTipus { get; set; }

        [Display(Name = nameof(TanuloResource.EgyuttmukodesiMegallapodasos), ResourceType = typeof(TanuloResource))]
        public string EgyuttmukodesiMegallapodasos { get; set; }

        [Display(Name = nameof(TanuloResource.KizarolagIskolaiKeretekKozott), ResourceType = typeof(TanuloResource))]
        public string KizarolagIskolaiKeretekKozott { get; set; }

        [Display(Name = nameof(TanuloResource.Szktv), ResourceType = typeof(TanuloResource))]
        public string SZKTV { get; set; }

        [Display(Name = nameof(TanuloResource.Szetv), ResourceType = typeof(TanuloResource))]
        public string SZETV { get; set; }

        [Display(Name = nameof(TanuloResource.Osztv), ResourceType = typeof(TanuloResource))]
        public string OSZTV { get; set; }

        [Display(Name = nameof(TanuloResource.EgyebOrszagosDonto), ResourceType = typeof(TanuloResource))]
        public string EgyebOrszagosDonto { get; set; }

        [Display(Name = nameof(TanuloResource.IsSzakmaiGyakorlatHiany), ResourceType = typeof(TanuloResource))]
        public string IsSzakmaiGyakorlatHiany { get; set; }

        public bool IsOsszevontOsztaly { get; set; }

        [Display(Name = nameof(TanuloResource.OsszevontOsztalyEvfolyamTipus), ResourceType = typeof(TanuloResource))]
        public string TanuloEvfolyamTipus { get; set; }

        [Display(Name = nameof(TanuloResource.TanterviJellemzo), ResourceType = typeof(TanuloResource))]
        public string TanterviJellemzo { get; set; }

        [Display(Name = nameof(TanuloResource.AgazatiAlapoktatasMegnevezese), ResourceType = typeof(TanuloResource))]
        public string AgazatAlapOktMegnevezesTipus { get; set; }

        [Display(Name = nameof(TanuloResource.AgazatiAlapvizsgaTeljesitese), ResourceType = typeof(TanuloResource))]
        public string AgazatAlapVizsgaEredmenyTipus { get; set; }

        [Display(Name = nameof(TanuloResource.AgazatiAlapvizsgaDatuma), ResourceType = typeof(TanuloResource))]
        public string AgazatiAlapvizsgaDatuma { get; set; }

        [Display(Name = nameof(TanuloResource.AgazatiAlapvizsgaEredmenye), ResourceType = typeof(TanuloResource))]
        public string AgazatiAlapvizsgaEredmenye { get; set; }

        [Display(Name = nameof(TanuloResource.AgazatiAlapvizsgaEredmenyeSzazalek), ResourceType = typeof(TanuloResource))]
        public string AgazatiAlapvizsgaEredmenyeSzazalek { get; set; }

        [Display(Name = nameof(TanuloResource.SzakkepzesiMunkaszerzodessel), ResourceType = typeof(TanuloResource))]
        public string IsSzakkepzesiMunkaszerzodessel { get; set; }

        [Display(Name = nameof(DualisResource.DualisKepzohelyNeveEsAdoszama), ResourceType = typeof(DualisResource))]
        public string DualisKepzohelyNeveEsAdoszama { get; set; }

        [Display(Name = nameof(TanuloResource.DualisKepzohelyNeve), ResourceType = typeof(TanuloResource))]
        public string DualisKepzohelyNeve { get; set; }

        [Display(Name = nameof(TanuloResource.DualisKepzohelyAdoszama), ResourceType = typeof(TanuloResource))]
        public string DualisKepzohelyAdoszama { get; set; }

        [Display(Name = nameof(TanuloResource.SzakiranyNktTipus), ResourceType = typeof(TanuloResource))]
        public string SzakiranyNktTipus { get; set; }

        [Display(Name = nameof(TanuloResource.SzakkepesitesNktTipus), ResourceType = typeof(TanuloResource))]
        public string SzakkepesitesNktTipus { get; set; }

        [Display(Name = nameof(TanuloResource.TanulmanyiTeruletNktTipus), ResourceType = typeof(TanuloResource))]
        public string TanulmanyiTeruletNktTipus { get; set; }
        public AmiKepzesiJellemzokModelForTanulo AmiKepzesiJellemzokModel { get; set; }

        [Display(Name = nameof(OsztalyCsoportResource.Is9kozul8ElozotanevbenVegezte), ResourceType = typeof(OsztalyCsoportResource))]
        public string Is9kozul8ElozotanevbenVegezte { get; set; }

        [Display(Name = nameof(TanuloResource.KiemeltenTehetseges), ResourceType = typeof(TanuloResource))]
        public string IsKiemeltenTehetseges { get; set; }

        [Display(Name = nameof(TanuloResource.SzamitogepetOktatasiCellalHasznal), ResourceType = typeof(TanuloResource))]
        public string IsSzamitogepetOktCelraHasznal { get; set; }

        [Display(Name = nameof(TanuloResource.SzabokyAdolfSzakkepzesiOsztondijbanReszesul), ResourceType = typeof(TanuloResource))]
        public string IsSzabokyAdolfSzakkepODReszesul { get; set; }

        [Display(Name = nameof(TanuloResource.EgeszNaposIskolaiOktatasbanReszesul), ResourceType = typeof(TanuloResource))]
        public string IsEgesznaposIskOktReszesul { get; set; }

        public bool IsAltalanosIskolaFeladatEllatasiHely { get; set; }

        [Display(Name = nameof(TanuloResource.TanterviJelleg), ResourceType = typeof(TanuloResource))]
        public string TanterviJellegId { get; set; }

        [Display(Name = nameof(TanuloResource.UjSzktReszszakmakAgazat), ResourceType = typeof(TanuloResource))]
        public string AgazatReszSzakmaTipusId { get; set; }

        [Display(Name = nameof(TanuloResource.UjSzktReszszakmakSzakma), ResourceType = typeof(TanuloResource))]
        public string SzakmaReszSzakmaTipusId { get; set; }

        [Display(Name = nameof(TanuloResource.UjSzktReszszakmakReszszakma), ResourceType = typeof(TanuloResource))]
        public string ReszSzakmaTipusId { get; set; }

        [Display(Name = nameof(TanuloResource.SzakkepzesenKivulrolJott), ResourceType = typeof(TanuloResource))]
        public bool IsSzakkepzesenKivulrolJott { get; set; }

        public int? SzervezetId { get; set; }
    }

    public class SzocialisModel
    {
        [Display(Name = nameof(TanuloResource.IngyenesTankonyvEllatas), ResourceType = typeof(TanuloResource))]
        public string IngyenesTankonyv { get; set; }

        [Display(Name = nameof(TanuloResource.SzocialisOsztondij), ResourceType = typeof(TanuloResource))]
        public string SzocialisTamogatas { get; set; }

        [Display(Name = nameof(TanuloResource.TestnevelesTipusa), ResourceType = typeof(TanuloResource))]
        public string TestnevelesTipus { get; set; }

        [Display(Name = nameof(TanuloResource.KollegiumiEllatasbanReszesulo), ResourceType = typeof(TanuloResource))]
        public string KollegiumiElletas { get; set; }

        [Display(Name = nameof(TanuloResource.EtkezesiKedvezmeny), ResourceType = typeof(TanuloResource))]
        public string EtkezesiKedvezmeny { get; set; }

        [Display(Name = nameof(TanuloResource.IntezetiNevelt), ResourceType = typeof(TanuloResource))]
        public string IntezetiAllamiNevelt { get; set; }

        [Display(Name = nameof(TanuloResource.HatranyosHelyzet), ResourceType = typeof(TanuloResource))]
        public string HatranyosHelyzet { get; set; }

        [Display(Name = nameof(TanuloResource.Veszelyeztetett), ResourceType = typeof(TanuloResource))]
        public string Veszelyeztetett { get; set; }

        [Display(Name = nameof(TanuloResource.TartosGyogykezelesOkmanyszama), ResourceType = typeof(TanuloResource))]
        public string TartosGyogykezelesSzama { get; set; }

        [Display(Name = nameof(TanuloResource.BeilleszkedesiNehezseg), ResourceType = typeof(TanuloResource))]
        public string BeilleszkedisNehezseg { get; set; }

        [Display(Name = nameof(TanuloResource.RendszeresGyermekvedelmiKedvezmeny), ResourceType = typeof(TanuloResource))]
        public string GyermekvedelmiKedvezmeny { get; set; }

        [Display(Name = nameof(TanuloResource.TanuloiHallgatoiJogviszonnyalRendelkezoEltartott), ResourceType = typeof(TanuloResource))]
        public string JogviszonnyalRendelkezoEltartott { get; set; }

        [Display(Name = nameof(TanuloResource.HaromVagyTobbGyermekIgazolasOkmanyszama), ResourceType = typeof(TanuloResource))]
        public string HaromGyerekOkmanyszam { get; set; }

        [Display(Name = nameof(TanuloResource.SzakkepesitesenekSzama), ResourceType = typeof(TanuloResource))]
        public string SzakkepesitesekSzama { get; set; }

        [Display(Name = nameof(TanuloResource.MenekultOltalmazottMenedekes), ResourceType = typeof(TanuloResource))]
        public string MenedekJoggalRendelkezo { get; set; }

        [Display(Name = nameof(TanuloResource.IsExternatusiEllatasban), ResourceType = typeof(TanuloResource))]
        public string IsExternatusiEllatasban { get; set; }

        [Display(Name = nameof(TanuloResource.IsNapkoziotthoniEllatasban), ResourceType = typeof(TanuloResource))]
        public string IsNapkoziotthoniEllatasban { get; set; }

        [Display(Name = nameof(TanuloResource.RendszeresGyermekvedelmiKedvezmenybenReszesul), ResourceType = typeof(TanuloResource))]
        public string IsRendszeresGyermekvedelmi { get; set; }

        [Display(Name = nameof(TanuloResource.OtthonNyujtottEllatasiFormabanReszesul), ResourceType = typeof(TanuloResource))]
        public string IsOtthonNyujtottEllatas { get; set; }
    }

    public class SNIBTNModel
    {
        [Display(Name = nameof(TanuloResource.SajatosNevelesiIgenyu), ResourceType = typeof(TanuloResource))]
        public string SajatosNevelesiIgenyu { get; set; }

        //[Display(Name = nameof(TanuloResource.HalmozottanFogyatekos), ResourceType = typeof(TanuloResource))]
        //public string HalmozottanFogyatekos { get; set; }

        [Display(Name = nameof(TanuloResource.Letszamsuly), ResourceType = typeof(TanuloResource))]
        public double? Letszamsuly { get; set; }

        //[Display(Name = nameof(TanuloResource.Hallasserult), ResourceType = typeof(TanuloResource))]
        //public string Hallasserult { get; set; }

        //[Display(Name = nameof(TanuloResource.HallasserultOkmanyszam), ResourceType = typeof(TanuloResource))]
        //public string HallasserultOkmanyszam { get; set; }

        //[Display(Name = nameof(TanuloResource.Latasserult), ResourceType = typeof(TanuloResource))]
        //public string Latasserult { get; set; }

        //[Display(Name = nameof(TanuloResource.LatasserultOkmanyszam), ResourceType = typeof(TanuloResource))]
        //public string LatasserultOkmanyszam { get; set; }

        //[Display(Name = nameof(TanuloResource.ErtelmiFogyatekos), ResourceType = typeof(TanuloResource))]
        //public string ErtelmiFogyatekos { get; set; }

        //[Display(Name = nameof(TanuloResource.ErtelmiFogyatekosOkmanyszam), ResourceType = typeof(TanuloResource))]
        //public string ErtelmiFogyatekosOkamnyszam { get; set; }

        //[Display(Name = nameof(TanuloResource.MozgaskorlatozottOkmanyszam), ResourceType = typeof(TanuloResource))]
        //public string MozgasserultOkmanyszam { get; set; }

        //[Display(Name = nameof(TanuloResource.BeszedfogyatekosOkmanyszam), ResourceType = typeof(TanuloResource))]
        //public string BeszedfogyatekosOkmanyszam { get; set; }

        //[Display(Name = nameof(TanuloResource.ViselkedesFejlodesenekOrganikusOkraVisszavezethetoTartosEsSulyosRendellenessegevelKuzdOkmanyszam), ResourceType = typeof(TanuloResource))]
        //public string ViselekdesVisszavezetheto { get; set; }

        //[Display(Name = nameof(TanuloResource.ViselkedesFejlodesenekOrganikusOkraVisszaNemVezethetoTartosEsSulyosRendellenessegevelKuzdOkmanyszam), ResourceType = typeof(TanuloResource))]
        //public string ViselekdesNemVisszavezetheto { get; set; }

        //[Display(Name = nameof(TanuloResource.MegismeroFunkciokOrganikusOkraVisszavezethetoTartosEsSulyosRendellenessegevelKuzdOkmanyszam), ResourceType = typeof(TanuloResource))]
        //public string MegismeroFunkcioVisszavezetheto { get; set; }

        //[Display(Name = nameof(TanuloResource.MegismeroFunkciokOrganikusOkraVisszaNemVezethetoTartosEsSulyosRendellenessegevelKuzdOkmanyszam), ResourceType = typeof(TanuloResource))]
        //public string MegismeroFunkcioNemVisszavezetheto { get; set; }

        //[Display(Name = nameof(TanuloResource.KiallitoIntezmenyMegnevezese), ResourceType = typeof(TanuloResource))]
        //public string KiallitoIntezmenyMegnevezese { get; set; }

        //[Display(Name = nameof(TanuloResource.OkmanyErvenyessegenekKezdete), ResourceType = typeof(TanuloResource))]
        //public string OkmanyErvenyessegenekKezdete { get; set; }

        //[Display(Name = nameof(TanuloResource.OkmanyErvenyessegenekVege), ResourceType = typeof(TanuloResource))]
        //public string OkmanyErvenyessegenekVege { get; set; }

        //[Display(Name = nameof(TanuloResource.BnoKod), ResourceType = typeof(TanuloResource))]
        //public string BNO { get; set; }

        //[Display(Name = nameof(TanuloResource.Meghatarozas), ResourceType = typeof(TanuloResource))]
        //public string Meghatarozas { get; set; }

        //[Display(Name = nameof(TanuloResource.SniKontrollIdopontja), ResourceType = typeof(TanuloResource))]
        //public string SNIKontrollIdopontja { get; set; }

        //[Display(Name = nameof(TanuloResource.FejlesztesreForditandoOraszam), ResourceType = typeof(TanuloResource))]
        //public double? FejlesztesreForditandoOraszam { get; set; }

        //[Display(Name = nameof(TanuloResource.FejlesztesreKijelolt), ResourceType = typeof(TanuloResource))]
        //public string FejlesztesreKijelolt { get; set; }

        //[Display(Name = nameof(TanuloResource.FejlesztoFoglalkozas), ResourceType = typeof(TanuloResource))]
        //public string FejlesztoFoglalkozas { get; set; }

        [Display(Name = nameof(TanuloResource.BeilleszkedesiTanulasiEsMagatartasiNehezseggelKuzdo), ResourceType = typeof(TanuloResource))]
        public string BeilleszkedesTanulasMagatartasiProblema { get; set; }

        //[Display(Name = nameof(TanuloResource.BeilleszkedesiProblemavalKuzd), ResourceType = typeof(TanuloResource))]
        //public string BeilleszkedesProblema { get; set; }

        //[Display(Name = nameof(TanuloResource.TanulasiProblemavalKuzd), ResourceType = typeof(TanuloResource))]
        //public string TanulasiProblema { get; set; }

        //[Display(Name = nameof(TanuloResource.Diszgrafia), ResourceType = typeof(TanuloResource))]
        //public string Diszgrafia { get; set; }

        //[Display(Name = nameof(TanuloResource.Diszlexia), ResourceType = typeof(TanuloResource))]
        //public string Diszlexia { get; set; }

        //[Display(Name = nameof(TanuloResource.Diszkalkulia), ResourceType = typeof(TanuloResource))]
        //public string Diszkalkulia { get; set; }

        //[Display(Name = nameof(TanuloResource.MagatartasiProblemavalKuzd), ResourceType = typeof(TanuloResource))]
        //public string MagatartasiProblema { get; set; }

        //[Display(Name = nameof(TanuloResource.BtmHatarozatOkmanyszama), ResourceType = typeof(TanuloResource))]
        //public string BTMHatarozatOkmanyszama { get; set; }

        //[Display(Name = nameof(TanuloResource.KiallitoIntezmenyMegnevezese), ResourceType = typeof(TanuloResource))]
        //public string ProblemaKiallitoIntezmenyMegnevezese { get; set; }

        //[Display(Name = nameof(TanuloResource.OkmanyErvenyessegenekKezdete), ResourceType = typeof(TanuloResource))]
        //public string ProblemaOkmanyErvenyessegenekKezdete { get; set; }

        //[Display(Name = nameof(TanuloResource.OkmanyErvenyessegenekVege), ResourceType = typeof(TanuloResource))]
        //public string ProblemaOkmanyErvenyessegenekVege { get; set; }

        //[Display(Name = nameof(TanuloResource.KontrollIdopontja), ResourceType = typeof(TanuloResource))]
        //public string KontrollIdopontja { get; set; }

        //[Display(Name = nameof(TanuloResource.HatarozatTartalma), ResourceType = typeof(TanuloResource))]
        //public string HatarozatTartalma { get; set; }

        [Display(Name = nameof(TanuloResource.KiallitoSzakertoiBizottsagNeve), ResourceType = typeof(TanuloResource))]
        public string KiallitoSzakertoiBizottsagNeve { get; set; }

        [Display(Name = nameof(TanuloResource.KiallitoSzakertoiBizottsagCime), ResourceType = typeof(TanuloResource))]
        public string KiallitoSzakertoiBizottsagCime { get; set; }

        [Display(Name = nameof(TanuloResource.SzakvelemenySzama), ResourceType = typeof(TanuloResource))]
        public string SzakvelemenySzama { get; set; }

        [Display(Name = nameof(TanuloResource.KiallitasanakKelte), ResourceType = typeof(TanuloResource))]
        public string KiallitasDatuma { get; set; }

        [Display(Name = nameof(TanuloResource.FelulvizsgalatIdopontjaTanev), ResourceType = typeof(TanuloResource))]
        public string FelulvizsgalatTaneve { get; set; }

        [Display(Name = nameof(TanuloResource.FogyatekossagTipusId), ResourceType = typeof(TanuloResource))]
        public string FogyatekossagTipus { get; set; }

        public bool IsFogyatekossagHide => !ClaimData.IsSelectedTanev21_22OrLater || (!ClaimData.IsAdministrator && !ClaimData.IsOsztalyfonok && ClaimData.FelhasznaloSzerepCsomagok.Contains(KretaClaimPackages.CsoportVezeto.ClaimValue));
    }

    public class SportVallasModel
    {
        [Display(Name = nameof(TanuloResource.Sportag), ResourceType = typeof(TanuloResource))]
        public string Sportag { get; set; }

        [Display(Name = nameof(TanuloResource.Sportklub), ResourceType = typeof(TanuloResource))]
        public string Sportklub { get; set; }

        [Display(Name = nameof(TanuloResource.SportedzoElerhetosege), ResourceType = typeof(TanuloResource))]
        public string SportedzoElerhetoseg { get; set; }

        [Display(Name = nameof(TanuloResource.Vallasa), ResourceType = typeof(TanuloResource))]
        public string Vallasa { get; set; }

        [Display(Name = nameof(TanuloResource.Egyhazkozossege), ResourceType = typeof(TanuloResource))]
        public string Egyhazkozossege { get; set; }
    }

    public class ErtekelesModel : IKretaIdentity
    {
        public string ID { get; set; }

        [Display(Name = nameof(TantargyResource.Tantargy), ResourceType = typeof(TantargyResource))]
        public string Tantargy { get; set; }

        [Display(Name = nameof(TanuloErtekelesResource.BejegyzesDatuma), ResourceType = typeof(TanuloErtekelesResource))]
        public DateTime? ErtekelesDatuma { get; set; }

        [Display(Name = nameof(TanuloErtekelesResource.Tema), ResourceType = typeof(TanuloErtekelesResource))]
        public string Tema { get; set; }

        [Display(Name = nameof(TantargyResource.Osztalyzat), ResourceType = typeof(TantargyResource))]
        public string Erdemjegy_DNAME { get; set; }

        [Display(Name = nameof(TantargyResource.SzovegesErtekeles), ResourceType = typeof(TantargyResource))]
        public string ErtekelesSzoveg { get; set; }

        [Display(Name = nameof(TanuloErtekelesResource.Tipus), ResourceType = typeof(TanuloErtekelesResource))]
        public string ErtekelesModja_DNAME { get; set; }

        [Display(Name = nameof(OsztalyCsoportResource.OsztalyCsoport), ResourceType = typeof(OsztalyCsoportResource))]
        public string OsztalyCsoport { get; set; }

        [Display(Name = nameof(TantargyResource.Tanar), ResourceType = typeof(TantargyResource))]
        public string Pedagogus { get; set; }
    }

    public class TanuloTantargyaiModel : IKretaIdentity
    {
        public string ID { get; set; }

        [Display(Name = nameof(TantargyResource.OsztalyCsoport), ResourceType = typeof(TantargyResource))]
        public int? OsztalyId { get; set; }

        [Display(Name = nameof(TantargyResource.Tantargy), ResourceType = typeof(TantargyResource))]
        public int? TantargyID { get; set; }

        [Display(Name = nameof(TantargyResource.Tanar), ResourceType = typeof(TantargyResource))]
        public int? TanarID { get; set; }

        [KretaRequired(typeof(TantargyResource), nameof(TantargyResource.OraszamMegadasaKotelezo))]
        [Range(0, General.TantargyfelosztasImportMaxOraszam, ErrorMessageResourceType = typeof(TantargyResource), ErrorMessageResourceName = nameof(TantargyResource.OraszamMegadasaKotelezo))]
        [Display(Name = nameof(TantargyResource.HetiOraszam), ResourceType = typeof(TantargyResource))]
        public double Oraszam { get; set; }

        [Display(Name = nameof(TantargyResource.Oraszamkorrekcio), ResourceType = typeof(TantargyResource))]
        public bool OsszevontOra_BOOL { get; set; }

        [Display(Name = nameof(TantargyResource.Fotargy), ResourceType = typeof(TantargyResource))]
        public int? AmiFotargy { get; set; }

        [Display(Name = nameof(TantargyResource.Tagozat), ResourceType = typeof(TantargyResource))]
        public int? AmiTagozat { get; set; }

        [Display(Name = nameof(TantargyResource.TantargyKotelezoseg), ResourceType = typeof(TantargyResource))]
        public int? AmiTantargyKotelezoseg { get; set; }

        [Display(Name = nameof(TantargyResource.EvfolyamTipus), ResourceType = typeof(TantargyResource))]
        public int? EvfolyamTipus { get; set; }

        public int TanuloId { get; set; }

        public int? AmiFoglalkozasID { get; set; }

        public bool IsCsoportos { get; set; }

        public int? AmiTantargyID { get; set; }

        public int? FoglalkozasTipusa { get; set; }

        public bool NemzetisegiOra_BOOL { get; set; }

        public double TuloraSzam { get; set; }

        public double MegbizasiOraszam { get; set; }

        public FoglalkozasAmiTanuloCo ToCo()
        {
            var co = new FoglalkozasAmiTanuloCo
            {
                AmiFoglalkozasId = AmiFoglalkozasID,
                AMIFotargyId = AmiFotargy.Value,
                AmiTagozatId = AmiTagozat.Value,
                AMITantargyKotelezosegId = AmiTantargyKotelezoseg.Value,
                EvfolyamTipusId = EvfolyamTipus.Value,
                TanuloId = TanuloId
            };

            co.TantargyfelosztasCo.ID = int.TryParse(ID, out var tempVal) ? tempVal : (int?)null;

            if (!IsCsoportos)
            {
                co.TantargyfelosztasCo.TanevID = ClaimData.SelectedTanevID.Value;
                co.TantargyfelosztasCo.FoglalkozasTipusa = FoglalkozasTipusa;
                co.TantargyfelosztasCo.TanarID = TanarID.Value;
                co.TantargyfelosztasCo.OsztalyCsoportID = OsztalyId.Value;
                co.TantargyfelosztasCo.TantargyID = TantargyID.Value;
                co.TantargyfelosztasCo.Oraszam = Oraszam;
                co.TantargyfelosztasCo.TuloraSzam = TuloraSzam;
                co.TantargyfelosztasCo.OsszevontOra = OsszevontOra_BOOL;
                co.TantargyfelosztasCo.NemzetisegiOra = NemzetisegiOra_BOOL;
                co.TantargyfelosztasCo.MegbizasiOraszam = MegbizasiOraszam;
            }

            return co;
        }
    }

    public class TanuloTantargyaiDetailModel : IKretaIdentity
    {
        public string ID { get; set; }

        [Display(Name = nameof(TantargyResource.OsztalyCsoport), ResourceType = typeof(TantargyResource))]
        public string Osztaly { get; set; }

        [Display(Name = nameof(TantargyResource.Tantargy), ResourceType = typeof(TantargyResource))]
        public string Tantargy { get; set; }

        [Display(Name = nameof(TantargyResource.Tanar), ResourceType = typeof(TantargyResource))]
        public string Tanar { get; set; }

        [Display(Name = nameof(TantargyResource.HetiOraszam), ResourceType = typeof(TantargyResource))]
        public double Oraszam { get; set; }

        [Display(Name = nameof(TantargyResource.Oraszamkorrekcio), ResourceType = typeof(TantargyResource))]
        public string OsszevontOra_BNAME { get; set; }

        [Display(Name = nameof(TantargyResource.Fotargy), ResourceType = typeof(TantargyResource))]
        public string AmiFotargy_DNAME { get; set; }

        [Display(Name = nameof(TantargyResource.Tagozat), ResourceType = typeof(TantargyResource))]
        public string AmiTagozat_DNAME { get; set; }

        [Display(Name = nameof(TantargyResource.TantargyKotelezoseg), ResourceType = typeof(TantargyResource))]
        public string AmiTantargyKotelezoseg_DNAME { get; set; }

        [Display(Name = nameof(TantargyResource.EvfolyamTipus), ResourceType = typeof(TantargyResource))]
        public string EvfolyamTipus_DNAME { get; set; }

    }

    public class TanuloTantargyaiEgyeniModel : IKretaIdentity
    {
        public string ID { get; set; }

        [Display(Name = nameof(TantargyResource.OsztalyCsoport), ResourceType = typeof(TantargyResource))]
        public int? EgyeniOsztalyId { get; set; }

        [Display(Name = nameof(TantargyResource.Tantargy), ResourceType = typeof(TantargyResource))]
        public int? EgyeniTantargyID { get; set; }

        [Display(Name = nameof(TantargyResource.Tanar), ResourceType = typeof(TantargyResource))]
        public int? EgyeniTanarID { get; set; }

        [KretaRequired(typeof(TantargyResource), nameof(TantargyResource.OraszamMegadasaKotelezo))]
        [Range(0, General.TantargyfelosztasImportMaxOraszam, ErrorMessageResourceType = typeof(TantargyResource), ErrorMessageResourceName = nameof(TantargyResource.OraszamMegadasaKotelezo))]
        [Display(Name = nameof(TantargyResource.HetiOraszam), ResourceType = typeof(TantargyResource))]
        public double EgyeniOraszam { get; set; }

        [Display(Name = nameof(TantargyResource.Oraszamkorrekcio), ResourceType = typeof(TantargyResource))]
        public bool EgyeniOsszevontOra_BOOL { get; set; }

        [Display(Name = nameof(TantargyResource.Fotargy), ResourceType = typeof(TantargyResource))]
        public int? EgyeniAmiFotargy { get; set; }

        [Display(Name = nameof(TantargyResource.Tagozat), ResourceType = typeof(TantargyResource))]
        public int? EgyeniAmiTagozat { get; set; }

        [Display(Name = nameof(TantargyResource.TantargyKotelezoseg), ResourceType = typeof(TantargyResource))]
        public int? EgyeniAmiTantargyKotelezoseg { get; set; }

        [Display(Name = nameof(TantargyResource.EvfolyamTipus), ResourceType = typeof(TantargyResource))]
        public int? EgyeniEvfolyamTipus { get; set; }

        public int TanuloId { get; set; }

        public int? EgyeniAmiFoglalkozasID { get; set; }

        public int? EgyeniAmiTantargyID { get; set; }

        public int? EgyeniFoglalkozasTipusa { get; set; }

        public bool EgyeniNemzetisegiOra_BOOL { get; set; }

        public double EgyeniTuloraSzam { get; set; }

        public double EgyeniMegbizasiOraszam { get; set; }
    }

    public class TanuloTantargyaiEgyeniDetailModel : IKretaIdentity
    {
        public string ID { get; set; }

        [Display(Name = nameof(TantargyResource.OsztalyCsoport), ResourceType = typeof(TantargyResource))]
        public string Osztaly { get; set; }

        [Display(Name = nameof(TantargyResource.Tantargy), ResourceType = typeof(TantargyResource))]
        public string Tantargy { get; set; }

        [Display(Name = nameof(TantargyResource.Tanar), ResourceType = typeof(TantargyResource))]
        public string Tanar { get; set; }

        [Display(Name = nameof(TantargyResource.HetiOraszam), ResourceType = typeof(TantargyResource))]
        public double EgyeniOraszam { get; set; }

        [Display(Name = nameof(TantargyResource.Oraszamkorrekcio), ResourceType = typeof(TantargyResource))]
        public string EgyeniOsszevontOra_BNAME { get; set; }

        [Display(Name = nameof(TantargyResource.Fotargy), ResourceType = typeof(TantargyResource))]
        public string EgyeniAmiFotargy_DNAME { get; set; }

        [Display(Name = nameof(TantargyResource.Tagozat), ResourceType = typeof(TantargyResource))]
        public string EgyeniAmiTagozat_DNAME { get; set; }

        [Display(Name = nameof(TantargyResource.TantargyKotelezoseg), ResourceType = typeof(TantargyResource))]
        public string EgyeniAmiTantargyKotelezoseg_DNAME { get; set; }

        [Display(Name = nameof(TantargyResource.EvfolyamTipus), ResourceType = typeof(TantargyResource))]
        public string EgyeniEvfolyamTipus_DNAME { get; set; }

    }

    public class SaveTanuloTantargyaiModel
    {
        public List<TanuloTantargyaiModel> TanuloTantargyak { get; set; }

        public int OsztalyId { get; set; }

        public int TanuloId { get; set; }
    }

    public class ElozmenyekModel : IKretaIdentity
    {
        public string ID { get; set; }

        [Display(Name = nameof(TantargyResource.Tanev), ResourceType = typeof(TantargyResource))]
        public string Tanev { get; set; }

        [Display(Name = nameof(OsztalyCsoportResource.OsztalyCsoport), ResourceType = typeof(OsztalyCsoportResource))]
        public string OsztalyCsoport { get; set; }

        [Display(Name = nameof(TanuloResource.BelepesIdeje), ResourceType = typeof(TanuloResource))]
        public DateTime BelepesDatuma { get; set; }

        [Display(Name = nameof(TanuloResource.KilepesIdeje), ResourceType = typeof(TanuloResource))]
        public DateTime KilepesDatuma { get; set; }

        [Display(Name = nameof(TanuloResource.Zaradek), ResourceType = typeof(TanuloResource))]
        public string Zaradek { get; set; }
    }

    public class KozossegiSzolgalatModel
    {
        [Display(Name = nameof(TanuloResource.Leiras), ResourceType = typeof(TanuloResource))]
        public string Szoveg { get; set; }

        [Display(Name = nameof(TanuloResource.KozossegiSzolgalatokOraszamaOsszesen), ResourceType = typeof(TanuloResource))]
        public double OsszKozossegiSzolgalatOraszam { get; set; }
    }

    public class OsztalyCsoportModel : IKretaIdentity
    {
        public string ID { get; set; }

        [Display(Name = nameof(TanuloResource.Tanev), ResourceType = typeof(TanuloResource))]
        public string Tanev { get; set; }

        [Display(Name = nameof(TanuloResource.OsztalyCsoport), ResourceType = typeof(TanuloResource))]
        public string Nev { get; set; }

        [Display(Name = nameof(TanuloResource.Datumtol), ResourceType = typeof(TanuloResource))]
        public DateTime ErvKezd { get; set; }

        [Display(Name = nameof(TanuloResource.Datumig), ResourceType = typeof(TanuloResource))]
        public DateTime ErvVeg { get; set; }

        [Display(Name = nameof(TanuloResource.Tipus), ResourceType = typeof(TanuloResource))]
        public string CsoportTipus_DNAME { get; set; }

        [Display(Name = nameof(OsztalyCsoportResource.KepzesTipusa), ResourceType = typeof(OsztalyCsoportResource))]
        public string KepzesiForma_DNAME { get; set; }

        [Display(Name = nameof(OsztalyCsoportResource.Bontas), ResourceType = typeof(OsztalyCsoportResource))]
        public string Osztalybontas { get; set; }
    }

    public class TanultTantargyakModel : IKretaIdentity
    {
        public string ID { get; set; }

        [Display(Name = nameof(TanuloResource.OsztalyCsoport), ResourceType = typeof(TanuloResource))]
        public string OsztalyCsoportNev { get; set; }

        [Display(Name = nameof(TanuloResource.Alkalmazott), ResourceType = typeof(TanuloResource))]
        public string AlkalmazottNev { get; set; }

        [Display(Name = nameof(TanuloResource.Tantargy), ResourceType = typeof(TanuloResource))]
        public string TantargyNev { get; set; }

        [Display(Name = nameof(AlkalmazottResource.HetiOraszam), ResourceType = typeof(AlkalmazottResource))]
        public string HetiOraszam { get; set; }
    }

    public class OrarendiOraModel : IKretaIdentity
    {
        public string ID { get; set; }

        [Display(Name = nameof(OrarendResource.OrarendiNapHetirendje), ResourceType = typeof(OrarendResource))]
        public string Hetirend_DNAME { get; set; }

        [Display(Name = nameof(OrarendResource.Nap), ResourceType = typeof(OrarendResource))]
        public string Hetnapja_DNAME { get; set; }

        [Display(Name = nameof(OrarendResource.OraszamNaponbelul), ResourceType = typeof(OrarendResource))]
        public string Oraszam { get; set; }

        [Display(Name = nameof(OrarendResource.OsztalyCsoport), ResourceType = typeof(OrarendResource))]
        public string OsztalyCsoport { get; set; }

        [Display(Name = nameof(OrarendResource.Pedagogus), ResourceType = typeof(OrarendResource))]
        public string Pedagogus { get; set; }

        [Display(Name = nameof(OrarendResource.Tantargy), ResourceType = typeof(OrarendResource))]
        public string Tantargy { get; set; }

        [Display(Name = nameof(OrarendResource.Helyiseg), ResourceType = typeof(OrarendResource))]
        public string Terem { get; set; }

        [Display(Name = nameof(OrarendResource.ErvenyessegKezdete), ResourceType = typeof(OrarendResource))]
        public DateTime OrarendErvenyessegKezdete { get; set; }

        [Display(Name = nameof(OrarendResource.ErvenyessegVege), ResourceType = typeof(OrarendResource))]
        public DateTime OrarendErvenyessegVege { get; set; }
    }

    public class MulasztasokModel : IKretaIdentity
    {
        public string ID { get; set; }

        [Display(Name = nameof(TanuloResource.Datum), ResourceType = typeof(TanuloResource))]
        public DateTime Datum { get; set; }

        [Display(Name = nameof(TanuloResource.Ora), ResourceType = typeof(TanuloResource))]
        public string Oraszam { get; set; }

        [Display(Name = nameof(TanuloResource.Tantargy), ResourceType = typeof(TanuloResource))]
        public string Tantargy { get; set; }

        [Display(Name = nameof(TanuloResource.OsztalyCsoport), ResourceType = typeof(TanuloResource))]
        public string OsztalyCsoport { get; set; }

        [Display(Name = nameof(TanuloResource.Igazolt), ResourceType = typeof(TanuloResource))]
        public bool IsIgazolt_BOOL { get; set; }

        [Display(Name = nameof(TanuloResource.MulasztasTipusa), ResourceType = typeof(TanuloResource))]
        public string MulasztasTipusa_DNAME { get; set; }

        [Display(Name = nameof(TanuloResource.IgazolasTipus), ResourceType = typeof(TanuloResource))]
        public string IgazolasTipusa_DNAME { get; set; }
    }

    public class TanariTantargyModel : IKretaIdentity
    {
        public string ID { get; set; }

        [Display(Name = nameof(TanuloResource.Tanar), ResourceType = typeof(TanuloResource))]
        public string Tanar { get; set; }

        [Display(Name = nameof(TanuloResource.Tantargy), ResourceType = typeof(TanuloResource))]
        public string Tantargy { get; set; }

        [Display(Name = nameof(TanuloResource.Tipus), ResourceType = typeof(TanuloResource))]
        public string Tipus_DNAME { get; set; }
    }

    public class TantargyMentessegekModel : IKretaIdentity
    {
        public string ID { get; set; }

        [Display(Name = nameof(TanuloResource.Tantargy), ResourceType = typeof(TanuloResource))]
        public string Tantargy { get; set; }

        [Display(Name = nameof(TanuloResource.Tanev), ResourceType = typeof(TanuloResource))]
        public string Tanev { get; set; }

        [Display(Name = nameof(TanuloResource.MentessegOka), ResourceType = typeof(TanuloResource))]
        public string Mentessegoka { get; set; }
    }

    public class IgazolasokModel : IKretaIdentity
    {
        public string ID { get; set; }

        [Display(Name = nameof(TanuloResource.IgazolasiIdoszakEleje), ResourceType = typeof(TanuloResource))]
        public DateTime IgazolasKezdete { get; set; }

        [Display(Name = nameof(TanuloResource.IgazolasiIdoszakVege), ResourceType = typeof(TanuloResource))]
        public DateTime IgazolasVege { get; set; }

        [Display(Name = nameof(TanuloResource.Pedagogus), ResourceType = typeof(TanuloResource))]
        public string Pedagogus { get; set; }

        [Display(Name = nameof(TanuloResource.IgazolasTipus), ResourceType = typeof(TanuloResource))]
        public string Tipusa_DNAME { get; set; }

        [Display(Name = nameof(CommonResource.Ugyiratszam), ResourceType = typeof(CommonResource))]
        public string Ugyiratszam { get; set; }

        [Display(Name = nameof(IgazolasResource.Megjegyzes), ResourceType = typeof(IgazolasResource))]
        public string Megjegyzes { get; set; }
    }

    public class FeljegyzesekHaviModel : IKretaIdentity
    {
        public string ID { get; set; }

        [Display(Name = nameof(TanuloResource.FeljegyzesTipus), ResourceType = typeof(TanuloResource))]
        public string Tipus { get; set; }

        [Display(Name = nameof(TanuloResource.Szeptember), ResourceType = typeof(TanuloResource))]
        public string Szeptember { get; set; }

        [Display(Name = nameof(TanuloResource.Oktober), ResourceType = typeof(TanuloResource))]
        public string Oktober { get; set; }

        [Display(Name = nameof(TanuloResource.November), ResourceType = typeof(TanuloResource))]
        public string November { get; set; }

        [Display(Name = nameof(TanuloResource.December), ResourceType = typeof(TanuloResource))]
        public string December { get; set; }

        [Display(Name = nameof(TanuloResource.Januar), ResourceType = typeof(TanuloResource))]
        public string Januar { get; set; }

        [Display(Name = nameof(TanuloResource.Februar), ResourceType = typeof(TanuloResource))]
        public string Februar { get; set; }

        [Display(Name = nameof(TanuloResource.Marcius), ResourceType = typeof(TanuloResource))]
        public string Marcius { get; set; }

        [Display(Name = nameof(TanuloResource.Aprilis), ResourceType = typeof(TanuloResource))]
        public string Aprilis { get; set; }

        [Display(Name = nameof(TanuloResource.Majus), ResourceType = typeof(TanuloResource))]
        public string Majus { get; set; }

        [Display(Name = nameof(TanuloResource.Junius), ResourceType = typeof(TanuloResource))]
        public string Junius { get; set; }

        [Display(Name = nameof(TanuloResource.Felev), ResourceType = typeof(TanuloResource))]
        public string Felev { get; set; }

        [Display(Name = nameof(TanuloResource.Osszesen), ResourceType = typeof(TanuloResource))]
        public string Ossz { get; set; }
    }

    public class GondviselokModel : IKretaIdentity
    {
        public string ID { get; set; }

        [Display(Name = nameof(TanuloResource.GondviseloNeve), ResourceType = typeof(TanuloResource))]
        public string Nev { get; set; }

        [Display(Name = nameof(TanuloResource.Felhasznalonev), ResourceType = typeof(TanuloResource))]
        [StringLength(maximumLength: 100, ErrorMessageResourceName = nameof(ErrorResource.FelhasznalonevMax100Karakter), ErrorMessageResourceType = typeof(ErrorResource))]
        public string BelepesiNev { get; set; }

        [Display(Name = nameof(TanuloResource.RokonsagiFok), ResourceType = typeof(TanuloResource))]
        public string RokonsagFoka_DNAME { get; set; }

        [PhoneExtended(ErrorMessageResourceName = nameof(ErrorResource.ATelefonszamFormatumaNemMegfelelo), ErrorMessageResourceType = typeof(ErrorResource))]
        [Display(Name = nameof(TanuloResource.Telefonszam), ResourceType = typeof(TanuloResource))]
        public string TelefonSzam { get; set; }

        [Display(Name = nameof(TanuloResource.EMail), ResourceType = typeof(TanuloResource))]
        [EmailAddressExtended(ErrorMessageResourceName = nameof(ErrorResource.EMailCimFormatumaNemMegfelelo), ErrorMessageResourceType = typeof(ErrorResource))]
        [StringLength(General.EmailMaximumKarakterekSzama, ErrorMessageResourceName = nameof(ErrorResource.EmailMax0Karakter), ErrorMessageResourceType = typeof(ErrorResource))]
        public string EmailCim { get; set; }

        [Display(Name = nameof(TanuloResource.TorvenyesKepviselo), ResourceType = typeof(TanuloResource))]
        public string IsTorvenyesKepviselo_BNAME { get; set; }

        [Display(Name = nameof(TanuloResource.BovitettJogosultsag), ResourceType = typeof(TanuloResource))]
        public string BovitettJog_BNAME { get; set; }

        [Display(Name = nameof(TanuloResource.UtolsoBelepes), ResourceType = typeof(TanuloResource))]
        public DateTime? UtolsoBelepes { get; set; }

        [Display(Name = nameof(TanuloResource.UtolsoBelepesMobil), ResourceType = typeof(TanuloResource))]
        public DateTime? UtolsoBelepesMobil { get; set; }

        public bool IsHibasanMegadva_BOOL { get; set; }
    }

    public class ElerhetosegCimModel : IKretaIdentity
    {
        public string ID { get; set; }

        [Display(Name = nameof(TanuloResource.Orszag), ResourceType = typeof(TanuloResource))]
        public string Orszag_DNAME { get; set; }

        [Display(Name = nameof(TanuloResource.Tipus), ResourceType = typeof(TanuloResource))]
        public string CimTipus_DNAME { get; set; }

        [Display(Name = nameof(TanuloResource.Iranyitoszam), ResourceType = typeof(TanuloResource))]
        public string Irsz { get; set; }

        [Display(Name = nameof(TanuloResource.Helyseg), ResourceType = typeof(TanuloResource))]
        public string Varos { get; set; }

        [Display(Name = nameof(TanuloResource.Cim), ResourceType = typeof(TanuloResource))]
        [StringLength(maximumLength: 100, ErrorMessageResourceName = nameof(ErrorResource.CimMax100Karakter), ErrorMessageResourceType = typeof(ErrorResource))]
        public string Cim { get; set; }

        [Display(Name = nameof(TanuloResource.Kozterulet), ResourceType = typeof(TanuloResource))]
        public string Kozterulet { get; set; }

        [Display(Name = nameof(TanuloResource.KozteruletJellege), ResourceType = typeof(TanuloResource))]
        public string KozteruletJellegeNev { get; set; }

        [Display(Name = nameof(TanuloResource.Hazszam), ResourceType = typeof(TanuloResource))]
        public string HazSzam { get; set; }

        [Display(Name = nameof(TanuloResource.Emelet), ResourceType = typeof(TanuloResource))]
        [StringLength(maximumLength: 100, ErrorMessageResourceName = nameof(ErrorResource.EmeletMax100Karakter), ErrorMessageResourceType = typeof(ErrorResource))]
        public string Emelet { get; set; }

        [Display(Name = nameof(TanuloResource.Ajto), ResourceType = typeof(TanuloResource))]
        [StringLength(maximumLength: 100, ErrorMessageResourceName = nameof(ErrorResource.AjtoMax100Karakter), ErrorMessageResourceType = typeof(ErrorResource))]
        public string Ajto { get; set; }

        [Display(Name = nameof(TanuloResource.Alapertelmezett), ResourceType = typeof(TanuloResource))]
        public bool Alapertelmezett_BOOL { get; set; }
    }

    public class GondviseloCimModel : IKretaIdentity
    {
        public string ID { get; set; }

        [Display(Name = nameof(TanuloResource.GondviseloNeve), ResourceType = typeof(TanuloResource))]
        public string GondviseloNev { get; set; }

        [Display(Name = nameof(TanuloResource.Orszag), ResourceType = typeof(TanuloResource))]
        public string Orszag_DNAME { get; set; }

        [Display(Name = nameof(TanuloResource.Tipus), ResourceType = typeof(TanuloResource))]
        public string CimTipus_DNAME { get; set; }

        [Display(Name = nameof(TanuloResource.Iranyitoszam), ResourceType = typeof(TanuloResource))]
        public string Iranyitoszam { get; set; }

        [Display(Name = nameof(TanuloResource.Helyseg), ResourceType = typeof(TanuloResource))]
        public string HelysegNev { get; set; }

        [Display(Name = nameof(TanuloResource.Cim), ResourceType = typeof(TanuloResource))]
        [StringLength(maximumLength: 100, ErrorMessageResourceName = nameof(ErrorResource.CimMax100Karakter), ErrorMessageResourceType = typeof(ErrorResource))]
        public string Cim { get; set; }

        [Display(Name = nameof(TanuloResource.Kozterulet), ResourceType = typeof(TanuloResource))]
        public string KozteruletNev { get; set; }

        [Display(Name = nameof(TanuloResource.KozteruletJellege), ResourceType = typeof(TanuloResource))]
        public string KozteruletTipusNev { get; set; }

        [Display(Name = nameof(TanuloResource.Hazszam), ResourceType = typeof(TanuloResource))]
        public string HazSzam { get; set; }

        [Display(Name = nameof(TanuloResource.Emelet), ResourceType = typeof(TanuloResource))]
        [StringLength(maximumLength: 100, ErrorMessageResourceName = nameof(ErrorResource.EmeletMax100Karakter), ErrorMessageResourceType = typeof(ErrorResource))]
        public string Emelet { get; set; }

        [Display(Name = nameof(TanuloResource.Ajto), ResourceType = typeof(TanuloResource))]
        [StringLength(maximumLength: 100, ErrorMessageResourceName = nameof(ErrorResource.AjtoMax100Karakter), ErrorMessageResourceType = typeof(ErrorResource))]
        public string Ajto { get; set; }

        [Display(Name = nameof(TanuloResource.Alapertelmezett), ResourceType = typeof(TanuloResource))]
        public bool Alapertelmezett_BOOL { get; set; }
    }

    public class ElerhetosegEmailModel : IKretaIdentity
    {
        public string ID { get; set; }

        [Display(Name = nameof(TanuloResource.Tipus), ResourceType = typeof(TanuloResource))]
        public string Tipus_DNAME { get; set; }

        [Display(Name = nameof(TanuloResource.EmailCim), ResourceType = typeof(TanuloResource))]
        public string EmailCim { get; set; }

        [Display(Name = nameof(TanuloResource.Alapertelmezett), ResourceType = typeof(TanuloResource))]
        public bool Alapertelmezett_BOOL { get; set; }

        public bool IsHibasanMegadva_BOOL { get; set; }
    }

    public class ElerhetosegTelModel : IKretaIdentity
    {
        public string ID { get; set; }

        [Display(Name = nameof(TanuloResource.Tipus), ResourceType = typeof(TanuloResource))]
        public string Tipus_DNAME { get; set; }

        [Display(Name = nameof(TanuloResource.Telefonszam), ResourceType = typeof(TanuloResource))]
        public string TelefonSzam { get; set; }

        [Display(Name = nameof(TanuloResource.Alapertelmezett), ResourceType = typeof(TanuloResource))]
        public bool Alapertelmezett_BOOL { get; set; }
    }

    public class TanuloFelmentesGridModel : IKretaIdentity
    {
        public string ID { get; set; }

        public int TanuloId { get; set; }

        [Display(Name = nameof(TanuloResource.Tantargy), ResourceType = typeof(TanuloResource))]
        public int TantargyId { get; set; }

        [Display(Name = nameof(TanuloResource.Tantargy), ResourceType = typeof(TanuloResource))]
        public string TantargyNev { get; set; }

        [Display(Name = nameof(TanuloResource.ErtekelesAloliFelmentes), ResourceType = typeof(TanuloResource))]
        public bool ErtekelesMentesites { get; set; }

        [Display(Name = nameof(TanuloResource.ErtekelesAloliFelmentes), ResourceType = typeof(TanuloResource))]
        public string ErtekelesMentesites_BNAME { get; set; }

        [Display(Name = nameof(TanuloResource.TanoraLatogatasaAloliFelmentes), ResourceType = typeof(TanuloResource))]
        public bool OraMentesites { get; set; }

        [Display(Name = nameof(TanuloResource.TanoraLatogatasaAloliFelmentes), ResourceType = typeof(TanuloResource))]
        public string OraMentesites_BNAME { get; set; }

        [Display(Name = nameof(TanuloResource.FelmentesOka), ResourceType = typeof(TanuloResource))]
        public string FelmentesOka { get; set; }

        [Display(Name = nameof(TanuloResource.Kezdete), ResourceType = typeof(TanuloResource))]
        public DateTime? Kezdete { get; set; }

        [Display(Name = nameof(TanuloResource.Vege), ResourceType = typeof(TanuloResource))]
        public DateTime? Vege { get; set; }

        [Display(Name = nameof(TanuloResource.SzovegesenErtekelheto), ResourceType = typeof(TanuloResource))]
        public bool SzovegesenErtekelheto { get; set; }

        [Display(Name = nameof(TanuloResource.SzovegesenErtekelheto), ResourceType = typeof(TanuloResource))]
        public string SzovegesenErtekelheto_BNAME { get; set; }
    }

    public class GondviseloUtolsoBelepesGridModel : IKretaIdentity
    {
        public string ID { get; set; }

        [Display(Name = nameof(TanuloResource.Gondviselo), ResourceType = typeof(TanuloResource))]
        public string GondviseloNev { get; set; }

        [Display(Name = nameof(TanuloResource.TanuloUtolsoBelepes), ResourceType = typeof(TanuloResource))]
        public string UtolsoBelepes { get; set; }
    }

    public class TanuloDetailSzirBeallitasokModel
    {
        [Display(Name = nameof(TanuloResource.KuldhetoErettsegiSzRnek), ResourceType = typeof(TanuloResource))]
        public string IsKuldhetoErettsegiSzRnek { get; set; }

        [Display(Name = nameof(TanuloResource.KuldhetoMeresiSzRnek), ResourceType = typeof(TanuloResource))]
        public string IsKuldhetoMeresiSzRnek { get; set; }

        [Display(Name = nameof(TanuloResource.KuldhetoKozepFelveteliSzRnek), ResourceType = typeof(TanuloResource))]
        public string IsKuldhetoKozepFelveteliSzRnek { get; set; }

        [Display(Name = nameof(TanuloResource.DiakigazolvanyAtadhatoSzRnek), ResourceType = typeof(TanuloResource))]
        public string IsDiakigazolvanyAtadhatoSzRnek { get; set; }
    }

    public class JogviszonyModel : IKretaIdentity
    {
        public string ID { get; set; }

        public int TanuloId { get; set; }

        [Display(Name = nameof(TanuloResource.JogviszonyTipusa), ResourceType = typeof(TanuloResource))]
        public string JogviszonyTipusa { get; set; }

        [Display(Name = nameof(TanuloResource.JogviszonyTipusa), ResourceType = typeof(TanuloResource))]
        [RequiredIf("TanuloId", Operator.NotEqualTo, 0, ErrorMessageResourceName = nameof(ErrorResource.JogviszonyTipusaKitolteseKotelez), ErrorMessageResourceType = typeof(ErrorResource))]
        public int? JogviszonyTipusaId { get; set; }

        [Display(Name = nameof(TanuloResource.JogviszonyKezdete), ResourceType = typeof(TanuloResource))]
        [RequiredIf("TanuloId", Operator.NotEqualTo, 0, ErrorMessageResourceName = nameof(ErrorResource.JogviszonyKezdeteKitolteseKotelezo), ErrorMessageResourceType = typeof(ErrorResource))]
        public DateTime? JogviszonyKezdete { get; set; }

        [Display(Name = nameof(TanuloResource.JogviszonyVege), ResourceType = typeof(TanuloResource))]
        public DateTime? JogviszonyVege { get; set; }

        [Display(Name = nameof(TanuloResource.JogviszonyKeletkezesenekJogcime), ResourceType = typeof(TanuloResource))]
        public string JogviszonyKeletkezesenekJogcime { get; set; }

        [Display(Name = nameof(TanuloResource.JogviszonyKeletkezesenekJogcime), ResourceType = typeof(TanuloResource))]
        [RequiredIf("TanuloId", Operator.NotEqualTo, 0, ErrorMessageResourceName = nameof(ErrorResource.JogviszonyKeletkezesenekJogcimeKitolteseKotelezo), ErrorMessageResourceType = typeof(ErrorResource))]
        public int? JogviszonyKeletkezesenekJogcimeId { get; set; }

        [Display(Name = nameof(TanuloResource.JogviszonyMegszunesenekJogcime), ResourceType = typeof(TanuloResource))]
        public string JogviszonyMegszunesenekJogcime { get; set; }

        [Display(Name = nameof(TanuloResource.JogviszonyMegszunesenekJogcime), ResourceType = typeof(TanuloResource))]
        public int? JogviszonyMegszunesenekJogcimeId { get; set; }

        [Display(Name = nameof(TanuloResource.JogviszonyStatusza), ResourceType = typeof(TanuloResource))]
        public string JogviszonyStatusza { get; set; }

        [Display(Name = nameof(TanuloResource.Megjegyzes), ResourceType = typeof(TanuloResource))]
        [MaxLength(150, ErrorMessageResourceName = nameof(TanuloResource.AMegjegyzesMaximum150KarakterLehet), ErrorMessageResourceType = typeof(TanuloResource))]
        public string Megjegyzes { get; set; }

        public bool IsNew { get; set; }

        public JogviszonyCo ConvertToCo()
        {
            var jogviszonyId = string.IsNullOrWhiteSpace(ID) ? (int?)null : int.Parse(ID);
            return new JogviszonyCo
            {
                ID = jogviszonyId,
                IsAktiv = IsNew,
                JogviszonyKeletkezesenekJogcimeId = JogviszonyKeletkezesenekJogcimeId,
                JogviszonyMegszunesenekJogcimeId = JogviszonyMegszunesenekJogcimeId,
                JogviszonyTipusId = JogviszonyTipusaId,
                Kezdete = JogviszonyKezdete.Value,
                Megjegyzes = Megjegyzes,
                TanuloId = TanuloId,
                Vege = JogviszonyVege,
            };
        }
    }
}
