﻿using System;
using System.ComponentModel.DataAnnotations;
using Kreta.BusinessLogic.HelperClasses;
using Kreta.BusinessLogic.Interfaces;
using Kreta.Core.CustomAttributes;
using Kreta.Resources;

namespace Kreta.Web.Areas.Tanulo.Models
{
    public class TanuloGridModel : IKretaIdentity
    {
        public const string TanuloExportAttributeId = nameof(TanuloExportAttributeId);
        public const string DualisTanuloExportAttributeId = nameof(DualisTanuloExportAttributeId);

        public TanuloGridModel()
        {

        }

        public TanuloGridModel(TanuloGridItemCo itemCo)
        {
            TanuloId = itemCo.TanuloId;
            TanuloNeve = itemCo.TanuloNeve;
            TanuloNeveElotagNelkul = itemCo.TanuloNeveElotagNelkul;
            AnyjaNeve = itemCo.AnyjaNeve;
            SzuletesiHely = itemCo.SzuletesiHely;
            SzuletesiIdo = itemCo.SzuletesiIdo;
            OktatasiAzonosito = itemCo.OktatasiAzonosito;
            IsTankotelezettText = itemCo.IsTanKotelezettText;
            Osztaly = itemCo.Osztaly;
            OsztalyCsoportId = itemCo.OsztalyCsoportId;
            IsArchivalt = itemCo.IsArchivalt;
            MuveszetiAgId_DNAME = itemCo.MuveszetiAgId_DNAME;
            ID = $"{TanuloId}_{OsztalyCsoportId}";
            SzervezetNev = itemCo.SzervezetNev;
            SzervezetAzonosito = itemCo.SzervezetAzonosito;
        }

        public string ID { get; set; }

        public int TanuloId { get; set; }
        public int? OsztalyCsoportId { get; set; }

        [Display(Name = nameof(TanuloResource.Nev), ResourceType = typeof(TanuloResource))]
        public string TanuloNeve { get; set; }

        [SimpleExportColumn(TanuloExportAttributeId, 00, nameof(TanuloResource.Neve), typeof(TanuloResource))]
        [SimpleExportColumn(DualisTanuloExportAttributeId, 00, nameof(TanuloResource.Neve), typeof(TanuloResource))]
        [Display(Name = nameof(TanuloResource.Nev), ResourceType = typeof(TanuloResource))]
        public string TanuloNeveElotagNelkul { get; set; }

        [SimpleExportColumn(TanuloExportAttributeId, 02, nameof(TanuloResource.AnyjaSzuletesiNev), typeof(TanuloResource))]
        [SimpleExportColumn(DualisTanuloExportAttributeId, 02, nameof(TanuloResource.AnyjaSzuletesiNev), typeof(TanuloResource))]
        [Display(Name = nameof(TanuloResource.AnyjaNeve), ResourceType = typeof(TanuloResource))]
        public string AnyjaNeve { get; set; }

        [SimpleExportColumn(TanuloExportAttributeId, 03, nameof(TanuloResource.SzuletesiHely), typeof(TanuloResource))]
        [SimpleExportColumn(DualisTanuloExportAttributeId, 03, nameof(TanuloResource.SzuletesiHely), typeof(TanuloResource))]
        [Display(Name = nameof(TanuloResource.SzuletesiHely), ResourceType = typeof(TanuloResource))]
        public string SzuletesiHely { get; set; }

        [SimpleExportColumn(TanuloExportAttributeId, 04, nameof(TanuloResource.SzuletesiIdo), typeof(TanuloResource))]
        [SimpleExportColumn(DualisTanuloExportAttributeId, 04, nameof(TanuloResource.SzuletesiIdo), typeof(TanuloResource))]
        [Display(Name = nameof(TanuloResource.SzuletesiIdo), ResourceType = typeof(TanuloResource))]
        public DateTime SzuletesiIdo { get; set; }

        [SimpleExportColumn(TanuloExportAttributeId, 01, nameof(TanuloResource.OktatasiAzonosito), typeof(TanuloResource))]
        [SimpleExportColumn(DualisTanuloExportAttributeId, 01, nameof(TanuloResource.OktatasiAzonosito), typeof(TanuloResource))]
        [Display(Name = nameof(TanuloResource.OktatasiAzonosito), ResourceType = typeof(TanuloResource))]
        public string OktatasiAzonosito { get; set; }

        [Display(Name = nameof(TanuloResource.Tankotelezett), ResourceType = typeof(TanuloResource))]
        public bool Tankotelezett { get; set; }

        [SimpleExportColumn(TanuloExportAttributeId, 05, nameof(TanuloResource.Tankotelezett), typeof(TanuloResource))]
        [Display(Name = nameof(TanuloResource.Tankotelezett), ResourceType = typeof(TanuloResource))]
        public string IsTankotelezettText { get; set; }

        [Display(Name = nameof(TanuloResource.Tanterv), ResourceType = typeof(TanuloResource))]
        public string Tanterv { get; set; }

        [SimpleExportColumn(TanuloExportAttributeId, 06, nameof(TanuloResource.Osztaly), typeof(TanuloResource))]
        [SimpleExportColumn(DualisTanuloExportAttributeId, 05, nameof(TanuloResource.Osztaly), typeof(TanuloResource))]
        [Display(Name = nameof(TanuloResource.Osztaly), ResourceType = typeof(TanuloResource))]
        public string Osztaly { get; set; }

        [Display(Name = nameof(OsztalyCsoportResource.MuvesztiAg), ResourceType = typeof(OsztalyCsoportResource))]
        public string MuveszetiAgId_DNAME { get; set; }

        [Display(Name = nameof(TanuloResource.Tankotelezett), ResourceType = typeof(TanuloResource))]
        public string Tankotelezett_BNAME { get; set; }

        public bool IsArchivalt { get; set; }

        [SimpleExportColumn(DualisTanuloExportAttributeId, 06, nameof(TeremResource.SzervezetNeve), typeof(TeremResource))]
        [Display(Name = nameof(TeremResource.SzervezetNeve), ResourceType = typeof(TeremResource))]
        public string SzervezetNev { get; set; }

        [SimpleExportColumn(DualisTanuloExportAttributeId, 07, nameof(TeremResource.SzervezetAzonosito), typeof(TeremResource))]
        [Display(Name = nameof(TeremResource.SzervezetAzonosito), ResourceType = typeof(TeremResource))]
        public string SzervezetAzonosito { get; set; }
    }
}
