﻿using System;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;
using System.Linq;
using System.Web.Mvc;
using Foolproof;
using Kreta.BusinessLogic.Classes;
using Kreta.BusinessLogic.HelperClasses;
using Kreta.BusinessLogic.Helpers;
using Kreta.BusinessLogic.Helpers.SystemSettings;
using Kreta.BusinessLogic.Interfaces;
using Kreta.BusinessLogic.Security;
using Kreta.Core;
using Kreta.Core.CustomAttributes;
using Kreta.Enums;
using Kreta.Enums.ManualEnums;
using Kreta.Enums.ManualEnums.SystemSettings;
using Kreta.Resources;
using Kreta.Web.Areas.Tanulo.Helper;
using Kreta.Web.Helpers;
using Kreta.Web.Models;
using Kreta.Web.Models.EditorTemplates;
using Kreta.Web.Security;
using static Kreta.Core.Constants;
using static Kreta.Core.EntityInfos.EntityLengths;

namespace Kreta.Web.Areas.Tanulo.Models
{
    public class TanuloModel : TabStripModel
    {
        public TanuloModel()
        {
            AmiKepzesiJellemzokModel = new AmiKepzesiJellemzokModelForTanulo();
        }
        public int? TanuloId { get; set; }

        public string TanuloModalHeader { get; set; }

        public int? TanevId { get; set; }

        public bool IsSzirIntezmeny { get; set; }

        public int? FollowUpolniId { get; set; }

        public bool IsTanterviJellemzoRequired => ClaimData.IsSelectedTanev21_22OrLater && ClaimData.IsSzakkepzoIntezmeny && TanuloTanugyModel.OsztalyId.HasValue;
        public bool IsTanterviJellegRequired => ClaimData.IsSelectedTanev21_22OrLater && ClaimData.IsSzakkepzoIntezmeny && TanuloTanugyModel.OsztalyId.HasValue;
        public bool IsKotelezoJogviszonyBefejezese => ClaimData.IsSelectedTanev21_22OrLater && ClaimData.IsSzakkepzoIntezmeny;

        [Display(Name = nameof(FeljegyzesekResource.OsszesOraszam), ResourceType = typeof(FeljegyzesekResource))]
        public double KozossegiSzolgalatOsszesOraszam { get; set; } = 0;

        [ValidateObject]
        public TanuloAlapAdatModel TanuloAlapAdatModel { get; set; }

        [ValidateObject]
        public CimElerhetosegModel CimElerhetosegModel { get; set; }

        [ValidateObject]
        public GondviseloCimElerhetosegModel GondviseloCimElerhetosegModel { get; set; }

        [ValidateObject]
        public TanuloGondviseloModel TanuloGondviseloModel { get; set; }

        [ValidateObject]
        public TanuloIgazolvanyModel TanuloIgazolvanyModel { get; set; }

        [ValidateObject]
        public TanuloTanugyModel TanuloTanugyModel { get; set; }

        [ValidateObject]
        public TanuloSzocialisModel TanuloSzocialisModel { get; set; }

        [ValidateObject]
        public TanuloSajatosAdatModel TanuloSajatosAdatModel { get; set; }

        [ValidateObject]
        public TanuloBTMProblemakModel TanuloBTMProblemakModel { get; set; }

        [ValidateObject]
        public TanuloSportModel TanuloSportModel { get; set; }

        [ValidateObject]
        public TanuloVallasModel TanuloVallasModel { get; set; }

        [ValidateObject]
        public TanuloKozszolgModel TanuloKozszolgModel { get; set; }

        public TanuloKozszolgGridModel TanuloKozszolgGridModel { get; set; }

        public ZaradekModel ZaradekModel { get; set; }

        [ValidateObject]
        public TanuloFelmentesModel TanuloFelmentesModel { get; set; }

        [ValidateObject]
        public TanuloJuttatasModel TanuloJuttatasModel { get; set; }

        [ValidateObject]
        public ApaczaiJuttatasModel ApaczaiJuttatasModel { get; set; }

        [ValidateObject]
        public TanuloBankszamlaModel TanuloBankszamlaModel { get; set; }

        [ValidateObject]
        public TanuloSzirBeallitasokModel TanuloSzirBeallitasokModel { get; set; }

        public EgyszeriPalyakezdesiModel TanuloEgyszeriPalyakezdesiModel { get; set; }

        public bool IsNszfhUjSzkt => ClaimData.IsSelectedTanev20_21OrLater && ClaimData.IsSzakkepzoIntezmeny;

        public AmiKepzesiJellemzokModelForTanulo AmiKepzesiJellemzokModel { get; set; }

        public bool IsApaczaiEnabled { get; set; }
        public bool IsDualisKepzesEnabled { get; set; }

        [ValidateObject]
        public JogviszonyModel TanuloUjJogviszonyModel { get; set; }

        public static TanuloAdatCO ConvertModelToCo(TanuloModel model)
        {
            var co = new TanuloAdatCO
            {
                ID = model.TanuloId
            };

            /*tanuloAlapAdatModel*/
            if (model.TanuloAlapAdatModel != null)
            {
                co.OktatasiAzonosito = model.TanuloAlapAdatModel.OktatasiAzonosito;
                co.IsOktatasiAzonositoNelkul = model.TanuloAlapAdatModel.IsOktatasiAzonositoNelkul;
                co.Neme = model.TanuloAlapAdatModel.Neme;
                co.CsaladiNev = model.TanuloAlapAdatModel.CsaladiNev.ReplaceMultipleSpacesAndTrim();
                co.UtoNev = model.TanuloAlapAdatModel.UtoNev.ReplaceMultipleSpacesAndTrim();
                co.Elotag = model.TanuloAlapAdatModel.Elotag;
                co.AnyjaCsaladiNev = model.TanuloAlapAdatModel.AnyjaCsaladiNev.ReplaceMultipleSpacesAndTrim();
                co.AnyjaUtoNev = model.TanuloAlapAdatModel.AnyjaUtoNev.ReplaceMultipleSpacesAndTrim();
                co.AnyjaNeveElotag = model.TanuloAlapAdatModel.AnyjaNeveElotag;
                co.SzuletesiCsaladiNev = model.TanuloAlapAdatModel.SzuletesiCsaladiNev.ReplaceMultipleSpacesAndTrim();
                co.SzuletesiUtoNev = model.TanuloAlapAdatModel.SzuletesiUtoNev.ReplaceMultipleSpacesAndTrim();
                co.SzuletesiNevElotag = model.TanuloAlapAdatModel.SzuletesiNevElotag;
                co.SzuletesiHely = model.TanuloAlapAdatModel.SzuletesiHely;
                co.SzuletesiIdo = model.TanuloAlapAdatModel.SzuletesiIdo ?? default(DateTime);
                co.Allampolgarsag = model.TanuloAlapAdatModel.Allampolgarsag ?? default(int);
                co.Allampolgarsag2 = model.TanuloAlapAdatModel.Allampolgarsag2 ?? default(int);
                co.TartozkodasJogcimTipusId = model.TanuloAlapAdatModel.TartozkodasJogcimTipusId;
                co.OkiratSzam = model.TanuloAlapAdatModel.OkiratSzam;
                co.Anyanyelv = model.TanuloAlapAdatModel.Anyanyelv;
                co.Megjegyzes = model.TanuloAlapAdatModel.Megjegyzes;
                co.BelepesiNev = model.TanuloAlapAdatModel.BejelentkezesiNev;
                co.Jelszo = model.TanuloAlapAdatModel.Jelszo;
                co.SzuletesiOrszag = model.TanuloAlapAdatModel.SzuletesiOrszag ?? default(int);
                co.TartozkodasiJogotIgazoloOkmanyId = model.TanuloAlapAdatModel.TartozkodasiJogotIgazoloOkmanyId;
                co.TartozkodasiJogotIgazoloOkmanySzama = model.TanuloAlapAdatModel.TartozkodasiJogotIgazoloOkmanySzama;
            }

            /*tanuloElerhetosegModel*/
            if (model.CimElerhetosegModel != null)
            {
                co.Orszag = model.CimElerhetosegModel.Orszag ?? (int)OrszagTipusEnum.Magyarorszag;
                co.Iranyitoszam = model.CimElerhetosegModel.Iranyitoszam_Str;
                co.HelysegNev = model.CimElerhetosegModel.HelysegNev_Str;
                co.KozteruletNev = model.CimElerhetosegModel.KozteruletNev;
                co.KozteruletTipusNev = model.CimElerhetosegModel.KozteruletTipus_Str;
                co.Hazszam = model.CimElerhetosegModel.Hazszam;
                co.Emelet = model.CimElerhetosegModel.Emelet;
                co.Ajto = model.CimElerhetosegModel.Ajto;
                co.Telefonszam = model.CimElerhetosegModel.Telefon;
                co.TelefonTipus = model.CimElerhetosegModel.TelefonTipus;
                co.Emailcim = model.CimElerhetosegModel.Emailcim;
                co.AlapertelmezettCim = model.CimElerhetosegModel.AlapertelmezettCim;
            }

            /*tanuloGondviseloModel*/
            if (model.TanuloGondviseloModel != null && !model.TanuloId.HasValue)
            {
                if (model.GondviseloCimElerhetosegModel == null || model.GondviseloCimElerhetosegModel.TanulovalEgyezik_Gondviselo)
                {
                    co.OrszagGondviselo = co.Orszag;
                    co.IranyitoszamGondviselo = co.Iranyitoszam;
                    co.HelysegNevGondviselo = co.HelysegNev;
                    co.KozteruletNevGondviselo = co.KozteruletNev;
                    co.KozteruletJellegNevGondviselo = co.KozteruletTipusNev;
                    co.HazszamGondviselo = co.Hazszam;
                    co.EmeletGondviselo = co.Emelet;
                    co.AjtoGondviselo = co.Ajto;
                    co.AlapertelmezettGondviseloCim = co.AlapertelmezettCim;
                }
                else
                {
                    co.OrszagGondviselo = model.GondviseloCimElerhetosegModel.Orszag_Gondviselo;
                    co.IranyitoszamGondviselo = model.GondviseloCimElerhetosegModel.Iranyitoszam_Gondviselo_Str;
                    co.HelysegNevGondviselo = model.GondviseloCimElerhetosegModel.HelysegNev_Gondviselo_Str;
                    co.KozteruletNevGondviselo = model.GondviseloCimElerhetosegModel.KozteruletNev_Gondviselo;
                    co.KozteruletJellegNevGondviselo = model.GondviseloCimElerhetosegModel.KozteruletTipus_Gondviselo_Str;
                    co.HazszamGondviselo = model.GondviseloCimElerhetosegModel.Hazszam_Gondviselo;
                    co.EmeletGondviselo = model.GondviseloCimElerhetosegModel.Emelet_Gondviselo;
                    co.AjtoGondviselo = model.GondviseloCimElerhetosegModel.Ajto_Gondviselo;
                    co.AlapertelmezettGondviseloCim = true;
                }

                co.TelefonszamGondviselo = model.GondviseloCimElerhetosegModel?.Telefon_Gondviselo;
                co.TelefonTipusGondviselo = model.GondviseloCimElerhetosegModel?.TelefonTipus_Gondviselo;
                co.EmailcimGondviselo = model.GondviseloCimElerhetosegModel?.Emailcim_Gondviselo;
                co.GondviseloNeve = model.TanuloGondviseloModel.GondviseloNeve;
                co.GondviseloBelepesiNeve = model.TanuloGondviseloModel.GondviseloBejelentkezesiNev;
                co.RokonsagiFok = model.TanuloGondviseloModel.RokonsagiFok ?? default(int);
                co.GondviseloJelszava = model.TanuloGondviseloModel.GondviseloJelszo;
                co.GondviseloAutoEmail = model.TanuloGondviseloModel.GondviseloAutoEmail;
                co.IsTorvenyesKepviselo = model.TanuloGondviseloModel.IsTorvenyesKepviselo;
            }

            /*tanuloIgazolvanyModel*/
            if (model.TanuloIgazolvanyModel != null)
            {
                co.AdoazonositoJel = model.TanuloIgazolvanyModel.AdoazonositoJel;
                //co.BankszamlaSzam = model.TanuloIgazolvanyModel.Bankszamlaszam;
                co.DiakigazolvanyKelte = model.TanuloIgazolvanyModel.DiakigazolvanyKelte;
                co.DiakigazolvanySzam = model.TanuloIgazolvanyModel.DiakigazolvanySzam;
                co.Igazolvanyszam = model.TanuloIgazolvanyModel.Igazolvanyszam;
                co.IgazolvanyTipus = model.TanuloIgazolvanyModel.IgazolvanyTipus;
                co.TajSzam = model.TanuloIgazolvanyModel.TajSzam;
                co.IsTajSzamNelkul = model.TanuloIgazolvanyModel.IsTajSzamNelkul;
                co.IsAdoazonositoJelNelkul = model.TanuloIgazolvanyModel.IsAdoazonositoJelNelkul;
                co.NemzetkoziBiztositasiOkmanySzama = model.TanuloIgazolvanyModel.NemzetkoziBiztositasiOkmanySzama;
            }

            /*tanuloTanugyModel*/
            if (model.TanuloTanugyModel != null)
            {
                co.TantervId = model.TanuloTanugyModel.TantervId ?? default(int);
                co.NaploSorszam = model.TanuloTanugyModel.NaploSorszam;
                co.BizonyitvanySorszama = model.TanuloTanugyModel.BizonyitvanySorszama;
                co.NyilvantartasiSzam = model.TanuloTanugyModel.NyilvantartasiSzam;
                co.BeirasiSorszam = model.TanuloTanugyModel.BeirasiSorszam;
                co.FelvetelTaneveId = model.TanuloTanugyModel.FelvetelTaneveId ?? default(int);
                co.NyilvantartastartasKezdete = model.TanuloTanugyModel.NyilvantartastartasKezdete ?? default(DateTime);
                co.IsESL16EvesUtanBelepett = model.TanuloTanugyModel.IsESL16EvesUtanBelepett;
                co.JogviszonyBefejezese = model.TanuloTanugyModel.JogviszonyBefejezese;
                co.JogviszonySzuneteltetese = model.TanuloTanugyModel.JogviszonySzuneteltetese;
                co.TankotelezettsegetTeljesito = model.TanuloTanugyModel.TankotelezettsegetTeljesito;
                co.TankotelezettsegVege = model.TanuloTanugyModel.TankotelezettsegVege;
                co.Bejaro = model.TanuloTanugyModel.Bejaro;
                co.SzakmaiGyakorlaton = model.TanuloTanugyModel.SzakmaiGyakorlaton;
                co.Magantanulo = model.TanuloTanugyModel.Magantanulo;
                co.MagantanulosagOka = model.TanuloTanugyModel.MagantanulosagOka;
                co.MagantanulosagKezdete = model.TanuloTanugyModel.MagantanulosagKezdete;
                co.MagantanulosagVege = model.TanuloTanugyModel.MagantanulosagVege;
                co.Vendeg = model.TanuloTanugyModel.Vendeg;
                co.TandijatFizeto = model.TanuloTanugyModel.TandijatFizeto;
                co.TeritestFizeto = model.TanuloTanugyModel.TeritestFizeto;
                co.Tanuloszerzodeses = model.TanuloTanugyModel.Tanuloszerzodeses;
                co.PolgariSzerzodeses = model.TanuloTanugyModel.PolgariSzerzodeses;
                co.DiaksportkorTag = model.TanuloTanugyModel.DiaksportkorTag;
                co.Evismetlo = model.TanuloTanugyModel.Evismetlo;
                co.ElozoIntezmeny = model.TanuloTanugyModel.ElozoIntezmeny;
                co.SzakmacsoportId = model.TanuloTanugyModel.SzakmacsoportId;
                co.AgazatId = model.TanuloTanugyModel.AgazatId;
                co.SzakkepesitesId = model.TanuloTanugyModel.SzakkepesitesId;
                co.ReszSzakkepesitesId = model.TanuloTanugyModel.ReszSzakkepesitesId;
                co.AgazatUjSzktTipusId = model.TanuloTanugyModel.AgazatUjSzktTipusId ??(int)AgazatUjSzktTipusEnum.na;
                co.SzakmaTipusId = model.TanuloTanugyModel.SzakmaTipusId ?? (int)SzakmaTipusEnum.na;
                co.SzakmairanyTipusId = model.TanuloTanugyModel.SzakmairanyTipusId ?? (int)SzakmairanyTipusEnum.na;
                co.SZKTV = model.TanuloTanugyModel.SZKTV;
                co.SZETV = model.TanuloTanugyModel.SZETV;
                co.OSZTV = model.TanuloTanugyModel.OSZTV;
                co.EgyebOrszagosDonto = model.TanuloTanugyModel.EgyebOrszagosDonto;
                co.GyakorlatiSzintvizsgakAtlaga = model.TanuloTanugyModel.GyakorlatiSzintvizsgakAtlaga;
                co.TechnikusiEvfolyam = model.TanuloTanugyModel.TechnikusiEvfolyam;
                co.EgyuttmukodesiMegallapodasos = model.TanuloTanugyModel.EgyuttmukodesiMegallapodasos;
                co.KizarolagIskolaiKeretekKozott = model.TanuloTanugyModel.KizarolagIskolaiKeretekKozott;
                co.TanuloEvfolyamTipus = model.TanuloTanugyModel.TanuloEvfolyamTipus;
                co.OsztalyId = model.TanuloTanugyModel.OsztalyId;
                co.IsSzakmaiGyakorlatHiany = model.TanuloTanugyModel.IsSzakmaiGyakorlatHiany;
                co.TanterviJellemzoId = model.TanuloTanugyModel.TanterviJellemzoId;
                co.OsztalyEvfolyamTipus = model.TanuloTanugyModel.OsztalyEvfolyamTipus;
                co.IsOsszevontOsztaly = model.TanuloTanugyModel.IsOsszevontOsztaly;
                co.AgazatAlapOktMegnevTipusId = model.TanuloTanugyModel.AgazatAlapOktMegnevTipusId;
                co.AgazatAlapVizsgaEredTipusId = model.TanuloTanugyModel.AgazatAlapVizsgaEredTipusId;
                co.AgazatiAlapvizsgaDatuma = model.TanuloTanugyModel.AgazatiAlapvizsgaDatuma;
                co.AgazatiAlapvizsgaEredmenye = model.TanuloTanugyModel.AgazatiAlapvizsgaEredmenye;
                co.AgazatiAlapvizsgaEredmenyeSzazalek = model.TanuloTanugyModel.AgazatiAlapvizsgaEredmenyeSzazalek;
                co.IsSzakkepzesiMunkaszerzodessel = model.TanuloTanugyModel.IsSzakkepzesiMunkaszerzodessel;
                co.DualisKepzohelyNeve = model.TanuloTanugyModel.DualisKepzohelyNeve;
                co.DualisKepzohelyAdoszama = model.TanuloTanugyModel.DualisKepzohelyAdoszama;
                co.SzervezetId = model.TanuloTanugyModel.IsSzakkepzesiMunkaszerzodessel ? model.TanuloTanugyModel.TanuloSzervezetId : null;
                co.SzakiranyNktTipusId = model.TanuloTanugyModel.SzakiranyNktTipusId;
                co.SzakkepesitesNktTipusId = model.TanuloTanugyModel.SzakkepesitesNktTipusId;
                co.TanulmanyiTeruletNktTipusId = model.TanuloTanugyModel.TanulmanyiTeruletNktTipusId;
                co.Is9kozul8ElozotanevbenVegezte = model.TanuloTanugyModel.Is9kozul8ElozotanevbenVegezte;
                co.IsKiemeltenTehetseges = model.TanuloTanugyModel.IsKiemeltenTehetseges;
                co.IsSzamitogepetOktCelraHasznal = model.TanuloTanugyModel.IsSzamitogepetOktCelraHasznal;
                co.IsSzabokyAdolfSzakkepODReszesul = model.TanuloTanugyModel.IsSzabokyAdolfSzakkepODReszesul;
                co.IsEgesznaposIskOktReszesul = model.TanuloTanugyModel.IsEgesznaposIskOktReszesul;
                co.TanterviJellegId = model.TanuloTanugyModel.TanterviJellegId;
                co.AgazatReszSzakmaTipusId = model.TanuloTanugyModel.AgazatReszSzakmaTipusId;
                co.ReszSzakmaTipusId = model.TanuloTanugyModel.ReszSzakmaTipusId;
                co.SzakmaReszSzakmaTipusId = model.TanuloTanugyModel.SzakmaReszSzakmaTipusId;
                co.IsSzakkepzesenKivulrolJott = model.TanuloTanugyModel.IsSzakkepzesenKivulrolJott;
                if ((model.TanuloTanugyModel.SzakkepzesiMunkaszerzodesModels?.Count ?? 0) > 0)
                {
                    co.SzakkepzesiMunkaszerzodesList = model.TanuloTanugyModel.SzakkepzesiMunkaszerzodesModels.Select(x => new SzakkepzesiMunkaszerzodesItemCo
                    {
                        Id = SDAConvert.ToInt32(x.ID),
                        Kezdete = x.Kezdete,
                        Vege = x.Vege.HasValue ? x.Vege.Value.AddHours(23).AddMinutes(59).AddSeconds(59) : x.Vege,
                        SzervezetId = x.NewModifySzakkepzesiMunkaszerzodesSzervezetId,
                        Status = x.GridRowStatus,
                    }).ToList();
                }
            }

            if (model.AmiKepzesiJellemzokModel != null)
            {
                co.MuveszetiAgId = model.AmiKepzesiJellemzokModel.MuveszetiAgId;
                co.MufajTipusId = model.AmiKepzesiJellemzokModel.MufajTipusId;
                co.TanszakTipusId = model.AmiKepzesiJellemzokModel.TanszakTipusId;
            }

            /*tanuloSzocialisModel*/
            if (model.TanuloSzocialisModel != null)
            {
                co.IngyenesTankonyvEllatas = model.TanuloSzocialisModel.IngyenesTankonyvEllatas;
                co.SzocialisTamogatas = model.TanuloSzocialisModel.SzocialisTamogatas;
                co.TestnevelesTipusa = model.TanuloSzocialisModel.TestnevelesTipusa;
                co.KollegiumiEllatasu = model.TanuloSzocialisModel.KollegiumiEllatasu;
                co.EtkezesiKedvezmeny = model.TanuloSzocialisModel.EtkezesiKedvezmeny;
                co.IntezetiNevelt = model.TanuloSzocialisModel.IntezetiNevelt;
                co.HatranyosHelyzet = model.TanuloSzocialisModel.HatranyosHelyzet;
                co.Veszelyeztetett = model.TanuloSzocialisModel.Veszelyeztetett;
                co.TartosGyogykezelesSzama = model.TanuloSzocialisModel.TartosGyogykezelesSzama;
                co.BeilleszkedesiNehezseg = model.TanuloSzocialisModel.BeilleszkedesiNehezseg;
                co.RendszeresGyermekvedelmiKedvezmeny = model.TanuloSzocialisModel.RendszeresGyermekvedelmiKedvezmeny;
                co.TanuloiJogviszonnyalEltartott = model.TanuloSzocialisModel.TanuloiJogviszonnyalEltartott;
                co.TobbGyermnekIgazolasSzama = model.TanuloSzocialisModel.TobbGyermnekIgazolasSzama;
                co.SzakkepesitesenekSzama = model.TanuloSzocialisModel.SzakkepesitesenekSzama;
                co.MenedekJoggalRendelkezo = model.TanuloSzocialisModel.MenedekJoggalRendelkezo;
                co.IsExternatusiEllatasban = model.TanuloSzocialisModel.IsExternatusiEllatasban;
                co.IsNapkoziotthoniEllatasban = model.TanuloSzocialisModel.IsNapkoziotthoniEllatasban;
                co.IsRendszeresGyermekvedelmi = model.TanuloSzocialisModel.IsRendszeresGyermekvedelmi;
                co.IsOtthonNyujtottEllatas = model.TanuloSzocialisModel.IsOtthonNyujtottEllatas;
            }

            /*tanuloSajatosAdatModel*/
            if (model.TanuloSajatosAdatModel != null)
            {
                co.SajatosNevelesiIgenyu = model.TanuloSajatosAdatModel.SajatosNevelesu;
                co.TanuloSniId = model.TanuloSajatosAdatModel.TanuloSniId;
                if (model.TanuloSajatosAdatModel.SajatosNevelesu)
                {
                    //    co.HalmozottanFogyatekos = model.TanuloSajatosAdatModel.HalmozottanFogyatekos;
                    co.SNILetszamsuly = model.TanuloSajatosAdatModel.TanuloLetszamSulyozasa;
                    //    co.ErtelmiFogyatekos = model.TanuloSajatosAdatModel.ErtelmiFogyatekos;
                    //    co.Hallasserult = model.TanuloSajatosAdatModel.Hallasserult;
                    //    co.Latasserult = model.TanuloSajatosAdatModel.Latasserult;
                    //    co.ErtelmiFogyatekosOkamnyszam = model.TanuloSajatosAdatModel.ErtelmiFogyatekosOkmanySzam;
                    //    co.HallasserultOkmanyszam = model.TanuloSajatosAdatModel.HallasserultOkmanySzam;
                    //    co.LatasserultOkmanyszam = model.TanuloSajatosAdatModel.LatasserultOkmanySzam;
                    //    co.MozgasserultOkmanyszam = model.TanuloSajatosAdatModel.MozgasserultOkmanySzam;
                    //    co.BeszedfogyatekosOkmanyszam = model.TanuloSajatosAdatModel.BeszedfogyatekosOkmanySzam;
                    //    co.Diszlexia = model.TanuloSajatosAdatModel.Diszlexia;
                    //    co.Diszkalkulia = model.TanuloSajatosAdatModel.Diszkalkulia;
                    //    co.Diszgrafia = model.TanuloSajatosAdatModel.Diszgrafia;
                    //    co.DiszlexiaOkmanyszam = model.TanuloSajatosAdatModel.DiszlexiaOkmanySzam;
                    //    co.DiszkalkuliaOkmanyszam = model.TanuloSajatosAdatModel.DiszkalkuliaOkmanySzam;
                    //    co.DiszgrafiaOkmanyszam = model.TanuloSajatosAdatModel.DiszgrafiaOkmanySzam;
                    //    co.ViselekdesVisszavezetheto = model.TanuloSajatosAdatModel.ViselkedesOkmanySzam;
                    //    co.ViselekdesNemVisszavezetheto = model.TanuloSajatosAdatModel.ViselkedesNemOkmanySzam;
                    //    co.MegismeroFunkcioVisszavezetheto = model.TanuloSajatosAdatModel.MegismeroFunkciokOkmanySzam;
                    //    co.MegismeroFunkcioNemVisszavezetheto = model.TanuloSajatosAdatModel.MegismeroFunkciokNemOkmanySzam;
                    //    co.BNOKod = model.TanuloSajatosAdatModel.BNOKod;
                    //    co.SNIMeghatarozas = model.TanuloSajatosAdatModel.Meghatarozas;
                    //    co.SNIKiallitoIntezmeny = model.TanuloSajatosAdatModel.KiallitoIntezmeny;
                    //    co.SNIOkmanyErvenyessegKezdete = model.TanuloSajatosAdatModel.OkmanyErvenyessegKezdete;
                    //    co.SNIOkmanyErvenyessegVege = model.TanuloSajatosAdatModel.OkmanyErvenyessegVege;
                    //    co.SNIKontrollIdopontja = model.TanuloSajatosAdatModel.SzuksegesKontrollIdopontja;
                    //    co.FejlesztesreForditandoOraszam = model.TanuloSajatosAdatModel.FejlesztesreForditandoOraszam;
                    //    co.FejlesztoFoglalkozas = model.TanuloSajatosAdatModel.FejlesztoFoglalkozas;
                    //    co.FejlesztesreKijelolt = model.TanuloSajatosAdatModel.FejlesztesreKijelolt;
                    co.KiallitoSzakertoiBizottsagNeve = model.TanuloSajatosAdatModel.KiallitoSzakertoiBizottsagNeve;
                    co.KiallitoSzakertoiBizottsagCime = model.TanuloSajatosAdatModel.KiallitoSzakertoiBizottsagCime;
                    co.SzakvelemenySzama = model.TanuloSajatosAdatModel.SzakvelemenySzama;
                    co.KiallitasDatuma = model.TanuloSajatosAdatModel.KiallitasDatuma;
                    co.FelulvizsgalatTaneve = model.TanuloSajatosAdatModel.FelulvizsgalatTaneve;
                    co.FogyatekossagTipusId = model.TanuloSajatosAdatModel.FogyatekossagTipusId;
                }
                else
                {
                    //    co.HalmozottanFogyatekos = default(bool);
                    co.SNILetszamsuly = default(int?);
                    //    co.ErtelmiFogyatekos = default(int?);
                    //    co.Hallasserult = default(int?);
                    //    co.Latasserult = default(int?);
                    //    co.ErtelmiFogyatekosOkamnyszam = default(string);
                    //    co.HallasserultOkmanyszam = default(string);
                    //    co.LatasserultOkmanyszam = default(string);
                    //    co.MozgasserultOkmanyszam = default(string);
                    //    co.BeszedfogyatekosOkmanyszam = default(string);
                    //    co.Diszlexia = default(bool);
                    //    co.Diszkalkulia = default(bool);
                    //    co.Diszgrafia = default(bool);
                    //    co.DiszlexiaOkmanyszam = default(string);
                    //    co.DiszkalkuliaOkmanyszam = default(string);
                    //    co.DiszgrafiaOkmanyszam = default(string);
                    //    co.ViselekdesVisszavezetheto = default(string);
                    //    co.ViselekdesNemVisszavezetheto = default(string);
                    //    co.MegismeroFunkcioVisszavezetheto = default(string);
                    //    co.MegismeroFunkcioNemVisszavezetheto = default(string);
                    //    co.BNOKod = default(string);
                    //    co.SNIMeghatarozas = default(string);
                    //    co.SNIKiallitoIntezmeny = default(string);
                    //    co.SNIOkmanyErvenyessegKezdete = default(DateTime?);
                    //    co.SNIOkmanyErvenyessegVege = default(DateTime?);
                    //    co.SNIKontrollIdopontja = default(DateTime?);
                    //    co.FejlesztesreForditandoOraszam = default(int?);
                    //    co.FejlesztoFoglalkozas = default(string);
                    //    co.FejlesztesreKijelolt = default(string);
                }
            }

            /*tanuloBTMProblemakModel*/
            if (model.TanuloBTMProblemakModel != null)
            {
                co.BTMProblema = model.TanuloBTMProblemakModel.BTMProblema;
                //if (model.TanuloBTMProblemakModel.BTMProblema)
                //{
                //    co.BTMLetszamsuly = model.TanuloBTMProblemakModel.TanuloLetszamSulyozasa;
                //    co.BeilleszkedesiProblema = model.TanuloBTMProblemakModel.BeilleszkedesiProblemavalKuzd;
                //    co.TanulasiProblema = model.TanuloBTMProblemakModel.TanulasiProblemavalKuzd;
                //    co.BTMDiszgrafia = model.TanuloBTMProblemakModel.Diszgrafia;
                //    co.BTMDiszlexia = model.TanuloBTMProblemakModel.Diszlexia;
                //    co.BTMDiszkalkulia = model.TanuloBTMProblemakModel.Diszkalkulia;
                //    co.MagatartasiProblema = model.TanuloBTMProblemakModel.MagatartasiProblemavalKuzd;
                //    co.BTMHatarozatOkmanyszama = model.TanuloBTMProblemakModel.BTMHatarozatOkmanySzam;
                //    co.BTMKiallitoIntezmeny = model.TanuloBTMProblemakModel.KiallitoIntezmeny;
                //    co.BTMOkmanyErvenyessegKezdete = model.TanuloBTMProblemakModel.OkmanyErvenyessegKezdete;
                //    co.BTMOkmanyErvenyessegVege = model.TanuloBTMProblemakModel.OkmanyErvenyessegVege;
                //    co.BTMKontrollIdopont = model.TanuloBTMProblemakModel.KontrolIdopontja;
                //    co.BTMHatarozatTartalma = model.TanuloBTMProblemakModel.HatarozatTartalma;
                //}
                //else
                //{
                //    co.BTMLetszamsuly = default(int?);
                //    co.BeilleszkedesiProblema = default(bool);
                //    co.TanulasiProblema = default(bool);
                //    co.BTMDiszgrafia = default(bool);
                //    co.BTMDiszlexia = default(bool);
                //    co.BTMDiszkalkulia = default(bool);
                //    co.MagatartasiProblema = default(bool);
                //    co.BTMHatarozatOkmanyszama = default(string);
                //    co.BTMKiallitoIntezmeny = default(string);
                //    co.BTMOkmanyErvenyessegKezdete = default(DateTime?);
                //    co.BTMOkmanyErvenyessegVege = default(DateTime?);
                //    co.BTMKontrollIdopont = default(DateTime?);
                //    co.BTMHatarozatTartalma = default(string);
                //}
            }

            /*tanuloVallasModel*/
            if (model.TanuloVallasModel != null)
            {
                co.Vallasa = model.TanuloVallasModel.Vallasa;
                co.Egyhazkozossege = model.TanuloVallasModel.Egyhazkozosseg;
            }

            /*tanuloSportModel*/
            if (model.TanuloSportModel != null)
            {
                co.Sportag = model.TanuloSportModel.Sportag;
                co.SportedzoElerhetoseg = model.TanuloSportModel.SportedzoNeve;
                co.Sportklub = model.TanuloSportModel.SportKlub;
            }

            if (model.TanuloJuttatasModel != null)
            {
                co.BankszamlaSzam = model.TanuloJuttatasModel.Bankszamlaszam;
                co.Jogviszony = model.TanuloJuttatasModel.Jogviszony;
                co.BankszamlaTulajdonos = model.TanuloJuttatasModel.BankszamlaTulajdonos;
                co.BankszamlaTulajdonosNeve = model.TanuloJuttatasModel.BankszamlaTulajdonosNeve;
                co.IsMasodikVagyTobbedikSzakmatSzerzo = model.TanuloJuttatasModel.IsMasodikVagyTobbedikSzakmatSzerzo;
                co.KeziAtlag = model.TanuloJuttatasModel.KeziAtlag;
                co.IsBeszamitasosTanulo = model.TanuloJuttatasModel.IsBeszamitasosTanulo;
                co.IsSikeresAgazatiVizsga = model.TanuloJuttatasModel.IsSikeresAgazatiVizsga;
                co.IsAtlagSzakkepzesi = model.TanuloJuttatasModel.IsAtlagSzakkepzesi;
                co.IsBeszamitasosFixSzazalek = model.TanuloJuttatasModel.IsBeszamitasosFixSzazalek;
                co.IsApaczaiIgenylo = model.TanuloJuttatasModel.IsApaczaiIgenylo;
                co.IsIngyenesKepzes = model.TanuloJuttatasModel.IsIngyenesKepzes;
                co.IsAtlagNelkuli = model.TanuloJuttatasModel.IsAtlagNelkuli;
            }

            if (model.ApaczaiJuttatasModel != null)
            {
                co.IsApaczaiSzerzodeses = model.ApaczaiJuttatasModel.IsApaczaiSzerzodeses;
                co.MentorId = model.ApaczaiJuttatasModel.MentorId;
            }

            if (model.TanuloSzirBeallitasokModel != null)
            {
                co.IsKuldhetoErettsegiSzRnek = model.TanuloSzirBeallitasokModel.IsKuldhetoErettsegiSzRnek;
                co.IsKuldhetoMeresiSzRnek = model.TanuloSzirBeallitasokModel.IsKuldhetoMeresiSzRnek;
                co.IsKuldhetoKozepFelveteliSzRnek = model.TanuloSzirBeallitasokModel.IsKuldhetoKozepFelveteliSzRnek;
                co.IsDiakigazolvanyAtadhatoSzRnek = model.TanuloSzirBeallitasokModel.IsDiakigazolvanyAtadhatoSzRnek;
            }

            if (model.TanuloUjJogviszonyModel != null)
            {
                co.JogviszonyKezdete = model.TanuloUjJogviszonyModel.JogviszonyKezdete;
                co.JogviszonyTipusa = model.TanuloUjJogviszonyModel.JogviszonyTipusaId;
                co.JogviszonyKeletkezesenekJogcime = model.TanuloUjJogviszonyModel.JogviszonyKeletkezesenekJogcimeId;
                co.JogviszonyMegjegyzes = model.TanuloUjJogviszonyModel.Megjegyzes;
            }

            co.FollowUpolniId = model.FollowUpolniId;
            return co;
        }

        public static TanuloModel ConvertCoToModel(TanuloAdatCO co)
        {
            var model = new TanuloModel();
            model.TanuloId = co.ID;
            model.KozossegiSzolgalatOsszesOraszam = co.KozossegiSzolgalatOsszesOraszam;

            model.TanuloAlapAdatModel = new TanuloAlapAdatModel()
            {
                OktatasiAzonosito = co.OktatasiAzonosito,
                IsOktatasiAzonositoNelkul = co.IsOktatasiAzonositoNelkul,
                Neme = co.Neme,
                CsaladiNev = co.CsaladiNev,
                UtoNev = co.UtoNev,
                Elotag = co.Elotag,
                AnyjaCsaladiNev = co.AnyjaCsaladiNev,
                AnyjaUtoNev = co.AnyjaUtoNev,
                AnyjaNeveElotag = co.AnyjaNeveElotag,
                SzuletesiCsaladiNev = co.SzuletesiCsaladiNev,
                SzuletesiUtoNev = co.SzuletesiUtoNev,
                SzuletesiNevElotag = co.SzuletesiNevElotag,
                SzuletesiHely = co.SzuletesiHely,
                SzuletesiIdo = co.SzuletesiIdo,
                Allampolgarsag = co.Allampolgarsag,
                Allampolgarsag2 = co.Allampolgarsag2,
                TartozkodasJogcimTipusId = co.TartozkodasJogcimTipusId,
                OkiratSzam = co.OkiratSzam,
                Anyanyelv = co.Anyanyelv,
                Megjegyzes = co.Megjegyzes,
                BejelentkezesiNev = co.BelepesiNev,
                Jelszo = co.Jelszo,
                SzuletesiOrszag = co.SzuletesiOrszag,
                TartozkodasiJogotIgazoloOkmanyId = co.TartozkodasiJogotIgazoloOkmanyId,
                TartozkodasiJogotIgazoloOkmanySzama = co.TartozkodasiJogotIgazoloOkmanySzama,
            };

            model.CimElerhetosegModel = new CimElerhetosegModel()
            {
                Orszag = co.Orszag,
                Iranyitoszam_Str = co.Iranyitoszam,
                Iranyitoszam = co.Iranyitoszam,
                HelysegNev = co.HelysegNev,
                HelysegNev_Str = co.HelysegNev,
                KozteruletNev = co.KozteruletNev,
                KozteruletTipus = co.KozteruletTipusNev,
                KozteruletTipus_Str = co.KozteruletTipusNev,
                Hazszam = co.Hazszam,
                Emelet = co.Emelet,
                Ajto = co.Ajto,
                Telefon = co.Telefonszam,
                Emailcim_Input = co.Emailcim
            };

            model.TanuloGondviseloModel = new TanuloGondviseloModel()
            {
                GondviseloNeve = co.GondviseloNeve,
                GondviseloBejelentkezesiNev = co.GondviseloBelepesiNeve,
                RokonsagiFok = co.RokonsagiFok,
                GondviseloJelszo = co.GondviseloJelszava,
                GondviseloAutoEmail = co.GondviseloAutoEmail,
                IsTorvenyesKepviselo = co.IsTorvenyesKepviselo
            };

            model.GondviseloCimElerhetosegModel = new GondviseloCimElerhetosegModel()
            {
                Orszag_Gondviselo = co.OrszagGondviselo,
                Iranyitoszam_Gondviselo_Str = co.IranyitoszamGondviselo,
                HelysegNev_Gondviselo_Str = co.HelysegNevGondviselo,
                KozteruletNev_Gondviselo = co.KozteruletNevGondviselo,
                KozteruletTipus_Gondviselo = co.KozteruletJellegNevGondviselo,
                KozteruletTipus_Gondviselo_Str = co.KozteruletJellegNevGondviselo,
                Hazszam_Gondviselo = co.HazszamGondviselo,
                Emelet_Gondviselo = co.EmeletGondviselo,
                Ajto_Gondviselo = co.AjtoGondviselo,
                Telefon_Gondviselo = co.TelefonszamGondviselo,
                Emailcim_Gondviselo_Input = co.EmailcimGondviselo,
                TelefonTipus_Gondviselo = co.TelefonTipusGondviselo
            };

            model.TanuloIgazolvanyModel = new TanuloIgazolvanyModel()
            {
                AdoazonositoJel = co.AdoazonositoJel,
                //Bankszamlaszam = co.BankszamlaSzam,
                DiakigazolvanyKelte = co.DiakigazolvanyKelte,
                DiakigazolvanySzam = co.DiakigazolvanySzam,
                Igazolvanyszam = co.Igazolvanyszam,
                IgazolvanyTipus = co.IgazolvanyTipus,
                TajSzam = co.TajSzam,
                IsTajSzamNelkul = co.IsTajSzamNelkul,
                IsAdoazonositoJelNelkul = co.IsAdoazonositoJelNelkul,
                NemzetkoziBiztositasiOkmanySzama = co.NemzetkoziBiztositasiOkmanySzama
            };

            model.TanuloTanugyModel = new TanuloTanugyModel
            {
                TantervId = co.TantervId,
                NaploSorszam = co.NaploSorszam,
                BizonyitvanySorszama = co.BizonyitvanySorszama,
                NyilvantartasiSzam = co.NyilvantartasiSzam,
                BeirasiSorszam = co.BeirasiSorszam,
                FelvetelTaneveId = co.FelvetelTaneveId,
                KifirAlapjanImportalt = co.KifirAlapjanImportalt,
                NyilvantartastartasKezdete = co.NyilvantartastartasKezdete,
                JogviszonyBefejezese = co.JogviszonyBefejezese,
                JogviszonySzuneteltetese = co.JogviszonySzuneteltetese,
                TankotelezettsegetTeljesito = co.TankotelezettsegetTeljesito,
                TankotelezettsegVege = co.TankotelezettsegVege,
                Bejaro = co.Bejaro,
                SzakmaiGyakorlaton = co.SzakmaiGyakorlaton,
                Magantanulo = co.Magantanulo,
                MagantanulosagOka = co.MagantanulosagOka,
                MagantanulosagKezdete = co.MagantanulosagKezdete,
                MagantanulosagVege = co.MagantanulosagVege,
                Vendeg = co.Vendeg,
                TandijatFizeto = co.TandijatFizeto,
                TeritestFizeto = co.TeritestFizeto,
                Tanuloszerzodeses = co.Tanuloszerzodeses,
                PolgariSzerzodeses = co.PolgariSzerzodeses,
                DiaksportkorTag = co.DiaksportkorTag,
                Evismetlo = co.Evismetlo,
                ElozoIntezmeny = co.ElozoIntezmeny,
                SzakmacsoportId = co.SzakmacsoportId,
                AgazatId = co.AgazatId,
                SzakkepesitesId = co.SzakkepesitesId,
                ReszSzakkepesitesId = co.ReszSzakkepesitesId,
                AgazatUjSzktTipusId = co.AgazatUjSzktTipusId,
                SzakmaTipusId = co.SzakmaTipusId,
                SzakmairanyTipusId = co.SzakmairanyTipusId,
                SZKTV = co.SZKTV,
                SZETV = co.SZETV,
                OSZTV = co.OSZTV,
                EgyebOrszagosDonto = co.EgyebOrszagosDonto,
                GyakorlatiSzintvizsgakAtlaga = co.GyakorlatiSzintvizsgakAtlaga,
                TechnikusiEvfolyam = co.TechnikusiEvfolyam,
                EgyuttmukodesiMegallapodasos = co.EgyuttmukodesiMegallapodasos,
                KizarolagIskolaiKeretekKozott = co.KizarolagIskolaiKeretekKozott,
                IsOsszevontOsztaly = co.IsOsszevontOsztaly,
                TanuloEvfolyamTipus = co.TanuloEvfolyamTipus,
                OsztalyEvfolyamTipus = co.OsztalyEvfolyamTipus,
                OsztalyNev = co.OsztalyNev,
                OsztalyId = co.OsztalyId,
                IsSzakmaiGyakorlatHiany = co.IsSzakmaiGyakorlatHiany,
                HasAktivOsztalybaSorolas = co.ID.HasValue && new TanuloHelper(ConnectionTypeExtensions.GetSessionConnectionType()).HasTanuloAktivOsztalybaSorolas(co.ID.Value),
                IsESL16EvesUtanBelepett = co.IsESL16EvesUtanBelepett,
                TanterviJellemzoId = co.TanterviJellemzoId,
                AgazatAlapOktMegnevTipusId = co.AgazatAlapOktMegnevTipusId,
                AgazatAlapVizsgaEredTipusId = co.AgazatAlapVizsgaEredTipusId,
                AgazatiAlapvizsgaDatuma = co.AgazatiAlapvizsgaDatuma,
                AgazatiAlapvizsgaEredmenye = co.AgazatiAlapvizsgaEredmenye,
                AgazatiAlapvizsgaEredmenyeSzazalek = co.AgazatiAlapvizsgaEredmenyeSzazalek,
                IsSzakkepzesiMunkaszerzodessel = co.IsSzakkepzesiMunkaszerzodessel,
                DualisKepzohelyNeve = co.DualisKepzohelyNeve,
                DualisKepzohelyAdoszama = co.DualisKepzohelyAdoszama,
                TanuloSzervezetId = co.SzervezetId,
                SzakiranyNktTipusId = co.SzakiranyNktTipusId,
                SzakkepesitesNktTipusId = co.SzakkepesitesNktTipusId,
                TanulmanyiTeruletNktTipusId = co.TanulmanyiTeruletNktTipusId,
                IsNKTSzakkepzeses = co.IsNKTSzakkepzeses,
                Is9kozul8ElozotanevbenVegezte = co.Is9kozul8ElozotanevbenVegezte,
                IsKiemeltenTehetseges = co.IsKiemeltenTehetseges,
                IsSzamitogepetOktCelraHasznal = co.IsSzamitogepetOktCelraHasznal,
                IsSzabokyAdolfSzakkepODReszesul = co.IsSzabokyAdolfSzakkepODReszesul,
                IsEgesznaposIskOktReszesul = co.IsEgesznaposIskOktReszesul,
                TanterviJellegId = co.TanterviJellegId,
                AgazatReszSzakmaTipusId = co.AgazatReszSzakmaTipusId,
                ReszSzakmaTipusId = co.ReszSzakmaTipusId,
                SzakmaReszSzakmaTipusId = co.SzakmaReszSzakmaTipusId,
                IsSzakkepzesenKivulrolJott = co.IsSzakkepzesenKivulrolJott
            };

            model.AmiKepzesiJellemzokModel = new AmiKepzesiJellemzokModelForTanulo
            {
                MuveszetiAgId = co.MuveszetiAgId,
                MufajTipusId = co.MufajTipusId,
                TanszakTipusId = co.TanszakTipusId
            };

            model.TanuloSzocialisModel = new TanuloSzocialisModel()
            {
                IngyenesTankonyvEllatas = co.IngyenesTankonyvEllatas,
                SzocialisTamogatas = co.SzocialisTamogatas,
                TestnevelesTipusa = co.TestnevelesTipusa,
                KollegiumiEllatasu = co.KollegiumiEllatasu,
                EtkezesiKedvezmeny = co.EtkezesiKedvezmeny,
                IntezetiNevelt = co.IntezetiNevelt,
                HatranyosHelyzet = co.HatranyosHelyzet,
                Veszelyeztetett = co.Veszelyeztetett,
                TartosGyogykezelesSzama = co.TartosGyogykezelesSzama,
                BeilleszkedesiNehezseg = co.BeilleszkedesiNehezseg,
                RendszeresGyermekvedelmiKedvezmeny = co.RendszeresGyermekvedelmiKedvezmeny,
                TanuloiJogviszonnyalEltartott = co.TanuloiJogviszonnyalEltartott,
                TobbGyermnekIgazolasSzama = co.TobbGyermnekIgazolasSzama,
                SzakkepesitesenekSzama = co.SzakkepesitesenekSzama,
                MenedekJoggalRendelkezo = co.MenedekJoggalRendelkezo,
                IsExternatusiEllatasban = co.IsExternatusiEllatasban,
                IsNapkoziotthoniEllatasban = co.IsNapkoziotthoniEllatasban,
                IsRendszeresGyermekvedelmi = co.IsRendszeresGyermekvedelmi,
                IsOtthonNyujtottEllatas = co.IsOtthonNyujtottEllatas
            };
            model.TanuloSajatosAdatModel = new TanuloSajatosAdatModel()
            {
                SajatosNevelesu = co.SajatosNevelesiIgenyu,
                //HalmozottanFogyatekos = co.HalmozottanFogyatekos,
                TanuloLetszamSulyozasa = co.SNILetszamsuly,
                //ErtelmiFogyatekos = co.ErtelmiFogyatekos,
                //Hallasserult = co.Hallasserult,
                //Latasserult = co.Latasserult,
                //ErtelmiFogyatekosOkmanySzam = co.ErtelmiFogyatekosOkamnyszam,
                //HallasserultOkmanySzam = co.HallasserultOkmanyszam,
                //LatasserultOkmanySzam = co.LatasserultOkmanyszam,
                //MozgasserultOkmanySzam = co.MozgasserultOkmanyszam,
                //BeszedfogyatekosOkmanySzam = co.BeszedfogyatekosOkmanyszam,
                //Diszlexia = co.Diszlexia,
                //Diszkalkulia = co.Diszkalkulia,
                //Diszgrafia = co.Diszgrafia,
                //DiszlexiaOkmanySzam = co.DiszlexiaOkmanyszam,
                //DiszkalkuliaOkmanySzam = co.DiszkalkuliaOkmanyszam,
                //DiszgrafiaOkmanySzam = co.DiszgrafiaOkmanyszam,
                //ViselkedesOkmanySzam = co.ViselekdesVisszavezetheto,
                //ViselkedesNemOkmanySzam = co.ViselekdesNemVisszavezetheto,
                //MegismeroFunkciokOkmanySzam = co.MegismeroFunkcioVisszavezetheto,
                //MegismeroFunkciokNemOkmanySzam = co.MegismeroFunkcioNemVisszavezetheto,
                //BNOKod = co.BNOKod,
                //Meghatarozas = co.SNIMeghatarozas,
                //KiallitoIntezmeny = co.SNIKiallitoIntezmeny,
                //OkmanyErvenyessegKezdete = co.SNIOkmanyErvenyessegKezdete,
                //OkmanyErvenyessegVege = co.SNIOkmanyErvenyessegVege,
                //SzuksegesKontrollIdopontja = co.SNIKontrollIdopontja,
                //FejlesztesreForditandoOraszam = co.FejlesztesreForditandoOraszam,
                //FejlesztoFoglalkozas = co.FejlesztoFoglalkozas,
                //FejlesztesreKijelolt = co.FejlesztesreKijelolt
                KiallitoSzakertoiBizottsagNeve = co.KiallitoSzakertoiBizottsagNeve,
                KiallitoSzakertoiBizottsagCime = co.KiallitoSzakertoiBizottsagCime,
                SzakvelemenySzama = co.SzakvelemenySzama,
                KiallitasDatuma = co.KiallitasDatuma,
                FelulvizsgalatTaneve = co.FelulvizsgalatTaneve,
                TanuloSniId = co.TanuloSniId,
                FogyatekossagTipusId = co.FogyatekossagTipusId ?? (int)FogyatekossagTipusEnum.na,
            };

            model.TanuloBTMProblemakModel = new TanuloBTMProblemakModel()
            {
                BTMProblema = co.BTMProblema,
                //TanuloLetszamSulyozasa = co.BTMLetszamsuly,
                //BeilleszkedesiProblemavalKuzd = co.BeilleszkedesiProblema,
                //TanulasiProblemavalKuzd = co.TanulasiProblema,
                //Diszlexia = co.BTMDiszlexia,
                //Diszkalkulia = co.BTMDiszkalkulia,
                //Diszgrafia = co.BTMDiszgrafia,
                //MagatartasiProblemavalKuzd = co.MagatartasiProblema,
                //BTMHatarozatOkmanySzam = co.BTMHatarozatOkmanyszama,
                //KiallitoIntezmeny = co.BTMKiallitoIntezmeny,
                //OkmanyErvenyessegKezdete = co.BTMOkmanyErvenyessegKezdete,
                //OkmanyErvenyessegVege = co.BTMOkmanyErvenyessegVege,
                //KontrolIdopontja = co.BTMKontrollIdopont,
                //HatarozatTartalma = co.BTMHatarozatTartalma
            };

            model.TanuloVallasModel = new TanuloVallasModel()
            {
                Vallasa = co.Vallasa,
                Egyhazkozosseg = co.Egyhazkozossege
            };

            model.TanuloSportModel = new TanuloSportModel()
            {
                Sportag = co.Sportag,
                SportedzoNeve = co.SportedzoElerhetoseg,
                SportKlub = co.Sportklub
            };

            model.TanuloKozszolgModel = new TanuloKozszolgModel()
            {
                TanuloId = co.ID ?? default
            };

            model.ZaradekModel = co.Zaradek.TanuloCsoportId.HasValue ? new ZaradekModel(co.Zaradek.TanuloCsoportId.Value, co.ID.Value) : new ZaradekModel();

            model.GlodalData = new GlodalData()
            {
                isAktivTanev = ClaimData.IsActivTanev,
                isFelhasznalonevGeneralas = ClaimManager.HasPackage(KretaClaimPackages.Adminisztrator.ClaimValue) && SystemSettingFelhasznalonevGeneralas.OktatasiAzonosito != SystemSettingFelhasznalonevGeneralas.Egyeni && ClaimData.IsActivTanev,
                isNewTanulo = !model.TanuloId.HasValue || model.TanuloId.Value == 0
            };

            var tanuloJelszoGeneralas = (SystemSettingJelszoGeneralas)new SystemSettingsHelper(ConnectionTypeExtensions.GetSessionConnectionType()).GetSystemSettingValue<int>(RendszerBeallitasTipusEnum.Tanuloi_jelszavak_generalasa_az_alabbi_ertek_alapjan);
            model.GlodalData.isJelszoGeneralas = ClaimManager.HasPackage(KretaClaimPackages.Adminisztrator.ClaimValue) && tanuloJelszoGeneralas != SystemSettingJelszoGeneralas.Egyeni && ClaimData.IsActivTanev;

            model.TanuloJuttatasModel = new TanuloJuttatasModel()
            {
                SzamitottAtlag = co.SzamitottAtlag,
                KeziAtlag = co.KeziAtlag,
                OsztondijAlapSzazalek = co.OsztondijAlapSzazalek,
                BankszamlaTulajdonos = co.BankszamlaTulajdonos,
                Bankszamlaszam = co.BankszamlaSzam,
                BankszamlaTulajdonosNeve = co.BankszamlaTulajdonosNeve,
                Evismetlo = co.Evismetlo,
                IsMasodikVagyTobbedikSzakmatSzerzo = co.IsMasodikVagyTobbedikSzakmatSzerzo,
                Jogviszony = co.Jogviszony,
                Jogviszony_DNAME = co.Jogviszony.GetDisplayName<JogviszonyTipusEnum>(ClaimData.SelectedTanevID.Value),
                TanuloTAJSzama = co.TajSzam,
                IsJogosult = co.IsJogosult,
                //IsEvvegiJegybol = co.IsEvvegiJegybol,
                IsAtlagFuggoSzazalek = co.IsAtlagFuggoSzazalek,
                IsDualisKepzesbenTanuloszerzodeses = co.Tanuloszerzodeses,
                IsDualisKepzesbenSzakkepzesiMunkaszerzodeses = co.IsSzakkepzesiMunkaszerzodessel,
                IsBeszamitasosTanulo = co.IsBeszamitasosTanulo,
                IsSikeresAgazatiVizsga = co.IsSikeresAgazatiVizsga,
                IsFelevnelValtos = co.IsFelevnelValtos,
                IsAtlagSzakkepzesi = co.IsAtlagSzakkepzesi,
                IsBeszamitasosFixSzazalek = co.IsBeszamitasosFixSzazalek,
                IsApaczaiIgenylo = co.IsApaczaiIgenylo,
                IsApaczaiSzerzodeses = co.IsApaczaiSzerzodeses,
                ElutasitasOkok = string.Join("; ", co.OsztondijElutasitasOkaList),
                IsIngyenesKepzes = co.IsIngyenesKepzes,
                IsAtlagNelkuli = co.IsAtlagNelkuli
            };

            model.ApaczaiJuttatasModel = new ApaczaiJuttatasModel()
            {
                JuttatasModelIdPrefix = "ApaczaiJuttatasModel_",
                JuttatasModelNamePrefix = "ApaczaiJuttatasModel.",
                SzamitottAtlag = co.SzamitottAtlag,
                KeziAtlag = co.KeziAtlag,
                OsztondijAlapSzazalek = co.OsztondijAlapSzazalek,
                BankszamlaTulajdonos = co.BankszamlaTulajdonos,
                Bankszamlaszam = co.BankszamlaSzam,
                BankszamlaTulajdonosNeve = co.BankszamlaTulajdonosNeve,
                Evismetlo = co.Evismetlo,
                IsMasodikVagyTobbedikSzakmatSzerzo = co.IsMasodikVagyTobbedikSzakmatSzerzo,
                Jogviszony = co.Jogviszony,
                Jogviszony_DNAME = co.Jogviszony.GetDisplayName<JogviszonyTipusEnum>(ClaimData.SelectedTanevID.Value),
                TanuloTAJSzama = co.TajSzam,
                IsJogosult = co.IsJogosult,
                //IsEvvegiJegybol = co.IsEvvegiJegybol,
                IsAtlagFuggoSzazalek = co.IsAtlagFuggoSzazalek,
                IsDualisKepzesbenTanuloszerzodeses = co.Tanuloszerzodeses,
                IsDualisKepzesbenSzakkepzesiMunkaszerzodeses = co.IsSzakkepzesiMunkaszerzodessel,
                IsBeszamitasosTanulo = co.IsBeszamitasosTanulo,
                IsSikeresAgazatiVizsga = co.IsSikeresAgazatiVizsga,
                IsFelevnelValtos = co.IsFelevnelValtos,
                IsAtlagSzakkepzesi = co.IsAtlagSzakkepzesi,
                IsBeszamitasosFixSzazalek = co.IsBeszamitasosFixSzazalek,
                IsApaczaiIgenylo = co.IsApaczaiIgenylo,
                IsApaczaiSzerzodeses = co.IsApaczaiSzerzodeses,
                ElutasitasOkok = string.Join("; ", co.OsztondijElutasitasOkaList),
                IsIngyenesKepzes = co.IsIngyenesKepzes,
                IsAtlagNelkuli = co.IsAtlagNelkuli,
                MentorId = co.MentorId
            };

            model.TanuloBankszamlaModel = new TanuloBankszamlaModel()
            {
                BankszamlaSzam = co.BankszamlaSzam,
                BankszamlaTulajdonos = co.BankszamlaTulajdonos,
                BankszamlaTulajdonosNeve = co.BankszamlaTulajdonosNeve,
                SzamlavezetoBank = co.SzamlavezetoBank,
                IsReadonly = true,
            };

            model.TanuloSzirBeallitasokModel = new TanuloSzirBeallitasokModel
            {
                IsKuldhetoErettsegiSzRnek = co.IsKuldhetoErettsegiSzRnek,
                IsKuldhetoMeresiSzRnek = co.IsKuldhetoMeresiSzRnek,
                IsKuldhetoKozepFelveteliSzRnek = co.IsKuldhetoKozepFelveteliSzRnek,
                IsDiakigazolvanyAtadhatoSzRnek = co.IsDiakigazolvanyAtadhatoSzRnek
            };

            model.TanuloEgyszeriPalyakezdesiModel = new EgyszeriPalyakezdesiModel
            {
                Erdemjegy = co.EPJErdemjegy,
                JavitoVizsga = co.IsEPJJavitoVizsga.GetDisplayName(),
                JuttatasSzazalek = co.EPJJuttatasSzazalek,
                PotloVizsga = co.IsEPJPotloVizsga.GetDisplayName(),
                SzakkepesitesAzonosito = co.EPJSzakkepesitesAzonosito,
                SzakkepesitesMegnevezes = co.EPJSzakkepesitesMegnevezes,
                VizsgaDatum = co.EPJVizsgaDatum?.ToString(ToStringPattern.HungarianDateWithSpaces),
                ElutasitasOka = co.EPJElutasitasOka,
                BizonyitvanySzama = co.EPJBizonyitvanySzama,
                ElutasitasOkok = string.Join("; ", co.EPJElutasitasOkaList),
            };

            return model;
        }

        public GlodalData GlodalData { get; set; }
    }

    public class GlodalData
    {
        public bool isAktivTanev { get; set; }
        public bool isFelhasznalonevGeneralas { get; set; }
        public bool isJelszoGeneralas { get; set; }
        public bool isNewTanulo { get; set; }
    }

    public class TanuloAlapAdatModel
    {
        public TanuloAlapAdatModel()
        {
            NemList = TanuloLogic.GetNemList(true);
        }

        public List<SelectListItem> NemList { get; set; }

        [RegularExpression(RegularExpressions.OktatasiAzonositoTanulo, ErrorMessageResourceName = nameof(ErrorResource.OktatasiAzonositoFormatumaNemMegfeleloTanulo), ErrorMessageResourceType = typeof(ErrorResource), MatchTimeoutInMilliseconds = 100)]
        [Display(Name = nameof(TanuloResource.OktatasiAzonosito), ResourceType = typeof(TanuloResource))]
        [RequiredIf(nameof(IsOktatasiAzonositoKotelezo), true, ErrorMessageResourceName = nameof(ErrorResource.OktatasiAzonositoKotelezotanuloAlapadatokFul), ErrorMessageResourceType = typeof(ErrorResource))]
        public string OktatasiAzonosito { get; set; }

        [Display(Name = nameof(TanuloResource.NemRendelkezikOktatasiAzonositoval), ResourceType = typeof(TanuloResource))]
        public bool IsOktatasiAzonositoNelkul { get; set; }

        public bool IsOktatasiAzonositoKotelezo
        {
            get
            {
                if (ClaimData.IsSzakkepzoIntezmeny && IsOktatasiAzonositoNelkul)
                {
                    return false;
                }
                return true;
            }
        }

        [Required(ErrorMessageResourceName = nameof(ErrorResource.NemeKitolteseKotelezotanuloAlapadatokFul), ErrorMessageResourceType = typeof(ErrorResource))]
        [Display(Name = nameof(TanuloResource.Neme), ResourceType = typeof(TanuloResource))]
        public int Neme { get; set; }

        [Required(ErrorMessageResourceName = nameof(ErrorResource.CsaladiNevKitolteseKotelezotanuloAlapadatokFul), ErrorMessageResourceType = typeof(ErrorResource))]
        [StringLength(maximumLength: 255, ErrorMessageResourceName = nameof(ErrorResource.CsaladiNevMaxKaraktertanuloAlapadatokFul), ErrorMessageResourceType = typeof(ErrorResource))]
        [Display(Name = nameof(TanuloResource.CsaladiNeve), ResourceType = typeof(TanuloResource))]
        public string CsaladiNev { get; set; }

        [Required(ErrorMessageResourceName = nameof(ErrorResource.UtonevKitolteseKotelezotanuloAlapadatokFul), ErrorMessageResourceType = typeof(ErrorResource))]
        [StringLength(maximumLength: 255, ErrorMessageResourceName = nameof(ErrorResource.UtonevMaxKaraktertanuloAlapadatokFul), ErrorMessageResourceType = typeof(ErrorResource))]
        [Display(Name = nameof(TanuloResource.UtoNeve), ResourceType = typeof(TanuloResource))]
        public string UtoNev { get; set; }

        [StringLength(maximumLength: 20, ErrorMessageResourceName = nameof(ErrorResource.ElonevMaxKaraktertanuloAlapadatokFul), ErrorMessageResourceType = typeof(ErrorResource))]
        [Display(Name = nameof(TanuloResource.Elotag), ResourceType = typeof(TanuloResource))]
        public string Elotag { get; set; }

        [Required(ErrorMessageResourceName = nameof(ErrorResource.AnyjaCsaladiNevenekKitolteseKotelezotanuloAlapadatokFul), ErrorMessageResourceType = typeof(ErrorResource))]
        [StringLength(maximumLength: 255, ErrorMessageResourceName = nameof(ErrorResource.AnyjaCsaladiNeveMaxKaraktertanuloAlapadatokFul), ErrorMessageResourceType = typeof(ErrorResource))]
        [Display(Name = nameof(TanuloResource.AnyjaCsaladiNev), ResourceType = typeof(TanuloResource))]
        public string AnyjaCsaladiNev { get; set; }

        [Required(ErrorMessageResourceName = nameof(ErrorResource.AnyjaUtoneveKitolteseKotelezotanuloAlapadatokFul), ErrorMessageResourceType = typeof(ErrorResource))]
        [StringLength(maximumLength: 255, ErrorMessageResourceName = nameof(ErrorResource.AnyjaUtoneveMaxKaraktertanuloAlapadatokFul), ErrorMessageResourceType = typeof(ErrorResource))]
        [Display(Name = nameof(TanuloResource.AnyjaUtonev), ResourceType = typeof(TanuloResource))]
        public string AnyjaUtoNev { get; set; }

        [StringLength(maximumLength: 20, ErrorMessageResourceName = nameof(ErrorResource.AnyjaNeveElotagMaxKaraktertanuloAlapadatokFul), ErrorMessageResourceType = typeof(ErrorResource))]
        [Display(Name = nameof(TanuloResource.AnyjaElotag), ResourceType = typeof(TanuloResource))]
        public string AnyjaNeveElotag { get; set; }

        [Required(ErrorMessageResourceName = nameof(ErrorResource.SzuletesiCsaladinevKotelezo), ErrorMessageResourceType = typeof(ErrorResource))]
        [StringLength(maximumLength: 255, ErrorMessageResourceName = nameof(ErrorResource.SzuletesiCsaladiNevMax200Karakter), ErrorMessageResourceType = typeof(ErrorResource))]
        [Display(Name = nameof(TanuloResource.SzuletesiCsaladiNeve), ResourceType = typeof(TanuloResource))]
        public string SzuletesiCsaladiNev { get; set; }

        [Required(ErrorMessageResourceName = nameof(ErrorResource.SzuletesiUtonevKitolteseKotelezotanuloAlapadatokFul), ErrorMessageResourceType = typeof(ErrorResource))]
        [StringLength(maximumLength: 255, ErrorMessageResourceName = nameof(ErrorResource.SzuletesiUtonevMax200Karakter), ErrorMessageResourceType = typeof(ErrorResource))]
        [Display(Name = nameof(TanuloResource.SzuletesiUtoneve), ResourceType = typeof(TanuloResource))]
        public string SzuletesiUtoNev { get; set; }

        [StringLength(maximumLength: 20, ErrorMessageResourceName = nameof(ErrorResource.SzuletesiElotagMaxKaraktertanuloAlapadatokFul), ErrorMessageResourceType = typeof(ErrorResource))]
        [Display(Name = nameof(TanuloResource.SzuletesiElotag), ResourceType = typeof(TanuloResource))]
        public string SzuletesiNevElotag { get; set; }

        [Required(ErrorMessageResourceName = nameof(ErrorResource.SzuletesiHelyKitolteseKotelezotanuloAlapadatokFul), ErrorMessageResourceType = typeof(ErrorResource))]
        [StringLength(maximumLength: 50, ErrorMessageResourceName = nameof(ErrorResource.SzuletesiHelyMax50KaraktertanuloAlapadatokFul), ErrorMessageResourceType = typeof(ErrorResource))]
        [Display(Name = nameof(TanuloResource.SzuletesiHely), ResourceType = typeof(TanuloResource))]
        public string SzuletesiHely { get; set; }

        [Required(ErrorMessageResourceName = nameof(ErrorResource.SzuletesiIdoKitolteseKotelezotanuloAlapadatokFul), ErrorMessageResourceType = typeof(ErrorResource))]
        [Display(Name = nameof(TanuloResource.SzuletesiIdo), ResourceType = typeof(TanuloResource))]
        [DateRange(ErrorMessageResourceName = nameof(ErrorResource.SzuletesiIdoDatumaNemErvenyes), ErrorMessageResourceType = typeof(ErrorResource))]
        public DateTime? SzuletesiIdo { get; set; }

        [Required(ErrorMessageResourceName = nameof(ErrorResource.AllampolgarsagMegadasaKotelezotanuloAlapadatokFul), ErrorMessageResourceType = typeof(ErrorResource))]
        [Display(Name = nameof(TanuloResource.Allampolgarsag), ResourceType = typeof(TanuloResource))]
        public int? Allampolgarsag { get; set; }

        [Required(ErrorMessageResourceName = nameof(ErrorResource.AnyanyelvMegadasaKotelezotanuloAlapadatokFul), ErrorMessageResourceType = typeof(ErrorResource))]
        [Display(Name = nameof(TanuloResource.Anyanyelv), ResourceType = typeof(TanuloResource))]
        public int? Anyanyelv { get; set; }

        [StringLength(2000, ErrorMessageResourceName = nameof(ErrorResource.AMegjegyzesSzovegeNemLehet2000KarakternelHosszabb), ErrorMessageResourceType = typeof(ErrorResource))]
        [Display(Name = nameof(TanuloResource.Megjegyzes), ResourceType = typeof(TanuloResource))]
        public string Megjegyzes { get; set; }

        //[Required(ErrorMessageResourceName = nameof(ErrorResource.FelhasznalonevKitolteseKotelezobelepesiAdatokFul), ErrorMessageResourceType = typeof(ErrorResource))]
        [Display(Name = nameof(TanuloResource.Felhasznalonev), ResourceType = typeof(TanuloResource))]
        [StringLength(maximumLength: 100, ErrorMessageResourceName = nameof(ErrorResource.FelhasznalonevMax100KarakterTanuloBelepesiAdatok), ErrorMessageResourceType = typeof(ErrorResource))]
        public string BejelentkezesiNev { get; set; }

        //[Required(ErrorMessageResourceName = nameof(ErrorResource.JelszoMegadasaKotelezotanuloAlapadatokFul), ErrorMessageResourceType = typeof(ErrorResource))]
        [Display(Name = nameof(TanuloResource.Jelszo), ResourceType = typeof(TanuloResource))]
        [StringLength(General.JelszoMaximumKarakterekSzama, MinimumLength = General.JelszoMinimumKarakterekSzama, ErrorMessageResourceName = nameof(ErrorResource.AJelszonakMin0Max0KarakterbolKellAllnia), ErrorMessageResourceType = typeof(ErrorResource))]
        public string Jelszo { get; set; }

        [System.ComponentModel.DataAnnotations.Compare(otherProperty: @"Jelszo", ErrorMessageResourceName = nameof(ErrorResource.AzIsmeteltJelszoNemEgyezikMegAJelszovaltanuloAlapadatokFul), ErrorMessageResourceType = typeof(ErrorResource))]
        [Display(Name = nameof(TanuloResource.IsmeteltJelszo), ResourceType = typeof(TanuloResource))]
        [StringLength(General.JelszoMaximumKarakterekSzama, MinimumLength = General.JelszoMinimumKarakterekSzama, ErrorMessageResourceName = nameof(ErrorResource.AJelszonakMin0Max0KarakterbolKellAllnia), ErrorMessageResourceType = typeof(ErrorResource))]
        public string Ismeteltjelszo { get; set; }

        [Required(ErrorMessageResourceName = nameof(ErrorResource.SzuletesiOrszagMegadasaKotelezotanuloAlapadatokFul), ErrorMessageResourceType = typeof(ErrorResource))]
        [Display(Name = nameof(TanuloResource.SzuletesiOrszag), ResourceType = typeof(TanuloResource))]
        public int? SzuletesiOrszag { get; set; }

        [Display(Name = nameof(TanuloResource.Allampolgarsag2), ResourceType = typeof(TanuloResource))]
        public int? Allampolgarsag2 { get; set; }

        [Display(Name = nameof(TanuloResource.TartozkodasJogcime), ResourceType = typeof(TanuloResource))]
        public int? TartozkodasJogcimTipusId { get; set; }

        [StringLength(256, ErrorMessageResourceName = nameof(ErrorResource.OkiratSzamaNemLehet256KarakternelHosszabb), ErrorMessageResourceType = typeof(ErrorResource))]
        [Display(Name = nameof(TanuloResource.OkiratSzama), ResourceType = typeof(TanuloResource))]
        public string OkiratSzam { get; set; }

        [Display(Name = nameof(TanuloResource.TartozkodasiJogotIgazoloOkmany), ResourceType = typeof(TanuloResource))]
        public int? TartozkodasiJogotIgazoloOkmanyId { get; set; }

        [StringLength(20, ErrorMessageResourceName = nameof(ErrorResource.TartozkodasiJogotIgazoloOkmanySzamaNemLehet20KarakternelHosszabb), ErrorMessageResourceType = typeof(ErrorResource))]
        [Display(Name = nameof(TanuloResource.TartozkodasiJogotIgazoloOkmanySzama), ResourceType = typeof(TanuloResource))]
        public string TartozkodasiJogotIgazoloOkmanySzama { get; set; }

        public FelhasznaloiNevGeneralasModjaEnum FelhasznaloiNevGeneralasModja { get; set; }
    }

    public class TanuloGondviseloModel
    {
        public int? Id { get; set; }

        public int TanuloId { get; set; }

        [StringLength(maximumLength: 200, ErrorMessageResourceName = nameof(ErrorResource.GondviseloNeveMax200KaraktergondviseloAdataiFul), ErrorMessageResourceType = typeof(ErrorResource))]
        [Display(Name = nameof(TanuloResource.GondviseloNeve), ResourceType = typeof(TanuloResource))]
        public string GondviseloNeve { get; set; }

        [StringLength(maximumLength: 100, ErrorMessageResourceName = nameof(ErrorResource.FelhasznalonevMax100Karakter), ErrorMessageResourceType = typeof(ErrorResource))]
        [Display(Name = nameof(TanuloResource.Felhasznalonev), ResourceType = typeof(TanuloResource))]
        public string GondviseloBejelentkezesiNev { get; set; }

        [Display(Name = nameof(TanuloResource.Jelszo), ResourceType = typeof(TanuloResource))]
        [StringLength(General.JelszoMaximumKarakterekSzama, MinimumLength = General.JelszoMinimumKarakterekSzama, ErrorMessageResourceName = nameof(ErrorResource.AJelszonakMin0Max0KarakterbolKellAllnia), ErrorMessageResourceType = typeof(ErrorResource))]
        public string GondviseloJelszo { get; set; }

        [StringLength(General.JelszoMaximumKarakterekSzama, MinimumLength = General.JelszoMinimumKarakterekSzama, ErrorMessageResourceName = nameof(ErrorResource.AJelszonakMin0Max0KarakterbolKellAllnia), ErrorMessageResourceType = typeof(ErrorResource))]
        [System.ComponentModel.DataAnnotations.Compare(otherProperty: @"GondviseloJelszo", ErrorMessageResourceName = nameof(ErrorResource.AzIsmeteltJelszoNemEgyezikMegAJelszovalGondviseloAdataiFul), ErrorMessageResourceType = typeof(ErrorResource))]
        [Display(Name = nameof(TanuloResource.IsmeteltJelszo), ResourceType = typeof(TanuloResource))]
        public string IsmeteltGondviseloJelszo { get; set; }

        [Display(Name = nameof(TanuloResource.RokonsagiFok), ResourceType = typeof(TanuloResource))]
        public int? RokonsagiFok { get; set; }

        [Display(Name = nameof(TanuloResource.BelepesiAdatokKikuldeseEmailben), ResourceType = typeof(TanuloResource))]
        public bool GondviseloAutoEmail { get; set; }

        [Display(Name = nameof(TanuloResource.TorvenyesKepviselo), ResourceType = typeof(TanuloResource))]
        public bool IsTorvenyesKepviselo { get; set; }

        [Display(Name = nameof(TanuloResource.HozzaferesGeneralasEsFajlLetoltes), ResourceType = typeof(TanuloResource))]
        public bool GondviseloBelepesFileLetoltesSzukseges { get; set; }
    }

    public class TanuloIgazolvanyModel
    {
        [StringLength(maximumLength: 50, ErrorMessageResourceName = nameof(ErrorResource.IgazolvanyszamMax50KarakterIgazolvanyokFul), ErrorMessageResourceType = typeof(ErrorResource))]
        [Display(Name = nameof(TanuloResource.IgazolvanySzama), ResourceType = typeof(TanuloResource))]
        public string Igazolvanyszam { get; set; }

        [Display(Name = nameof(TanuloResource.IgazolvanyTipus), ResourceType = typeof(TanuloResource))]
        public int? IgazolvanyTipus { get; set; }

        [StringLength(maximumLength: 50, ErrorMessageResourceName = nameof(ErrorResource.DiakigazolvanyszamMax200KarakterigazolvanyokFul), ErrorMessageResourceType = typeof(ErrorResource))]
        [Display(Name = nameof(TanuloResource.DiakigazolvanySzam), ResourceType = typeof(TanuloResource))]
        public string DiakigazolvanySzam { get; set; }

        [Display(Name = nameof(TanuloResource.DiakigazolvanyKelte), ResourceType = typeof(TanuloResource))]
        public DateTime? DiakigazolvanyKelte { get; set; }

        [StringLength(maximumLength: 9, ErrorMessageResourceName = nameof(ErrorResource.TajSzamMax9KarakterigazolvanyokFul), ErrorMessageResourceType = typeof(ErrorResource))]
        [Display(Name = nameof(TanuloResource.TajSzam), ResourceType = typeof(TanuloResource))]
        public string TajSzam { get; set; }

        [Display(Name = nameof(TanuloResource.NemRendelkezikTajSzammal), ResourceType = typeof(TanuloResource))]
        public bool IsTajSzamNelkul { get; set; }

        [Display(Name = nameof(TanuloResource.NemRendelkezikAdoazonositoJellel), ResourceType = typeof(TanuloResource))]
        public bool IsAdoazonositoJelNelkul { get; set; }

        [StringLength(maximumLength: 50, ErrorMessageResourceName = nameof(ErrorResource.AdoazonositoJelMax10KarakterigazolvanyokFul), ErrorMessageResourceType = typeof(ErrorResource))]
        [Display(Name = nameof(TanuloResource.AdoazonositoJel), ResourceType = typeof(TanuloResource))]
        public string AdoazonositoJel { get; set; }

        [StringLength(maximumLength: 30, ErrorMessageResourceName = nameof(ErrorResource.ANemzetkoziBiztositasiOkmanySzama), ErrorMessageResourceType = typeof(ErrorResource))]
        [Display(Name = nameof(TanuloResource.NemzetkoziBiztositasiOkmanySzama), ResourceType = typeof(TanuloResource))]
        public string NemzetkoziBiztositasiOkmanySzama { get; set; }

    }

    public class TanuloTanugyModel
    {
        string osztalyNev;
        public string OsztalyNev { get { return !string.IsNullOrWhiteSpace(osztalyNev) ? osztalyNev : TanuloResource.Alap; } set { osztalyNev = value; } }
        public int? OsztalyId { get; set; }

        [Required(ErrorMessageResourceName = nameof(ErrorResource.TantervKivalasztasaKotelezotanugyiAdatokFul), ErrorMessageResourceType = typeof(ErrorResource))]
        [Display(Name = nameof(TanuloResource.Tanterv), ResourceType = typeof(TanuloResource))]
        public int? TantervId { get; set; }

        [Required(ErrorMessageResourceName = nameof(ErrorResource.NevelesiTervKivalasztasaKotelezotanugyiAdatokFul), ErrorMessageResourceType = typeof(ErrorResource))]
        [Display(Name = nameof(OsztalyCsoportResource.NevelesiTerv), ResourceType = typeof(OsztalyCsoportResource))]
        public int? NevelesiTervId
        {
            get { return TantervId; }
            set { TantervId = value; }
        }

        [Display(Name = nameof(TanuloResource.NaploSorszam), ResourceType = typeof(TanuloResource))]
        public int? NaploSorszam { get; set; }

        [StringLength(TanuloTanugyiAdatok.BizonyitvanySzamaLength, ErrorMessageResourceName = nameof(ErrorResource.A0NemLehetHosszabb1Karakternel), ErrorMessageResourceType = typeof(ErrorResource))]
        [Display(Name = nameof(TanuloResource.BizonyitvanySorszama), ResourceType = typeof(TanuloResource))]
        public string BizonyitvanySorszama { get; set; }

        [StringLength(maximumLength: 50, ErrorMessageResourceName = nameof(ErrorResource.TorzslapszamNemLehetHosszabb50Karakternel), ErrorMessageResourceType = typeof(ErrorResource))]
        [Display(Name = nameof(TanuloResource.Torzslapszam), ResourceType = typeof(TanuloResource))]
        public string NyilvantartasiSzam { get; set; }

        [Display(Name = nameof(TanuloResource.BeirasiNaploSorszama), ResourceType = typeof(TanuloResource))]
        [StringLength(maximumLength: 100, ErrorMessageResourceName = nameof(ErrorResource.BeirasiSorszamMax100Karakter), ErrorMessageResourceType = typeof(ErrorResource))]
        public string BeirasiSorszam { get; set; }

        [Required(ErrorMessageResourceName = nameof(ErrorResource.TanevKivalasztasaKotelezotanugyiAdatokFul), ErrorMessageResourceType = typeof(ErrorResource))]
        [Display(Name = nameof(TanuloResource.FelvetelTaneve), ResourceType = typeof(TanuloResource))]
        public int? FelvetelTaneveId { get; set; }

        [Display(Name = nameof(TanuloResource.KifirAlapjanImportalt), ResourceType = typeof(TanuloResource))]
        public bool KifirAlapjanImportalt { get; set; }

        public bool IsSzakkepzeses { get; set; }

        public bool IsNKTSzakkepzeses { get; set; }

        public bool HasAktivOsztalybaSorolas { get; set; }

        public bool IsAgazatUjSzktTipusModificationEnabled { get; set; }
        public bool IsSzakmaTipusModificationEnabled { get; set; }
        public bool IsSzakmairanyTipusModificationEnabled { get; set; }
        public bool IsSzakmacsoportModificationEnabled { get; set; }
        public bool IsAgazatModificationEnabled { get; set; }
        public bool IsSzakkepesitesModificationEnabled { get; set; }
        public bool IsReszSzakkepesitesModificationEnabled { get; set; }

        public bool IsTanulmanyiTeruletNktTipusModificationEnabled { get; set; }
        public bool IsSzakkepesitesNktTipusModificationEnabled { get; set; }
        public bool IsSzakiranyNktTipusModificationEnabled { get; set; }
        public bool IsAgazatReszSzakmaTipusModificationEnabled { get; set; }
        public bool IsSzakmaReszSzakmaTipusModificationEnabled { get; set; }
        public bool IsReszSzakmaTipusModificationEnabled { get; set; }

        [Display(Name = nameof(TanuloResource.Szakmacsoport), ResourceType = typeof(TanuloResource))]
        public int? SzakmacsoportId { get; set; }

        [Display(Name = nameof(TanuloResource.Agazat), ResourceType = typeof(TanuloResource))]
        public int? AgazatId { get; set; }

        [Display(Name = nameof(TanuloResource.Szakkepesites), ResourceType = typeof(TanuloResource))]
        public int? SzakkepesitesId { get; set; }

        [Display(Name = nameof(TanuloResource.ReszSzakkepesites), ResourceType = typeof(TanuloResource))]
        public int? ReszSzakkepesitesId { get; set; }

        [Display(Name = nameof(OsztalyCsoportResource.Agazat), ResourceType = typeof(OsztalyCsoportResource))]
        public int? AgazatUjSzktTipusId { get; set; }

        [Display(Name = nameof(OsztalyCsoportResource.Szakma), ResourceType = typeof(OsztalyCsoportResource))]
        public int? SzakmaTipusId { get; set; }

        [Display(Name = nameof(OsztalyCsoportResource.Szakmairany), ResourceType = typeof(OsztalyCsoportResource))]
        public int? SzakmairanyTipusId { get; set; }

        [Display(Name = nameof(TanuloResource.JogviszonyKezdete), ResourceType = typeof(TanuloResource))]
        public DateTime? NyilvantartastartasKezdete { get; set; }

        [Display(Name = nameof(OsztalyCsoportResource.IsESL16EvesUtanBelepett), ResourceType = typeof(OsztalyCsoportResource))]
        public bool IsESL16EvesUtanBelepett { get; set; }

        [Display(Name = nameof(TanuloResource.JogviszonyVarhatoBefejezese), ResourceType = typeof(TanuloResource))]
        public DateTime? JogviszonyBefejezese { get; set; }

        [Display(Name = nameof(TanuloResource.JogviszonySzunteteltetese), ResourceType = typeof(TanuloResource))]
        public bool JogviszonySzuneteltetese { get; set; }

        [Display(Name = nameof(TanuloResource.TankotelezettsegetTeljesito), ResourceType = typeof(TanuloResource))]
        public bool TankotelezettsegetTeljesito { get; set; }

        [Display(Name = nameof(TanuloResource.TankotelezettsegVege), ResourceType = typeof(TanuloResource))]
        public DateTime? TankotelezettsegVege { get; set; }

        [Display(Name = nameof(TanuloResource.Bejaro), ResourceType = typeof(TanuloResource))]
        public bool Bejaro { get; set; }

        [Display(Name = nameof(TanuloResource.SzakmaiGyakorlatonTartozkodik), ResourceType = typeof(TanuloResource))]
        public bool SzakmaiGyakorlaton { get; set; }

        [Display(Name = nameof(TanuloResource.Magantanulo), ResourceType = typeof(TanuloResource))]
        public bool Magantanulo { get; set; }

        [Display(Name = nameof(TanuloResource.MagantanulosagOka), ResourceType = typeof(TanuloResource))]
        public int? MagantanulosagOka { get; set; }

        [RequiredIf("Magantanulo", true, ErrorMessageResourceName = nameof(TanuloResource.EgyeniMunkarendKezdetenekMegadasaKotelezotanugyiAdatokFul), ErrorMessageResourceType = typeof(TanuloResource))]
        [Display(Name = nameof(TanuloResource.MagantanulosagKezdete), ResourceType = typeof(TanuloResource))]
        public DateTime? MagantanulosagKezdete { get; set; }

        [Display(Name = nameof(TanuloResource.EgyeniMunkarendVege), ResourceType = typeof(TanuloResource))]
        public DateTime? MagantanulosagVege { get; set; }

        [Display(Name = nameof(TanuloResource.Vendegtanulo), ResourceType = typeof(TanuloResource))]
        public bool Vendeg { get; set; }

        [Display(Name = nameof(TanuloResource.TandijatFizeto), ResourceType = typeof(TanuloResource))]
        public bool TandijatFizeto { get; set; }

        [Display(Name = nameof(TanuloResource.TeritesiDijatFizeto), ResourceType = typeof(TanuloResource))]
        public bool TeritestFizeto { get; set; }

        [Display(Name = nameof(TanuloResource.Tanuloszerzodeses), ResourceType = typeof(TanuloResource))]
        public bool Tanuloszerzodeses { get; set; }

        [Display(Name = nameof(TanuloResource.PolgariSzerzodeses), ResourceType = typeof(TanuloResource))]
        public bool PolgariSzerzodeses { get; set; }

        [Display(Name = nameof(TanuloResource.DiaksportkorTagja), ResourceType = typeof(TanuloResource))]
        public bool DiaksportkorTag { get; set; }

        [Display(Name = nameof(TanuloResource.Evismetlo), ResourceType = typeof(TanuloResource))]
        public bool Evismetlo { get; set; }

        [Display(Name = nameof(TanuloResource.ElozoIntezmeny), ResourceType = typeof(TanuloResource))]
        [StringLength(maximumLength: 255, ErrorMessageResourceName = nameof(ErrorResource.ElozoIntezmenyMax255Karakter), ErrorMessageResourceType = typeof(ErrorResource))]
        public string ElozoIntezmeny { get; set; }

        [Display(Name = nameof(TanuloResource.Szktv), ResourceType = typeof(TanuloResource))]
        public bool SZKTV { get; set; }

        [Display(Name = nameof(TanuloResource.Szetv), ResourceType = typeof(TanuloResource))]
        public bool SZETV { get; set; }

        [Display(Name = nameof(TanuloResource.Osztv), ResourceType = typeof(TanuloResource))]
        public bool OSZTV { get; set; }

        [Display(Name = nameof(TanuloResource.EgyebOrszagosDonto), ResourceType = typeof(TanuloResource))]
        public bool EgyebOrszagosDonto { get; set; }

        [Display(Name = nameof(TanuloResource.GyakorlatiSzintvizsgakAtlaga), ResourceType = typeof(TanuloResource))]
        public double? GyakorlatiSzintvizsgakAtlaga { get; set; }

        [Display(Name = nameof(TanuloResource.TechnikusiEvfolyam), ResourceType = typeof(TanuloResource))]
        public bool TechnikusiEvfolyam { get; set; }

        [Display(Name = nameof(TanuloResource.EgyuttmukodesiMegallapodasos), ResourceType = typeof(TanuloResource))]
        public bool EgyuttmukodesiMegallapodasos { get; set; }

        [Display(Name = nameof(TanuloResource.KizarolagIskolaiKeretekKozott), ResourceType = typeof(TanuloResource))]
        public bool KizarolagIskolaiKeretekKozott { get; set; }

        [Display(Name = nameof(TanuloResource.OsszevontOsztalyEvfolyamTipus), ResourceType = typeof(TanuloResource))]
        public int? TanuloEvfolyamTipus { get; set; }

        public bool IsOsszevontOsztaly { get; set; }

        [Display(Name = nameof(TanuloResource.IsSzakmaiGyakorlatHiany), ResourceType = typeof(TanuloResource))]
        public bool IsSzakmaiGyakorlatHiany { get; set; }

        [RequiredIf("IsTanterviJellemzoRequired", true, ErrorMessageResourceName = nameof(TanuloResource.TanterviJellemzoMegadasaKotelezo), ErrorMessageResourceType = typeof(TanuloResource))]
        [Display(Name = nameof(TanuloResource.TanterviJellemzo), ResourceType = typeof(TanuloResource))]
        public int? TanterviJellemzoId { get; set; }
        public bool IsTanterviJellemzoRequired => ClaimData.IsSelectedTanev21_22OrLater && ClaimData.IsSzakkepzoIntezmeny && OsztalyId.HasValue;

        public int? OsztalyEvfolyamTipus { get; set; }

        [Display(Name = nameof(TanuloResource.AgazatiAlapvizsgaEredmenye), ResourceType = typeof(TanuloResource))]
        public double? AgazatiAlapvizsgaEredmenye { get; set; }

        [Display(Name = nameof(TanuloResource.AgazatiAlapvizsgaEredmenyeSzazalek), ResourceType = typeof(TanuloResource))]
        public int? AgazatiAlapvizsgaEredmenyeSzazalek { get; set; }

        [Display(Name = nameof(TanuloResource.AgazatiAlapoktatasMegnevezese), ResourceType = typeof(TanuloResource))]
        public int? AgazatAlapOktMegnevTipusId { get; set; }

        [Display(Name = nameof(TanuloResource.AgazatiAlapvizsgaTeljesitese), ResourceType = typeof(TanuloResource))]
        public int? AgazatAlapVizsgaEredTipusId { get; set; }

        public bool IsVanAgazatialapvizsgaEredmeny => AgazatAlapVizsgaEredTipusId == (int)AgazatAlapVizsgaEredTipusEnum.teljesitette || AgazatAlapVizsgaEredTipusId == (int)AgazatAlapVizsgaEredTipusEnum.nem_teljesitette;

        [RequiredIf("IsVanAgazatialapvizsgaEredmeny", true, ErrorMessageResourceName = nameof(TanuloResource.AgazatialapvizsgaDatumanakMegadasaKotelezo), ErrorMessageResourceType = typeof(TanuloResource))]
        [Display(Name = nameof(TanuloResource.AgazatiAlapvizsgaDatuma), ResourceType = typeof(TanuloResource))]
        public DateTime? AgazatiAlapvizsgaDatuma { get; set; }

        [Display(Name = nameof(TanuloResource.SzakkepzesiMunkaszerzodessel), ResourceType = typeof(TanuloResource))]
        public bool IsSzakkepzesiMunkaszerzodessel { get; set; }

        [Display(Name = nameof(TanuloResource.DualisKepzohelyNeve), ResourceType = typeof(TanuloResource))]
        [StringLength(maximumLength: 255, ErrorMessageResourceName = nameof(ErrorResource.DualisKepzohelyNeveMax255Karakter), ErrorMessageResourceType = typeof(ErrorResource))]
        public string DualisKepzohelyNeve { get; set; }

        [Display(Name = nameof(TanuloResource.DualisKepzohelyAdoszama), ResourceType = typeof(TanuloResource))]
        [AdoszamExtended(ErrorMessageResourceName = nameof(ErrorResource.AdoszamFormatumaNemMegfelelo), ErrorMessageResourceType = typeof(ErrorResource))]
        public string DualisKepzohelyAdoszama { get; set; }

        [Display(Name = nameof(TanuloResource.SzakiranyNktTipus), ResourceType = typeof(TanuloResource))]
        public int? SzakiranyNktTipusId { get; set; }

        [Display(Name = nameof(TanuloResource.SzakkepesitesNktTipus), ResourceType = typeof(TanuloResource))]
        public int? SzakkepesitesNktTipusId { get; set; }

        [Display(Name = nameof(TanuloResource.TanulmanyiTeruletNktTipus), ResourceType = typeof(TanuloResource))]
        public int? TanulmanyiTeruletNktTipusId { get; set; }

        [Display(Name = nameof(TanuloResource.UjSzktReszszakmakAgazat), ResourceType = typeof(TanuloResource))]
        public int? AgazatReszSzakmaTipusId { get; set; }

        [Display(Name = nameof(TanuloResource.UjSzktReszszakmakSzakma), ResourceType = typeof(TanuloResource))]
        public int? SzakmaReszSzakmaTipusId { get; set; }

        [Display(Name = nameof(TanuloResource.UjSzktReszszakmakReszszakma), ResourceType = typeof(TanuloResource))]
        public int? ReszSzakmaTipusId { get; set; }

        [Display(Name = nameof(OsztalyCsoportResource.Is9kozul8ElozotanevbenVegezte), ResourceType = typeof(OsztalyCsoportResource))]
        public bool Is9kozul8ElozotanevbenVegezte { get; set; }

        [Display(Name = nameof(TanuloResource.KiemeltenTehetseges), ResourceType = typeof(TanuloResource))]
        public bool IsKiemeltenTehetseges { get; set; }

        [Display(Name = nameof(TanuloResource.SzamitogepetOktatasiCellalHasznal), ResourceType = typeof(TanuloResource))]
        public bool IsSzamitogepetOktCelraHasznal { get; set; }

        [Display(Name = nameof(TanuloResource.SzabokyAdolfSzakkepzesiOsztondijbanReszesul), ResourceType = typeof(TanuloResource))]
        public bool IsSzabokyAdolfSzakkepODReszesul { get; set; }

        [Display(Name = nameof(TanuloResource.EgeszNaposIskolaiOktatasbanReszesul), ResourceType = typeof(TanuloResource))]
        public bool IsEgesznaposIskOktReszesul { get; set; }

        public bool IsAltalanosIskolaFeladatEllatasiHely { get; set; }

        public bool IsUjSzktBlokkAlkalmaz { get; set; }

        public bool IsNktBlokkAlkalmaz { get; set; }

        public bool IsRegiSzktBlokkAlkalmaz { get; set; }

        public bool IsUjSzktReszSzakmakBlokkAlkalmaz { get; set; }

        [RequiredIf("IsTanterviJellegRequired", true, ErrorMessageResourceName = nameof(TanuloResource.TanterviJellegMegadasaKotelezo), ErrorMessageResourceType = typeof(TanuloResource))]
        [Display(Name = nameof(TanuloResource.TanterviJelleg), ResourceType = typeof(TanuloResource))]
        public int? TanterviJellegId { get; set; }
        public bool IsTanterviJellegRequired => ClaimData.IsSelectedTanev21_22OrLater && ClaimData.IsSzakkepzoIntezmeny && OsztalyId.HasValue;

        [Display(Name = nameof(TanuloResource.SzakkepzesenKivulrolJott), ResourceType = typeof(TanuloResource))]
        public bool IsSzakkepzesenKivulrolJott { get; set; }

        // NOTE: Itt azért nem a nameof(SzervezetResource.Szervezet)-ből jön a szöveg, mert ez a property fixen mindig ezzel a label-el kell, hogy megjelenjen, függetlenül a nyelviesítéstől!
        [Display(Name = nameof(DualisResource.DualisKepzohelyNeveEsAdoszama), ResourceType = typeof(DualisResource))]
        public int? TanuloSzervezetId { get; set; }

        public List<SzakkepzesiMunkaszerzodesGridModel> SzakkepzesiMunkaszerzodesModels { get; set; }
    }

    public class TanuloSzocialisModel
    {
        [Display(Name = nameof(TanuloResource.IngyenesTankonyvEllatas), ResourceType = typeof(TanuloResource))]
        public int? IngyenesTankonyvEllatas { get; set; }

        [Display(Name = nameof(TanuloResource.SzocialisOsztondij), ResourceType = typeof(TanuloResource))]
        public bool SzocialisTamogatas { get; set; }

        [Display(Name = nameof(TanuloResource.TestnevelesTipusa), ResourceType = typeof(TanuloResource))]
        public int? TestnevelesTipusa { get; set; }

        [Display(Name = nameof(TanuloResource.KollegiumiEllatasbanReszesulo), ResourceType = typeof(TanuloResource))]
        public bool KollegiumiEllatasu { get; set; }

        [Display(Name = nameof(TanuloResource.EtkezesiKedvezmeny), ResourceType = typeof(TanuloResource))]
        public int? EtkezesiKedvezmeny { get; set; }

        [Display(Name = nameof(TanuloResource.IntezetiNevelt), ResourceType = typeof(TanuloResource))]
        public bool IntezetiNevelt { get; set; }

        [Required(ErrorMessageResourceName = nameof(TanuloResource.AHatranyosHelyzetErtekeErvenytelen), ErrorMessageResourceType = typeof(TanuloResource))]
        [Display(Name = nameof(TanuloResource.HatranyosHelyzet), ResourceType = typeof(TanuloResource))]
        public int? HatranyosHelyzet { get; set; }

        [Display(Name = nameof(TanuloResource.Veszelyeztetett), ResourceType = typeof(TanuloResource))]
        public bool Veszelyeztetett { get; set; }

        [Display(Name = nameof(TanuloResource.MenekultOltalmazottMenedekes), ResourceType = typeof(TanuloResource))]
        public bool MenedekJoggalRendelkezo { get; set; }

        [Display(Name = nameof(TanuloResource.TartosGyogykezelesOkmanyszama), ResourceType = typeof(TanuloResource))]
        [StringLength(maximumLength: 50, ErrorMessageResourceName = nameof(ErrorResource.TartosgyogykezelesSzamMax50KarakterTanuloSzocialisAdatok), ErrorMessageResourceType = typeof(ErrorResource))]
        public string TartosGyogykezelesSzama { get; set; }

        [Display(Name = nameof(TanuloResource.BeilleszkedesiNehezseg), ResourceType = typeof(TanuloResource))]
        public bool BeilleszkedesiNehezseg { get; set; }

        [Display(Name = nameof(TanuloResource.RendszeresGyermekvedelmiKedvezmeny), ResourceType = typeof(TanuloResource))]
        [StringLength(maximumLength: 100, ErrorMessageResourceName = nameof(ErrorResource.TartosGyogykezelesSzamMax100KarakterSzocialisAdatok), ErrorMessageResourceType = typeof(ErrorResource))]
        public string RendszeresGyermekvedelmiKedvezmeny { get; set; }

        [Range(minimum: 0, maximum: 100)]
        [Display(Name = nameof(TanuloResource.TanuloiHallgatoiJogviszonnyalRendelkezoEltartott), ResourceType = typeof(TanuloResource))]
        public int? TanuloiJogviszonnyalEltartott { get; set; }

        [Display(Name = nameof(TanuloResource.HaromVagyTobbGyermekIgazolasOkmanyszama), ResourceType = typeof(TanuloResource))]
        [StringLength(maximumLength: 100, ErrorMessageResourceName = nameof(ErrorResource.TobbGyermnekIgazolasSzamaMax100KarakterSzocialisAdatok), ErrorMessageResourceType = typeof(ErrorResource))]
        public string TobbGyermnekIgazolasSzama { get; set; }

        [Range(minimum: 0, maximum: 100)]
        [Display(Name = nameof(TanuloResource.SzakkepesitesenekSzama), ResourceType = typeof(TanuloResource))]
        public int? SzakkepesitesenekSzama { get; set; }

        [Display(Name = nameof(TanuloResource.IsExternatusiEllatasban), ResourceType = typeof(TanuloResource))]
        public bool IsExternatusiEllatasban { get; set; }

        [Display(Name = nameof(TanuloResource.IsNapkoziotthoniEllatasban), ResourceType = typeof(TanuloResource))]
        public bool IsNapkoziotthoniEllatasban { get; set; }

        [Display(Name = nameof(TanuloResource.RendszeresGyermekvedelmiKedvezmenybenReszesul), ResourceType = typeof(TanuloResource))]
        public bool IsRendszeresGyermekvedelmi { get; set; }

        [Display(Name = nameof(TanuloResource.OtthonNyujtottEllatasiFormabanReszesul), ResourceType = typeof(TanuloResource))]
        public bool IsOtthonNyujtottEllatas { get; set; }
    }

    public class TanuloSajatosAdatModel
    {
        [Display(Name = nameof(TanuloResource.SajatosNevelesiIgenyu), ResourceType = typeof(TanuloResource))]
        public bool SajatosNevelesu { get; set; }

        //[Display(Name = nameof(TanuloResource.HalmozottanFogyatekos), ResourceType = typeof(TanuloResource))]
        //public bool HalmozottanFogyatekos { get; set; }

        [Range(minimum: 0, maximum: 3, ErrorMessageResourceName = nameof(ErrorResource.ALetszamsuly0Es3KoztiEgeszSzamLehet), ErrorMessageResourceType = typeof(ErrorResource))]
        [Display(Name = nameof(TanuloResource.TanuloLetszamsulyozasa), ResourceType = typeof(TanuloResource))]
        public int? TanuloLetszamSulyozasa { get; set; }

        //[Display(Name = nameof(TanuloResource.ErtelmiFogyatekos), ResourceType = typeof(TanuloResource))]
        //public int? ErtelmiFogyatekos { get; set; }

        //[Display(Name = nameof(TanuloResource.Hallasserult), ResourceType = typeof(TanuloResource))]
        //public int? Hallasserult { get; set; }

        //[Display(Name = nameof(TanuloResource.Latasserult), ResourceType = typeof(TanuloResource))]
        //public int? Latasserult { get; set; }

        //[Display(Name = nameof(TanuloResource.ErtelmiFogyatekosOkmanyszam), ResourceType = typeof(TanuloResource))]
        //public string ErtelmiFogyatekosOkmanySzam { get; set; }

        //[Display(Name = nameof(TanuloResource.HallasserultOkmanyszam), ResourceType = typeof(TanuloResource))]
        //public string HallasserultOkmanySzam { get; set; }

        //[Display(Name = nameof(TanuloResource.LatasserultOkmanyszam), ResourceType = typeof(TanuloResource))]
        //public string LatasserultOkmanySzam { get; set; }

        //[Display(Name = nameof(TanuloResource.MozgaskorlatozottOkmanyszam), ResourceType = typeof(TanuloResource))]
        //public string MozgasserultOkmanySzam { get; set; }

        //[Display(Name = nameof(TanuloResource.BeszedfogyatekosOkmanyszam), ResourceType = typeof(TanuloResource))]
        //public string BeszedfogyatekosOkmanySzam { get; set; }

        //[Display(Name = nameof(TanuloResource.DiszlexiaOkmanyszam), ResourceType = typeof(TanuloResource))]
        //public string DiszlexiaOkmanySzam { get; set; }

        //[Display(Name = nameof(TanuloResource.DiszkalkuliaOkmanyszam), ResourceType = typeof(TanuloResource))]
        //public string DiszkalkuliaOkmanySzam { get; set; }

        //[Display(Name = nameof(TanuloResource.DiszgrafiaOkmanyszam), ResourceType = typeof(TanuloResource))]
        //public string DiszgrafiaOkmanySzam { get; set; }

        //[Display(Name = nameof(TanuloResource.Diszlexia0), ResourceType = typeof(TanuloResource))]
        //public bool Diszlexia { get; set; }

        //[Display(Name = nameof(TanuloResource.Diszkalkulia0), ResourceType = typeof(TanuloResource))]
        //public bool Diszkalkulia { get; set; }

        //[Display(Name = nameof(TanuloResource.Diszgrafia0), ResourceType = typeof(TanuloResource))]
        //public bool Diszgrafia { get; set; }

        //[StringLength(100, ErrorMessageResourceName = nameof(ErrorResource.ViselkedesFejlodesMaxHossz), ErrorMessageResourceType = typeof(ErrorResource))]
        //[Display(Name = nameof(TanuloResource.ViselkedesFejlodesenekOrganikusOkraVisszavezethetoTartosEsSulyosRendellenessegevelKuzdOkmanyszam), ResourceType = typeof(TanuloResource))]
        //public string ViselkedesOkmanySzam { get; set; }

        //[StringLength(100, ErrorMessageResourceName = nameof(ErrorResource.ViselkedesFejlodesMaxHossz), ErrorMessageResourceType = typeof(ErrorResource))]
        //[Display(Name = nameof(TanuloResource.ViselkedesFejlodesenekOrganikusOkraVisszaNemVezethetoTartosEsSulyosRendellenessegevelKuzdOkmanyszam), ResourceType = typeof(TanuloResource))]
        //public string ViselkedesNemOkmanySzam { get; set; }

        //[StringLength(100, ErrorMessageResourceName = nameof(ErrorResource.MegismeroFunkciokMaxHossz), ErrorMessageResourceType = typeof(ErrorResource))]
        //[Display(Name = nameof(TanuloResource.MegismeroFunkciokOrganikusOkraVisszavezethetoTartosEsSulyosRendellenessegevelKuzdOkmanyszam), ResourceType = typeof(TanuloResource))]
        //public string MegismeroFunkciokOkmanySzam { get; set; }

        //[StringLength(100, ErrorMessageResourceName = nameof(ErrorResource.MegismeroFunkciokMaxHossz), ErrorMessageResourceType = typeof(ErrorResource))]
        //[Display(Name = nameof(TanuloResource.MegismeroFunkciokOrganikusOkraVisszaNemVezethetoTartosEsSulyosRendellenessegevelKuzdOkmanyszam), ResourceType = typeof(TanuloResource))]
        //public string MegismeroFunkciokNemOkmanySzam { get; set; }

        //[Display(Name = nameof(TanuloResource.BnoKod), ResourceType = typeof(TanuloResource))]
        //public string BNOKod { get; set; }

        //[Display(Name = nameof(TanuloResource.Meghatarozas), ResourceType = typeof(TanuloResource))]
        //public string Meghatarozas { get; set; }

        //[Display(Name = nameof(TanuloResource.KiallitoIntezmenyMegnevezese), ResourceType = typeof(TanuloResource))]
        //public string KiallitoIntezmeny { get; set; }

        //[Display(Name = nameof(TanuloResource.OkmanyErvenyessegenekKezdete), ResourceType = typeof(TanuloResource))]
        //public DateTime? OkmanyErvenyessegKezdete { get; set; }

        //[Display(Name = nameof(TanuloResource.OkmanyErvenyessegenekVege), ResourceType = typeof(TanuloResource))]
        //public DateTime? OkmanyErvenyessegVege { get; set; }

        //[Display(Name = nameof(TanuloResource.SzuksegesKontrollIdopontja), ResourceType = typeof(TanuloResource))]
        //public DateTime? SzuksegesKontrollIdopontja { get; set; }

        //[Range(minimum: 1, maximum: 10000, ErrorMessageResourceName = nameof(ErrorResource.FejlesztesreForditandoOraszamNagyobbKellLegyenNullanal), ErrorMessageResourceType = typeof(ErrorResource))]
        //[Display(Name = nameof(TanuloResource.FejlesztesreForditandoOraszam), ResourceType = typeof(TanuloResource))]
        //public double? FejlesztesreForditandoOraszam { get; set; }

        //[Display(Name = nameof(TanuloResource.FejlesztoFoglalkozas), ResourceType = typeof(TanuloResource))]
        //public string FejlesztoFoglalkozas { get; set; }

        //[Display(Name = nameof(TanuloResource.FejlesztesreKijelolt), ResourceType = typeof(TanuloResource))]
        //public string FejlesztesreKijelolt { get; set; }

        [Display(Name = nameof(TanuloResource.KiallitoSzakertoiBizottsagNeve), ResourceType = typeof(TanuloResource))]
        [StringLength(500, ErrorMessageResourceName = nameof(ErrorResource.KiallitoSzakertoiBizottsagNeveMax500KarakterLehet), ErrorMessageResourceType = typeof(ErrorResource))]
        public string KiallitoSzakertoiBizottsagNeve { get; set; }

        [Display(Name = nameof(TanuloResource.KiallitoSzakertoiBizottsagCime), ResourceType = typeof(TanuloResource))]
        [StringLength(500, ErrorMessageResourceName = nameof(ErrorResource.KiallitoSzakertoiBizottsagCimeMax500KarakterLehet), ErrorMessageResourceType = typeof(ErrorResource))]
        public string KiallitoSzakertoiBizottsagCime { get; set; }

        [Display(Name = nameof(TanuloResource.SzakvelemenySzama), ResourceType = typeof(TanuloResource))]
        [StringLength(500, ErrorMessageResourceName = nameof(ErrorResource.SzakvelemenySzamaMax500KarakterLehet), ErrorMessageResourceType = typeof(ErrorResource))]
        public string SzakvelemenySzama { get; set; }

        [Display(Name = nameof(TanuloResource.KiallitasanakKelte), ResourceType = typeof(TanuloResource))]
        public DateTime? KiallitasDatuma { get; set; }

        [Display(Name = nameof(TanuloResource.FelulvizsgalatIdopontjaTanev), ResourceType = typeof(TanuloResource))]
        [MaxLength(50, ErrorMessageResourceName = nameof(ErrorResource.AFelulvizsgalatTaneveMaxmum50KarakterLehet), ErrorMessageResourceType = typeof(ErrorResource))]
        public string FelulvizsgalatTaneve { get; set; }

        public int? TanuloSniId { get; set; }

        [Display(Name = nameof(TanuloResource.FogyatekossagTipusId), ResourceType = typeof(TanuloResource))]
        public int? FogyatekossagTipusId { get; set; }

        public bool IsFogyatekossagHide => (!ClaimData.IsSelectedTanev21_22OrLater || (!ClaimData.IsAdministrator && !ClaimData.IsOsztalyfonok && ClaimData.FelhasznaloSzerepCsomagok.Contains(KretaClaimPackages.CsoportVezeto.ClaimValue))) && !ClaimData.IsSzakkepzoIntezmeny;
    }

    public class TanuloBTMProblemakModel
    {
        [Display(Name = nameof(TanuloResource.BeilleszkedesiTanulasiEsMagatartasiNehezseggelKuzdo), ResourceType = typeof(TanuloResource))]
        public bool BTMProblema { get; set; }

        //[Range(minimum: 0, maximum: 3, ErrorMessageResourceName = nameof(ErrorResource.ALetszamsuly0Es3KoztiEgeszVagyTortSzamLehet), ErrorMessageResourceType = typeof(ErrorResource))]
        //[Display(Name = nameof(TanuloResource.TanuloLetszamsulyozasa), ResourceType = typeof(TanuloResource))]
        //public double? TanuloLetszamSulyozasa { get; set; }

        //[Display(Name = nameof(TanuloResource.BeilleszkedesiProblemavalKuzd), ResourceType = typeof(TanuloResource))]
        //public bool BeilleszkedesiProblemavalKuzd { get; set; }

        //[Display(Name = nameof(TanuloResource.TanulasiProblemavalKuzd), ResourceType = typeof(TanuloResource))]
        //public bool TanulasiProblemavalKuzd { get; set; }

        //[Display(Name = nameof(TanuloResource.Diszlexia0), ResourceType = typeof(TanuloResource))]
        //public bool Diszlexia { get; set; }

        //[Display(Name = nameof(TanuloResource.Diszkalkulia0), ResourceType = typeof(TanuloResource))]
        //public bool Diszkalkulia { get; set; }

        //[Display(Name = nameof(TanuloResource.Diszgrafia0), ResourceType = typeof(TanuloResource))]
        //public bool Diszgrafia { get; set; }

        //[Display(Name = nameof(TanuloResource.MagatartasiProblemavalKuzd), ResourceType = typeof(TanuloResource))]
        //public bool MagatartasiProblemavalKuzd { get; set; }

        //[Display(Name = nameof(TanuloResource.BtmHatarozatOkmanyszama), ResourceType = typeof(TanuloResource))]
        //public string BTMHatarozatOkmanySzam { get; set; }

        //[Display(Name = nameof(TanuloResource.KiallitoIntezmenyMegnevezese), ResourceType = typeof(TanuloResource))]
        //public string KiallitoIntezmeny { get; set; }

        //[Display(Name = nameof(TanuloResource.OkmanyErvenyessegenekKezdete), ResourceType = typeof(TanuloResource))]
        //public DateTime? OkmanyErvenyessegKezdete { get; set; }

        //[Display(Name = nameof(TanuloResource.OkmanyErvenyessegenekVege), ResourceType = typeof(TanuloResource))]
        //public DateTime? OkmanyErvenyessegVege { get; set; }

        //[Display(Name = nameof(TanuloResource.KontrollIdopontja), ResourceType = typeof(TanuloResource))]
        //public DateTime? KontrolIdopontja { get; set; }

        //[Display(Name = nameof(TanuloResource.HatarozatTartalma), ResourceType = typeof(TanuloResource))]
        //public string HatarozatTartalma { get; set; }
    }

    public class TanuloSportModel
    {
        [Display(Name = nameof(TanuloResource.Sportag), ResourceType = typeof(TanuloResource))]
        public string Sportag { get; set; }

        [Display(Name = nameof(TanuloResource.SportedzoNeveElerhetosege), ResourceType = typeof(TanuloResource))]
        public string SportedzoNeve { get; set; }

        [Display(Name = nameof(TanuloResource.Sportklub), ResourceType = typeof(TanuloResource))]
        public string SportKlub { get; set; }

        public int DummySport { get; set; }
    }

    public class TanuloVallasModel
    {
        [Display(Name = nameof(TanuloResource.Vallasa), ResourceType = typeof(TanuloResource))]
        public int? Vallasa { get; set; }

        [Display(Name = nameof(TanuloResource.Egyhazkozossege), ResourceType = typeof(TanuloResource))]
        public string Egyhazkozosseg { get; set; }

        public int DummyVallas { get; set; }
    }

    public class TanuloKozszolgGridModel : IKretaIdentity
    {
        public string ID { get; set; }

        [Display(Name = nameof(TanuloResource.IntervallumKezdete), ResourceType = typeof(TanuloResource))]
        public DateTime IntervallumKezdete { get; set; }

        [Display(Name = nameof(TanuloResource.IntervallumVege), ResourceType = typeof(TanuloResource))]
        public DateTime IntervallumVege { get; set; }

        [Display(Name = nameof(TanuloResource.Oraszam), ResourceType = typeof(TanuloResource))]
        public double Oraszam { get; set; }

        [Display(Name = nameof(TanuloResource.Alkalmazott), ResourceType = typeof(TanuloResource))]
        public string Alkalmazott { get; set; }

        [Display(Name = nameof(TanuloResource.Megjegyzes), ResourceType = typeof(TanuloResource))]
        public string Megjegyzes { get; set; }
    }

    public class TanuloKozszolgModel
    {
        public int? Id { get; set; }

        public int TanuloId { get; set; }

        [Required(ErrorMessageResourceName = nameof(ErrorResource.DatumMegadasaKotelezo), ErrorMessageResourceType = typeof(ErrorResource))]
        [Range(type: typeof(DateTime?), minimum: Core.Constants.MinMaxValues.MinDate, maximum: Core.Constants.MinMaxValues.MaxDate, ErrorMessageResourceName = nameof(ErrorResource.Ervenytelen), ErrorMessageResourceType = typeof(ErrorResource))]
        [Display(Name = nameof(TanuloResource.IntervallumKezdete), ResourceType = typeof(TanuloResource))]
        public DateTime? IntervallumKezdete { get; set; }

        [Required(ErrorMessageResourceName = nameof(ErrorResource.DatumMegadasaKotelezo), ErrorMessageResourceType = typeof(ErrorResource))]
        [Range(type: typeof(DateTime?), minimum: Core.Constants.MinMaxValues.MinDate, maximum: Core.Constants.MinMaxValues.MaxDate, ErrorMessageResourceName = nameof(ErrorResource.Ervenytelen), ErrorMessageResourceType = typeof(ErrorResource))]
        [Display(Name = nameof(TanuloResource.IntervallumVege), ResourceType = typeof(TanuloResource))]
        public DateTime? IntervallumVege { get; set; }

        [Required(ErrorMessageResourceName = nameof(ErrorResource.OraszamKitolteseKotelezo), ErrorMessageResourceType = typeof(ErrorResource))]
        [Range(minimum: 1, maximum: int.MaxValue)]
        [Display(Name = nameof(TanuloResource.Oraszam), ResourceType = typeof(TanuloResource))]
        public double? Oraszam { get; set; }

        [Required(ErrorMessageResourceName = nameof(ErrorResource.Required), ErrorMessageResourceType = typeof(ErrorResource))]
        [Display(Name = nameof(TanuloResource.Tevekenyseg), ResourceType = typeof(TanuloResource))]
        public int? KozossegiSzolgalatTipusa { get; set; }

        [Display(Name = nameof(TanuloResource.Megjegyzes), ResourceType = typeof(TanuloResource))]
        public string Megjegyzes { get; set; }

        public static TanuloKozossegiSzolgalatCO ConvertModelToCo(TanuloKozszolgModel model)
        {
            var co = new TanuloKozossegiSzolgalatCO();

            co.ID = model.Id;
            co.TanuloId = model.TanuloId;
            co.IntervallumKezdete = model.IntervallumKezdete.Value;
            co.IntervallumVege = model.IntervallumVege.Value;
            co.Oraszam = model.Oraszam;
            co.Megjegyzes = model.Megjegyzes;
            co.KozossegiSzolgalatTipusa = model.KozossegiSzolgalatTipusa.Value;

            return co;
        }

        public static TanuloKozszolgModel ConvertCoToModel(TanuloKozossegiSzolgalatCO co)
        {
            var model = new TanuloKozszolgModel();

            model.Id = co.ID;
            model.TanuloId = co.TanuloId;
            model.IntervallumKezdete = co.IntervallumKezdete;
            model.IntervallumVege = co.IntervallumVege;
            model.Oraszam = co.Oraszam;
            model.Megjegyzes = co.Megjegyzes;
            model.KozossegiSzolgalatTipusa = co.KozossegiSzolgalatTipusa;

            return model;
        }
    }

    public class TanuloModGondviseloModel : CimElerhetosegModel
    {
        [Display(Name = nameof(TanuloResource.TanuloCimElerhetosegek), ResourceType = typeof(TanuloResource))]
        public int? TanuloElerhetosegCimId { get; set; }

        [Required(ErrorMessageResourceName = nameof(ErrorResource.GondviseloNeveKotelezo), ErrorMessageResourceType = typeof(ErrorResource))]
        [StringLength(200, ErrorMessageResourceName = nameof(ErrorResource.GondviseloNeveMax200Karakter), ErrorMessageResourceType = typeof(ErrorResource))]
        [Display(Name = nameof(TanuloResource.GondviseloNeve), ResourceType = typeof(TanuloResource))]
        public string GondviseloNeve { get; set; }

        [StringLength(100, ErrorMessageResourceName = nameof(ErrorResource.FelhasznalonevMax100Karakter), ErrorMessageResourceType = typeof(ErrorResource))]
        [Display(Name = nameof(TanuloResource.Felhasznalonev), ResourceType = typeof(TanuloResource))]
        public string GondviseloBejelentkezesiNev { get; set; }

        [Display(Name = nameof(TanuloResource.Jelszo), ResourceType = typeof(TanuloResource))]
        [StringLength(General.JelszoMaximumKarakterekSzama, MinimumLength = General.JelszoMinimumKarakterekSzama, ErrorMessageResourceName = nameof(ErrorResource.AJelszonakMin0Max0KarakterbolKellAllnia), ErrorMessageResourceType = typeof(ErrorResource))]
        public string GondviseloJelszo { get; set; }

        [System.ComponentModel.DataAnnotations.Compare(@"GondviseloJelszo", ErrorMessageResourceName = nameof(ErrorResource.AzIsmeteltJelszoNemEgyezikMegAJelszoval), ErrorMessageResourceType = typeof(ErrorResource))]
        [Display(Name = nameof(TanuloResource.IsmeteltJelszo), ResourceType = typeof(TanuloResource))]
        [StringLength(General.JelszoMaximumKarakterekSzama, MinimumLength = General.JelszoMinimumKarakterekSzama, ErrorMessageResourceName = nameof(ErrorResource.AJelszonakMin0Max0KarakterbolKellAllnia), ErrorMessageResourceType = typeof(ErrorResource))]
        public string IsmeteltGondviseloJelszo { get; set; }

        [Required(ErrorMessageResourceName = nameof(ErrorResource.GondviseloRokonsagiFokaKotelezo), ErrorMessageResourceType = typeof(ErrorResource))]
        [Display(Name = nameof(TanuloResource.RokonsagiFok), ResourceType = typeof(TanuloResource))]
        public int? RokonsagiFok { get; set; }

        [Display(Name = nameof(TanuloResource.BelepesiAdatokKikuldeseEmailben), ResourceType = typeof(TanuloResource))]
        public bool GondviseloAutoEmail { get; set; }

        [Display(Name = nameof(TanuloResource.TorvenyesKepviselo), ResourceType = typeof(TanuloResource))]
        public bool IsTorvenyesKepviselo { get; set; }

        [Display(Name = nameof(TanuloResource.HozzaferesGeneralasEsFajlLetoltes), ResourceType = typeof(TanuloResource))]
        public bool FileLetoltesSzukseges { get; set; }

        public bool IsSzirIntezmeny { get; set; }

        public static TanuloModGondviseloModel ConvertCoToModel(TanuloGondviseloCO co)
        {
            var model = new TanuloModGondviseloModel();

            model.Id = co.ID;
            model.FelhasznaloId = co.TanuloId;
            model.GondviseloNeve = co.GondviseloNeve;
            model.RokonsagiFok = co.RokonsagiFok;
            model.Telefon = co.TelefonszamGondviselo;
            model.TelefonTipus = co.TelefonTipusGondviselo;
            model.Emailcim_Input = co.EmailcimGondviselo;
            model.EmailTipus = co.EmailcimTipusGondviselo;
            model.GondviseloBejelentkezesiNev = co.GondviseloBelepesiNeve;
            model.GondviseloAutoEmail = co.GondviseloAutoEmail;
            model.IsTorvenyesKepviselo = co.IsTorvenyesKepviselo;
            // A gondviselő címadata másik model-ben kerül módosításra, illetve ez az érték nem tárolódik db-ben,
            // ezért a validáció miatt implicit be kell állítani ezt a mezőt:
            model.TanulovalEgyezik = true;

            return model;
        }

        public static TanuloGondviseloCO ConvertModelToCo(TanuloModGondviseloModel model)
        {
            var co = new TanuloGondviseloCO();

            co.ID = model.Id;
            co.TanuloId = model.FelhasznaloId;
            co.GondviseloNeve = model.GondviseloNeve;
            co.RokonsagiFok = model.RokonsagiFok;
            co.TelefonszamGondviselo = model.Telefon;
            co.TelefonTipusGondviselo = model.TelefonTipus;
            co.EmailcimTipusGondviselo = model.EmailTipus;
            co.EmailcimGondviselo = model.Emailcim;
            co.GondviseloBelepesiNeve = model.GondviseloBejelentkezesiNev;
            co.GondviseloJelszava = model.GondviseloJelszo;

            co.TanuloElerhetosegCimId = model.TanuloElerhetosegCimId;
            co.TanuloElerhetosegTelId = model.TanuloElerhetosegTelId;
            co.TanuloElerhetosegEmailId = model.TanuloElerhetosegEmailId;
            co.GondviseloAutoEmail = model.GondviseloAutoEmail;
            co.IsTorvenyesKepviselo = model.IsTorvenyesKepviselo;

            return co;
        }
    }

    public class TanuloFelmentesModel
    {
        public int ID { get; set; }

        public int TanuloId { get; set; }

        [Display(Name = nameof(FelmentesResource.TanuloNeve), ResourceType = typeof(FelmentesResource))]
        public string TanuloNeve { get; set; }

        [Display(Name = nameof(FelmentesResource.TanuloOsztalya), ResourceType = typeof(FelmentesResource))]
        public string TanuloOsztalya { get; set; }

        [Display(Name = nameof(TanuloResource.Tantargy), ResourceType = typeof(TanuloResource))]
        //[Required(ErrorMessageResourceName = nameof(ErrorResource.TantargyKivalasztasaKotelezo), ErrorMessageResourceType = typeof(ErrorResource))]
        public int? TantargyId { get; set; }

        [Display(Name = nameof(TanuloResource.Tantargy), ResourceType = typeof(TanuloResource))]
        public string[] TantargyIdList { get; set; }

        [Display(Name = nameof(TanuloResource.ErtekelesAloliFelmentes), ResourceType = typeof(TanuloResource))]
        public bool ErtekelesMentesites { get; set; }

        [Display(Name = nameof(TanuloResource.TanoraLatogatasaAloliFelmentes), ResourceType = typeof(TanuloResource))]
        public bool OraMentesites { get; set; }

        [Required(ErrorMessageResourceName = nameof(ErrorResource.FelmentesOkanakLeirasaKotelezo), ErrorMessageResourceType = typeof(ErrorResource))]
        [Display(Name = nameof(TanuloResource.FelmentesOka), ResourceType = typeof(TanuloResource))]
        public string FelmentesOka { get; set; }

        [Required(ErrorMessageResourceName = nameof(ErrorResource.FelmentesKezdetenekMegadasaKotelezo), ErrorMessageResourceType = typeof(ErrorResource))]
        [Display(Name = nameof(TanuloResource.Kezdete), ResourceType = typeof(TanuloResource))]
        public DateTime? Kezdete { get; set; }

        [Display(Name = nameof(TanuloResource.Vege), ResourceType = typeof(TanuloResource))]
        public DateTime? Vege { get; set; }

        [Display(Name = nameof(TanuloResource.SzovegesenErtekelheto), ResourceType = typeof(TanuloResource))]
        public bool SzovegesenErtekelheto { get; set; }
        public bool IsKorabbiMulasztasokEllenorzese { get; set; }
        public bool IsKorabbiMulasztasokModositasa { get; set; }

        public string SzovegesenErtekelheto_Str => SzovegesenErtekelheto ? IgenNemEnum.Igen.GetDisplayName(ClaimData.SelectedTanevID.Value) : IgenNemEnum.Nem.GetDisplayName(ClaimData.SelectedTanevID.Value);
        public string IsKorabbiMulasztasokEllenorzese_Str => IsKorabbiMulasztasokEllenorzese ? IgenNemEnum.Igen.GetDisplayName(ClaimData.SelectedTanevID.Value) : IgenNemEnum.Nem.GetDisplayName(ClaimData.SelectedTanevID.Value);
        public string IsKorabbiMulasztasokModositasa_Str => IsKorabbiMulasztasokModositasa ? IgenNemEnum.Igen.GetDisplayName(ClaimData.SelectedTanevID.Value) : IgenNemEnum.Nem.GetDisplayName(ClaimData.SelectedTanevID.Value);
        public string Kezdete_Str => Kezdete.HasValue ? Kezdete.Value.ToString(Kreta.Core.Constants.ToStringPattern.HungarianDate) : "-";
        public string Vege_Str => Vege.HasValue ? Vege.Value.ToString(Kreta.Core.Constants.ToStringPattern.HungarianDate) : "-";

        public static TanuloFelmentesCO ConvertModelToCo(TanuloFelmentesModel model)
        {
            var co = new TanuloFelmentesCO()
            {
                ID = model.ID,
                TanuloId = model.TanuloId,
                TantargyId = model.TantargyId,
                ErtekelesMentesites = model.ErtekelesMentesites,
                OraMentesites = model.OraMentesites,
                FelmentesOka = model.FelmentesOka,
                Kezdete = model.Kezdete,
                Vege = model.Vege,
                SzovegesenErtekelheto = model.SzovegesenErtekelheto,
                TantargyIdList = model.TantargyIdList,
                IsKorabbiMulasztasokEllenorzese = model.IsKorabbiMulasztasokEllenorzese,
                IsKorabbiMulasztasokModositasa = model.IsKorabbiMulasztasokModositasa,
                TanuloNeve = model.TanuloNeve,
                TanuloOsztalya = model.TanuloOsztalya
            };

            return co;
        }

        public static TanuloFelmentesModel ConvertCoToModel(TanuloFelmentesCO co)
        {
            var model = new TanuloFelmentesModel()
            {
                ID = co.ID ?? default(int),
                TanuloId = co.TanuloId ?? default(int),
                TantargyId = co.TantargyId,
                ErtekelesMentesites = co.ErtekelesMentesites,
                OraMentesites = co.OraMentesites,
                FelmentesOka = co.FelmentesOka,
                Kezdete = co.Kezdete,
                Vege = co.Vege,
                SzovegesenErtekelheto = co.SzovegesenErtekelheto,
                TanuloNeve = co.TanuloNeve,
                TanuloOsztalya = co.TanuloOsztalya
            };

            return model;
        }
    }

    public class TanuloJuttatasModel : BaseTanuloJuttatasModel
    {

    }

    public class ApaczaiJuttatasModel : BaseTanuloJuttatasModel
    {
        [Display(Name = nameof(TanuloResource.ApaczaiOsztondijprogrambanKijeloltMentor), ResourceType = typeof(TanuloResource))]
        public int? MentorId { get; set; }
    }

    public class BaseTanuloJuttatasModel
    {
        public string JuttatasModelIdPrefix { get; set; } = "TanuloJuttatasModel_";
        public string JuttatasModelNamePrefix { get; set; } = "TanuloJuttatasModel.";

        [Display(Name = nameof(TanuloResource.Evismetlo), ResourceType = typeof(TanuloResource))]
        public bool Evismetlo { get; set; }

        [Display(Name = nameof(TanuloResource.BankszamlaSzam), ResourceType = typeof(TanuloResource))]
        public string Bankszamlaszam { get; set; }

        [Display(Name = nameof(TanuloResource.Jogviszony), ResourceType = typeof(TanuloResource))]
        public int? Jogviszony { get; set; }

        [Display(Name = nameof(TanuloResource.Jogviszony), ResourceType = typeof(TanuloResource))]
        public string Jogviszony_DNAME { get; set; }

        [Display(Name = nameof(TanuloResource.BankszamlaTulajdonosa), ResourceType = typeof(TanuloResource))]
        public int? BankszamlaTulajdonos { get; set; }

        [Display(Name = nameof(TanuloResource.BankszamlaTulajdonosa), ResourceType = typeof(TanuloResource))]
        public string BankszamlaTulajdonos_DNAME { get; set; }

        [Display(Name = nameof(TanuloResource.MasodikVagyTobbedikSzakmatSzerzo), ResourceType = typeof(TanuloResource))]
        public bool IsMasodikVagyTobbedikSzakmatSzerzo { get; set; }

        [Display(Name = nameof(TanuloResource.BankszamlaTulajdonosNeve), ResourceType = typeof(TanuloResource))]
        public string BankszamlaTulajdonosNeve { get; set; }

        [Display(Name = nameof(TanuloResource.TanuloTajSzama), ResourceType = typeof(TanuloResource))]
        public string TanuloTAJSzama { get; set; }

        public double? SzamitottAtlag { get; set; }

        public double? KeziAtlag { get; set; }

        public double? KeziAtlag_Beszamitas { get { return KeziAtlag; } set { KeziAtlag = value; } }

        public double? KeziAtlag_Alapvizsga { get { return KeziAtlag; } set { KeziAtlag = value; } }

        public int OsztondijAlapSzazalek { get; set; }

        public JuttatasraNemJogosultOkaEnum IsJogosult { get; set; }

        //public bool IsEvvegiJegybol { get; set; }

        public bool IsAtlagFuggoSzazalek { get; set; }

        [Display(Name = nameof(TanuloResource.Tanuloszerzodeses), ResourceType = typeof(TanuloResource))]
        public bool IsDualisKepzesbenTanuloszerzodeses { get; set; }

        [Display(Name = nameof(TanuloResource.SzakkepzesiMunkaszerzodessel), ResourceType = typeof(TanuloResource))]
        public bool IsDualisKepzesbenSzakkepzesiMunkaszerzodeses { get; set; }

        [Display(Name = nameof(TanuloResource.Vendegtanulo), ResourceType = typeof(TanuloResource))]
        public bool IsVendeg { get; set; }

        [Display(Name = nameof(TanuloResource.JogviszonySzunetelo), ResourceType = typeof(TanuloResource))]
        public bool IsJogviszonySzuneteltetese { get; set; }

        [Display(Name = nameof(TanuloResource.BeszamitasosTanulo), ResourceType = typeof(TanuloResource))]
        public bool IsBeszamitasosTanulo { get; set; }

        [Display(Name = nameof(TanuloResource.IsSikeresAgazatiVizsga), ResourceType = typeof(TanuloResource))]
        public bool IsSikeresAgazatiVizsga { get; set; }
        public bool IsFelevnelValtos { get; set; }
        public bool IsAtlagSzakkepzesi { get; set; }
        public bool IsBeszamitasosFixSzazalek { get; set; }

        [Display(Name = nameof(TanuloResource.IsApaczaiIgenylo), ResourceType = typeof(TanuloResource))]
        public bool IsApaczaiIgenylo { get; set; }
        [Display(Name = nameof(TanuloResource.IsApaczaiSzerzodeses), ResourceType = typeof(TanuloResource))]
        public bool IsApaczaiSzerzodeses { get; set; }

        [Display(Name = nameof(SzakkepzesiJuttatasokResource.NemJogosultsagOka), ResourceType = typeof(SzakkepzesiJuttatasokResource))]
        public string ElutasitasOkok { get; set; }

        [Display(Name = nameof(TanuloResource.AllamAltalIngyenesenBiztositottKepzesbenResztvevo), ResourceType = typeof(TanuloResource))]
        public bool IsIngyenesKepzes { get; set; }

        [Display(Name = nameof(TanuloResource.TanevVegiAtlagMegadasaNemRelevans), ResourceType = typeof(TanuloResource))]
        public bool IsAtlagNelkuli { get; set; }
    }

    public class TanuloSzirBeallitasokModel
    {
        [Display(Name = nameof(TanuloResource.KuldhetoErettsegiSzRnek), ResourceType = typeof(TanuloResource))]
        public bool IsKuldhetoErettsegiSzRnek { get; set; }

        [Display(Name = nameof(TanuloResource.KuldhetoMeresiSzRnek), ResourceType = typeof(TanuloResource))]
        public bool IsKuldhetoMeresiSzRnek { get; set; }

        [Display(Name = nameof(TanuloResource.KuldhetoKozepFelveteliSzRnek), ResourceType = typeof(TanuloResource))]
        public bool IsKuldhetoKozepFelveteliSzRnek { get; set; }

        [Display(Name = nameof(TanuloResource.DiakigazolvanyAtadhatoSzRnek), ResourceType = typeof(TanuloResource))]
        public bool IsDiakigazolvanyAtadhatoSzRnek { get; set; }
    }
}
