﻿using System;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;
using System.Linq;
using System.Web.Mvc;
using Foolproof;
using Kreta.BusinessLogic.Classes;
using Kreta.BusinessLogic.HelperClasses;
using Kreta.Enums;
using Kreta.Resources;
using Kreta.Web.Models;
using Kreta.Web.Models.EditorTemplates;
using Kreta.Web.Security;
using Newtonsoft.Json;

namespace Kreta.Web.Areas.Tanulo.Models
{
    public class TanuloTobbesModModel : TabStripModel
    {
        public List<TanuloTobbesModId> TobbesModIdList { get; set; }
        public string TobbesModIdListJson { get { return TobbesModIdList == null ? string.Empty : JsonConvert.SerializeObject(TobbesModIdList); } set { TobbesModIdList = JsonConvert.DeserializeObject<List<TanuloTobbesModId>>(value); } }

        [Display(Name = nameof(TanuloResource.Nev), ResourceType = typeof(TanuloResource))]
        public string TanuloNev { get; set; }

        [Display(Name = nameof(TanuloResource.KivalasztottTanulok), ResourceType = typeof(TanuloResource))]
        public string TanuloNevArray { get; set; }

        [ValidateObject]
        public TanuloTobbesAlapAdatModel TanuloTobbesAlapAdatModel { get; set; }

        [ValidateObject]
        public TanuloTobbesTanugyModel TanuloTobbesTanugyModel { get; set; }

        [ValidateObject]
        public TanuloTobbesVallasModel TanuloTobbesVallasModel { get; set; }

        [ValidateObject]
        public TanuloTobbesSportModel TanuloTobbesSportModel { get; set; }

        [ValidateObject]
        public TanuloTobbesSzirBeallitasokModel TanuloTobbesSzirBeallitasokModel { get; set; }

        public bool IsNszfhUjSzkt => ClaimData.IsSelectedTanev20_21OrLater && ClaimData.IsSzakkepzoIntezmeny;

        public TanuloTobbesJuttatasModel TanuloTobbesJuttatasModel { get; set; }

        public AmiKepzesiJellemzokModelForTanulo AmiKepzesiJellemzokModel { get; set; }

        public bool IsApaczaiEnabled { get; set; }
        public bool IsDualisKepzesEnabled { get; set; }

        public TanuloTobbesModModel()
        {
            IgenNemList = GetIgenNemList();
            TobbesModIdList = new List<TanuloTobbesModId>();
            AmiKepzesiJellemzokModel = new AmiKepzesiJellemzokModelForTanulo();
        }

        private List<SelectListItem> GetIgenNemList()
        {
            List<SelectListItem> list = new List<SelectListItem>();

            list.Add(new SelectListItem() { Text = CommonResource.Igen, Value = ((int)Enums.ManualEnums.IgenNemEnum.Igen).ToString() });
            list.Add(new SelectListItem() { Text = CommonResource.Nem, Value = ((int)Enums.ManualEnums.IgenNemEnum.Nem).ToString() });

            return list;
        }

        public List<SelectListItem> IgenNemList { get; set; }

        public static TanuloTobbesModAdatCO ConvertModModelToCo(TanuloTobbesModModel model)
        {
            var co = new TanuloTobbesModAdatCO();

            if (model.TanuloTobbesAlapAdatModel != null)
            {
                co.Allampolgarsag = model.TanuloTobbesAlapAdatModel.Allampolgarsag;
                co.Allampolgarsag2 = model.TanuloTobbesAlapAdatModel.Allampolgarsag2;
                co.Anyanyelv = model.TanuloTobbesAlapAdatModel.Anyanyelv;
                co.SzuletesiOrszag = model.TanuloTobbesAlapAdatModel.SzuletesiOrszag;
                co.Neme = model.TanuloTobbesAlapAdatModel.Neme;
            }
            if (model.TanuloTobbesTanugyModel != null)
            {
                co.TantervId = model.TanuloTobbesTanugyModel.TantervId;
                co.FelvetelTaneveId = model.TanuloTobbesTanugyModel.FelvetelTaneveId;
                co.NyilvantartastartasKezdete = model.TanuloTobbesTanugyModel.NyilvantartastartasKezdete;
                co.JogviszonyBefejezese = model.TanuloTobbesTanugyModel.JogviszonyBefejezese;
                co.JogviszonySzuneteltetese = model.TanuloTobbesTanugyModel.JogviszonySzuneteltetese;
                co.TankotelezettsegetTeljesito = model.TanuloTobbesTanugyModel.TankotelezettsegetTeljesito;
                co.TankotelezettsegVege = model.TanuloTobbesTanugyModel.TankotelezettsegVege;
                co.Magantanulo = model.TanuloTobbesTanugyModel.Magantanulo;
                co.MagantanulosagOka = model.TanuloTobbesTanugyModel.MagantanulosagOka;
                co.MagantanulosagKezdete = model.TanuloTobbesTanugyModel.MagantanulosagKezdete;
                co.MagantanulosagVege = model.TanuloTobbesTanugyModel.MagantanulosagVege;
                co.Vendeg = model.TanuloTobbesTanugyModel.Vendeg;
                co.TandijatFizeto = model.TanuloTobbesTanugyModel.TandijatFizeto;
                co.TeritestFizeto = model.TanuloTobbesTanugyModel.TeritestFizeto;
                co.Tanuloszerzodeses = model.TanuloTobbesTanugyModel.Tanuloszerzodeses;
                co.PolgariSzerzodeses = model.TanuloTobbesTanugyModel.PolgariSzerzodeses;
                co.DiaksportkorTag = model.TanuloTobbesTanugyModel.DiaksportkorTag;
                co.Evismetlo = model.TanuloTobbesTanugyModel.Evismetlo;
                co.ESL16EvesUtanBelepett = model.TanuloTobbesTanugyModel.ESL16EvesUtanBelepett;
                co.IngyenesTankonyvEllatas = model.TanuloTobbesTanugyModel.IngyenesTankonyvEllatas;
                co.SzocialisTamogatas = model.TanuloTobbesTanugyModel.SzocialisTamogatas;
                co.TestnevelesTipusa = model.TanuloTobbesTanugyModel.TestnevelesTipusa;
                co.KollegiumiEllatasu = model.TanuloTobbesTanugyModel.KollegiumiEllatasu;
                co.EtkezesiKedvezmeny = model.TanuloTobbesTanugyModel.EtkezesiKedvezmeny;
                co.IntezetiNevelt = model.TanuloTobbesTanugyModel.IntezetiNevelt;
                co.HatranyosHelyzet = model.TanuloTobbesTanugyModel.HatranyosHelyzet;
                co.Veszelyeztetett = model.TanuloTobbesTanugyModel.Veszelyeztetett;
                co.SzakmacsoportId = model.TanuloTobbesTanugyModel.SzakmacsoportId;
                co.AgazatId = model.TanuloTobbesTanugyModel.AgazatId;
                co.SzakkepesitesId = model.TanuloTobbesTanugyModel.SzakkepesitesId;
                co.ReszSzakkepesitesId = model.TanuloTobbesTanugyModel.ReszSzakkepesitesId;
                co.AgazatUjSzktTipusId = model.TanuloTobbesTanugyModel.AgazatUjSzktTipusId;
                co.SzakmaTipusId = model.TanuloTobbesTanugyModel.SzakmaTipusId;
                co.SzakmairanyTipusId = model.TanuloTobbesTanugyModel.SzakmairanyTipusId;
                co.AgazatReszSzakmaTipusId = model.TanuloTobbesTanugyModel.AgazatReszSzakmaTipusId;
                co.ReszSzakmaTipusId = model.TanuloTobbesTanugyModel.ReszSzakmaTipusId;
                co.SzakmaReszSzakmaTipusId = model.TanuloTobbesTanugyModel.SzakmaReszSzakmaTipusId;
                co.SZKTV = model.TanuloTobbesTanugyModel.SZKTV;
                co.SZETV = model.TanuloTobbesTanugyModel.SZETV;
                co.OSZTV = model.TanuloTobbesTanugyModel.OSZTV;
                co.EgyebOrszagosDonto = model.TanuloTobbesTanugyModel.EgyebOrszagosDonto;
                co.TechnikusiEvfolyam = model.TanuloTobbesTanugyModel.TechnikusiEvfolyam;
                co.EgyuttmukodesiMegallpodasos = model.TanuloTobbesTanugyModel.EgyuttmukodesiMegallapodasos;
                co.KizarolagIskolaiKeretekKozott = model.TanuloTobbesTanugyModel.KizarolagIskolaiKeretekKozott;
                co.SzakmaiGyakorlatonTartozkodik = model.TanuloTobbesTanugyModel.SzakmaiGyakorlatonTartozkodik;
                co.Bejaro = model.TanuloTobbesTanugyModel.Bejaro;
                co.MenekultOltalmazottMenedekes = model.TanuloTobbesTanugyModel.MenekultOltalmazottMenedekes;
                co.BeilleszkedesiNehezseg = model.TanuloTobbesTanugyModel.BeilleszkedesiNehezseg;
                co.IsSzakmaiGyakorlatHiany = model.TanuloTobbesTanugyModel.IsSzakmaiGyakorlatHiany;
                co.TanterviJellemzoId = model.TanuloTobbesTanugyModel.TanterviJellemzoId;
                co.TanuloEvfolyamTipusId = model.TanuloTobbesTanugyModel.TanuloEvfolyamTipusId;
                co.Jogviszony = model.TanuloTobbesTanugyModel.Jogviszony;
                co.IsSzakkepzesiMunkaszerzodessel = model.TanuloTobbesTanugyModel.IsSzakkepzesiMunkaszerzodessel;
                co.TanuloSzervezetId = model.TanuloTobbesTanugyModel.TanuloSzervezetId;
                co.SzakiranyNktTipusId = model.TanuloTobbesTanugyModel.SzakiranyNktTipusId;
                co.SzakkepesitesNktTipusId = model.TanuloTobbesTanugyModel.SzakkepesitesNktTipusId;
                co.TanulmanyiTeruletNktTipusId = model.TanuloTobbesTanugyModel.TanulmanyiTeruletNktTipusId;
                co.Is9kozul8ElozotanevbenVegezte = model.TanuloTobbesTanugyModel.Is9kozul8ElozotanevbenVegezte;
                co.IsKiemeltenTehetseges = model.TanuloTobbesTanugyModel.IsKiemeltenTehetseges;
                co.IsSzamitogepetOktCelraHasznal = model.TanuloTobbesTanugyModel.IsSzamitogepetOktCelraHasznal;
                co.IsSzabokyAdolfSzakkepODReszesul = model.TanuloTobbesTanugyModel.IsSzabokyAdolfSzakkepODReszesul;
                co.IsEgesznaposIskOktReszesul = model.TanuloTobbesTanugyModel.IsEgesznaposIskOktReszesul;
                co.TanterviJellegId = model.TanuloTobbesTanugyModel.TanterviJellegId;
                co.AgazatAlapOktMegnevTipusId = model.TanuloTobbesTanugyModel.AgazatAlapOktMegnevTipusId;
                co.AgazatAlapVizsgaEredTipusId = model.TanuloTobbesTanugyModel.AgazatAlapVizsgaEredTipusId;
                co.AgazatiAlapvizsgaDatuma = model.TanuloTobbesTanugyModel.AgazatiAlapvizsgaDatuma;
                co.AgazatiAlapvizsgaEredmenye = model.TanuloTobbesTanugyModel.AgazatiAlapvizsgaEredmenye;
                co.AgazatiAlapvizsgaEredmenyeSzazalek = model.TanuloTobbesTanugyModel.AgazatiAlapvizsgaEredmenyeSzazalek;
                if ((model.TanuloTobbesTanugyModel.SzakkepzesiMunkaszerzodesModels?.Count ?? 0) > 0)
                {
                    co.SzakkepzesiMunkaszerzodesList = model.TanuloTobbesTanugyModel.SzakkepzesiMunkaszerzodesModels.Select(x => new SzakkepzesiMunkaszerzodesItemCo
                    {
                        Id = SDAConvert.ToInt32(x.ID),
                        Kezdete = x.Kezdete,
                        Vege = x.Vege,
                        SzervezetId = x.NewModifySzakkepzesiMunkaszerzodesSzervezetId,
                        Status = x.GridRowStatus,
                    }).ToList();
                }
            }
            if (model.AmiKepzesiJellemzokModel != null)
            {
                co.MuveszetiAgId = model.AmiKepzesiJellemzokModel.MuveszetiAgId;
                co.MufajTipusId = model.AmiKepzesiJellemzokModel.MufajTipusId;
                co.TanszakTipusId = model.AmiKepzesiJellemzokModel.TanszakTipusId;
            }

            if (model.TanuloTobbesVallasModel != null)
            {
                co.Vallasa = model.TanuloTobbesVallasModel.Vallasa;
                co.Egyhazkozossege = model.TanuloTobbesVallasModel.Egyhazkozosseg;
            }
            if (model.TanuloTobbesSportModel != null)
            {
                co.Sportag = model.TanuloTobbesSportModel.Sportag;
                co.SportedzoElerhetoseg = model.TanuloTobbesSportModel.SportedzoNeve;
                co.Sportklub = model.TanuloTobbesSportModel.SportKlub;
            }

            if (model.TanuloTobbesSzirBeallitasokModel != null)
            {
                co.IsKuldhetoErettsegiSzRnek = model.TanuloTobbesSzirBeallitasokModel.IsKuldhetoErettsegiSzRnek;
                co.IsKuldhetoMeresiSzRnek = model.TanuloTobbesSzirBeallitasokModel.IsKuldhetoMeresiSzRnek;
                co.IsKuldhetoKozepFelveteliSzRnek = model.TanuloTobbesSzirBeallitasokModel.IsKuldhetoKozepFelveteliSzRnek;
                co.IsDiakigazolvanyAtadhatoSzRnek = model.TanuloTobbesSzirBeallitasokModel.IsDiakigazolvanyAtadhatoSzRnek;
                co.IsExternatusiEllatasban = model.TanuloTobbesSzirBeallitasokModel.IsExternatusiEllatasban;
                co.IsNapkoziotthoniEllatasban = model.TanuloTobbesSzirBeallitasokModel.IsNapkoziotthoniEllatasban;
            }

            if (model.TanuloTobbesJuttatasModel != null)
            {
                co.IsSikeresAgazatiVizsga = model.TanuloTobbesJuttatasModel.IsSikeresAgazatiVizsga;
                co.IsAtlagSzakkepzesi = model.TanuloTobbesJuttatasModel.IsAtlagSzakkepzesi;
                co.IsBeszamitasosTanulo = model.TanuloTobbesJuttatasModel.IsBeszamitasosTanulo;
                co.IsBeszamitasosFixSzazalek = model.TanuloTobbesJuttatasModel.IsBeszamitasosFixSzazalek;
                co.IsApaczaiIgenylo = model.TanuloTobbesJuttatasModel.IsApaczaiIgenylo;
                co.IsApaczaiSzerzodeses = model.TanuloTobbesJuttatasModel.IsApaczaiSzerzodeses;
                co.IsIngyenesKepzes = model.TanuloTobbesJuttatasModel.IsIngyenesKepzes;
            }

            return co;
        }
    }

    public class TanuloTobbesAlapAdatModel
    {
        [Display(Name = nameof(TanuloResource.SzuletesiOrszag), ResourceType = typeof(TanuloResource))]
        public int? SzuletesiOrszag { get; set; }

        [Display(Name = nameof(TanuloResource.Anyanyelv), ResourceType = typeof(TanuloResource))]
        public int? Anyanyelv { get; set; }

        [Display(Name = nameof(TanuloResource.Allampolgarsag), ResourceType = typeof(TanuloResource))]
        public int? Allampolgarsag { get; set; }

        [Display(Name = nameof(TanuloResource.Allampolgarsag2), ResourceType = typeof(TanuloResource))]
        public int? Allampolgarsag2 { get; set; }

        [Display(Name = nameof(TanuloResource.Neme), ResourceType = typeof(TanuloResource))]
        public int? Neme { get; set; }
    }

    public class TanuloTobbesTanugyModel
    {
        [Display(Name = nameof(TanuloResource.Tanterv), ResourceType = typeof(TanuloResource))]
        public int? TantervId { get; set; }

        [Display(Name = nameof(OsztalyCsoportResource.NevelesiTerv), ResourceType = typeof(OsztalyCsoportResource))]
        public int? NevelesiTervId
        {
            get { return TantervId; }
            set { TantervId = value; }
        }

        [Display(Name = nameof(TanuloResource.FelvetelTaneve), ResourceType = typeof(TanuloResource))]
        public int? FelvetelTaneveId { get; set; }

        [Display(Name = nameof(TanuloResource.JogviszonyKezdete), ResourceType = typeof(TanuloResource))]
        public DateTime? NyilvantartastartasKezdete { get; set; }

        [Display(Name = nameof(OsztalyCsoportResource.IsESL16EvesUtanBelepett), ResourceType = typeof(OsztalyCsoportResource))]
        public int? ESL16EvesUtanBelepett { get; set; }

        [Display(Name = nameof(TanuloResource.JogviszonyVarhatoBefejezese), ResourceType = typeof(TanuloResource))]
        public DateTime? JogviszonyBefejezese { get; set; }

        [Display(Name = nameof(TanuloResource.JogviszonySzunteteltetese), ResourceType = typeof(TanuloResource))]
        public int? JogviszonySzuneteltetese { get; set; }

        [Display(Name = nameof(TanuloResource.TankotelezettsegetTeljesito), ResourceType = typeof(TanuloResource))]
        public int? TankotelezettsegetTeljesito { get; set; }

        [Display(Name = nameof(TanuloResource.TankotelezettsegVege), ResourceType = typeof(TanuloResource))]
        public DateTime? TankotelezettsegVege { get; set; }

        [Display(Name = nameof(TanuloResource.Magantanulo), ResourceType = typeof(TanuloResource))]
        public int? Magantanulo { get; set; }

        [Display(Name = nameof(TanuloResource.MagantanulosagOka), ResourceType = typeof(TanuloResource))]
        public int? MagantanulosagOka { get; set; }

        [Display(Name = nameof(TanuloResource.MagantanulosagKezdete), ResourceType = typeof(TanuloResource))]
        public DateTime? MagantanulosagKezdete { get; set; }

        [Display(Name = nameof(TanuloResource.EgyeniMunkarendVege), ResourceType = typeof(TanuloResource))]
        public DateTime? MagantanulosagVege { get; set; }

        [Display(Name = nameof(TanuloResource.Vendegtanulo), ResourceType = typeof(TanuloResource))]
        public int? Vendeg { get; set; }

        [Display(Name = nameof(TanuloResource.TandijatFizeto), ResourceType = typeof(TanuloResource))]
        public int? TandijatFizeto { get; set; }

        [Display(Name = nameof(TanuloResource.TeritesiDijatFizeto), ResourceType = typeof(TanuloResource))]
        public int? TeritestFizeto { get; set; }

        [Display(Name = nameof(TanuloResource.Tanuloszerzodeses), ResourceType = typeof(TanuloResource))]
        public int? Tanuloszerzodeses { get; set; }

        [Display(Name = nameof(TanuloResource.PolgariSzerzodeses), ResourceType = typeof(TanuloResource))]
        public int? PolgariSzerzodeses { get; set; }

        [Display(Name = nameof(TanuloResource.DiaksportkorTagja), ResourceType = typeof(TanuloResource))]
        public int? DiaksportkorTag { get; set; }

        [Display(Name = nameof(TanuloResource.Evismetlo), ResourceType = typeof(TanuloResource))]
        public int? Evismetlo { get; set; }

        [Display(Name = nameof(TanuloResource.IngyenesTankonyvEllatas), ResourceType = typeof(TanuloResource))]
        public int? IngyenesTankonyvEllatas { get; set; }

        [Display(Name = nameof(TanuloResource.SzocialisOsztondij), ResourceType = typeof(TanuloResource))]
        public int? SzocialisTamogatas { get; set; }

        [Display(Name = nameof(TanuloResource.TestnevelesTipusa), ResourceType = typeof(TanuloResource))]
        public int? TestnevelesTipusa { get; set; }

        [Display(Name = nameof(TanuloResource.KollegiumiEllatasbanReszesulo), ResourceType = typeof(TanuloResource))]
        public int? KollegiumiEllatasu { get; set; }

        [Display(Name = nameof(TanuloResource.EtkezesiKedvezmeny), ResourceType = typeof(TanuloResource))]
        public int? EtkezesiKedvezmeny { get; set; }

        [Display(Name = nameof(TanuloResource.IntezetiNevelt), ResourceType = typeof(TanuloResource))]
        public int? IntezetiNevelt { get; set; }

        [Display(Name = nameof(TanuloResource.HatranyosHelyzet), ResourceType = typeof(TanuloResource))]
        public int? HatranyosHelyzet { get; set; }

        [Display(Name = nameof(TanuloResource.Veszelyeztetett), ResourceType = typeof(TanuloResource))]
        public int? Veszelyeztetett { get; set; }

        [Display(Name = nameof(TanuloResource.Szakmacsoport), ResourceType = typeof(TanuloResource))]
        public int? SzakmacsoportId { get; set; }

        [Display(Name = nameof(TanuloResource.Agazat), ResourceType = typeof(TanuloResource))]
        public int? AgazatId { get; set; }

        [Display(Name = nameof(TanuloResource.Szakkepesites), ResourceType = typeof(TanuloResource))]
        public int? SzakkepesitesId { get; set; }

        [Display(Name = nameof(TanuloResource.ReszSzakkepesites), ResourceType = typeof(TanuloResource))]
        public int? ReszSzakkepesitesId { get; set; }

        [Display(Name = nameof(OsztalyCsoportResource.Agazat), ResourceType = typeof(OsztalyCsoportResource))]
        public int? AgazatUjSzktTipusId { get; set; }

        [Display(Name = nameof(OsztalyCsoportResource.Szakma), ResourceType = typeof(OsztalyCsoportResource))]
        public int? SzakmaTipusId { get; set; }

        [Display(Name = nameof(OsztalyCsoportResource.Szakmairany), ResourceType = typeof(OsztalyCsoportResource))]
        public int? SzakmairanyTipusId { get; set; }

        [Display(Name = nameof(TanuloResource.UjSzktReszszakmakAgazat), ResourceType = typeof(TanuloResource))]
        public int? AgazatReszSzakmaTipusId { get; set; }

        [Display(Name = nameof(TanuloResource.UjSzktReszszakmakSzakma), ResourceType = typeof(TanuloResource))]
        public int? SzakmaReszSzakmaTipusId { get; set; }

        [Display(Name = nameof(TanuloResource.UjSzktReszszakmakReszszakma), ResourceType = typeof(TanuloResource))]
        public int? ReszSzakmaTipusId { get; set; }

        public bool IsSzakkepzeses { get; set; }

        public bool IsNKTSzakkepzeses { get; set; }

        [Display(Name = nameof(TanuloResource.Szktv), ResourceType = typeof(TanuloResource))]
        public int? SZKTV { get; set; }

        [Display(Name = nameof(TanuloResource.Szetv), ResourceType = typeof(TanuloResource))]
        public int? SZETV { get; set; }

        [Display(Name = nameof(TanuloResource.Osztv), ResourceType = typeof(TanuloResource))]
        public int? OSZTV { get; set; }

        [Display(Name = nameof(TanuloResource.EgyebOrszagosDonto), ResourceType = typeof(TanuloResource))]
        public int? EgyebOrszagosDonto { get; set; }

        [Display(Name = nameof(TanuloResource.TechnikusiEvfolyam), ResourceType = typeof(TanuloResource))]
        public int? TechnikusiEvfolyam { get; set; }

        [Display(Name = nameof(TanuloResource.EgyuttmukodesiMegallapodasos), ResourceType = typeof(TanuloResource))]
        public int? EgyuttmukodesiMegallapodasos { get; set; }

        [Display(Name = nameof(TanuloResource.KizarolagIskolaiKeretekKozott), ResourceType = typeof(TanuloResource))]
        public int? KizarolagIskolaiKeretekKozott { get; set; }

        [Display(Name = nameof(TanuloResource.Bejaro), ResourceType = typeof(TanuloResource))]
        public int? Bejaro { get; set; }

        [Display(Name = nameof(TanuloResource.SzakmaiGyakorlatonTartozkodik), ResourceType = typeof(TanuloResource))]
        public int? SzakmaiGyakorlatonTartozkodik { get; set; }

        [Display(Name = nameof(TanuloResource.BeilleszkedesiNehezseg), ResourceType = typeof(TanuloResource))]
        public int? BeilleszkedesiNehezseg { get; set; }

        [Display(Name = nameof(TanuloResource.MenekultOltalmazottMenedekes), ResourceType = typeof(TanuloResource))]
        public int? MenekultOltalmazottMenedekes { get; set; }

        [Display(Name = nameof(TanuloResource.IsSzakmaiGyakorlatHiany), ResourceType = typeof(TanuloResource))]
        public int? IsSzakmaiGyakorlatHiany { get; set; }

        [Display(Name = nameof(TanuloResource.TanterviJellemzo), ResourceType = typeof(TanuloResource))]
        public int? TanterviJellemzoId { get; set; }

        [Display(Name = nameof(TanuloResource.OsszevontOsztalyEvfolyamTipus), ResourceType = typeof(TanuloResource))]
        public int? TanuloEvfolyamTipusId { get; set; }

        [Display(Name = nameof(TanuloResource.Jogviszony), ResourceType = typeof(TanuloResource))]
        public int? Jogviszony { get; set; }

        public bool IsSzakkepzo { get; set; }

        [Display(Name = nameof(TanuloResource.SzakkepzesiMunkaszerzodessel), ResourceType = typeof(TanuloResource))]
        public int? IsSzakkepzesiMunkaszerzodessel { get; set; }

        // NOTE: Itt azért nem a nameof(SzervezetResource.Szervezet)-ből jön a szöveg, mert ez a property fixen mindig ezzel a label-el kell, hogy megjelenjen, függetlenül a nyelviesítéstől!
        [Display(Name = nameof(DualisResource.DualisKepzohelyNeveEsAdoszama), ResourceType = typeof(DualisResource))]
        public int? TanuloSzervezetId { get; set; }

        [Display(Name = nameof(TanuloResource.SzakiranyNktTipus), ResourceType = typeof(TanuloResource))]
        public int? SzakiranyNktTipusId { get; set; }

        [Display(Name = nameof(TanuloResource.SzakkepesitesNktTipus), ResourceType = typeof(TanuloResource))]
        public int? SzakkepesitesNktTipusId { get; set; }

        [Display(Name = nameof(TanuloResource.TanulmanyiTeruletNktTipus), ResourceType = typeof(TanuloResource))]
        public int? TanulmanyiTeruletNktTipusId { get; set; }

        [Display(Name = nameof(OsztalyCsoportResource.Is9kozul8ElozotanevbenVegezte), ResourceType = typeof(OsztalyCsoportResource))]
        public int? Is9kozul8ElozotanevbenVegezte { get; set; }

        [Display(Name = nameof(TanuloResource.KiemeltenTehetseges), ResourceType = typeof(TanuloResource))]
        public int? IsKiemeltenTehetseges { get; set; }

        [Display(Name = nameof(TanuloResource.SzamitogepetOktatasiCellalHasznal), ResourceType = typeof(TanuloResource))]
        public int? IsSzamitogepetOktCelraHasznal { get; set; }

        [Display(Name = nameof(TanuloResource.SzabokyAdolfSzakkepzesiOsztondijbanReszesul), ResourceType = typeof(TanuloResource))]
        public int? IsSzabokyAdolfSzakkepODReszesul { get; set; }

        [Display(Name = nameof(TanuloResource.EgeszNaposIskolaiOktatasbanReszesul), ResourceType = typeof(TanuloResource))]
        public int? IsEgesznaposIskOktReszesul { get; set; }

        public bool IsAllOsztalyAltalanosIskolaFeladatellatasiHely { get; set; }

        [Display(Name = nameof(TanuloResource.Munkarend), ResourceType = typeof(TanuloResource))]
        public int? TanterviJellegId { get; set; }

        public bool HasAktivOsztalybaSorolasGyereknek { get; set; }

        [Display(Name = nameof(TanuloResource.AgazatiAlapvizsgaEredmenye), ResourceType = typeof(TanuloResource))]
        public double? AgazatiAlapvizsgaEredmenye { get; set; }

        [Display(Name = nameof(TanuloResource.AgazatiAlapvizsgaEredmenyeSzazalek), ResourceType = typeof(TanuloResource))]
        public int? AgazatiAlapvizsgaEredmenyeSzazalek { get; set; }

        [Display(Name = nameof(TanuloResource.AgazatiAlapoktatasMegnevezese), ResourceType = typeof(TanuloResource))]
        public int? AgazatAlapOktMegnevTipusId { get; set; }

        [Display(Name = nameof(TanuloResource.AgazatiAlapvizsgaTeljesitese), ResourceType = typeof(TanuloResource))]
        public int? AgazatAlapVizsgaEredTipusId { get; set; }

        public bool IsVanAgazatialapvizsgaEredmeny => AgazatAlapVizsgaEredTipusId == (int)AgazatAlapVizsgaEredTipusEnum.teljesitette || AgazatAlapVizsgaEredTipusId == (int)AgazatAlapVizsgaEredTipusEnum.nem_teljesitette;

        [RequiredIf("IsVanAgazatialapvizsgaEredmeny", true, ErrorMessageResourceName = nameof(TanuloResource.AgazatialapvizsgaDatumanakMegadasaKotelezo), ErrorMessageResourceType = typeof(TanuloResource))]
        [Display(Name = nameof(TanuloResource.AgazatiAlapvizsgaDatuma), ResourceType = typeof(TanuloResource))]
        public DateTime? AgazatiAlapvizsgaDatuma { get; set; }

        public List<SzakkepzesiMunkaszerzodesGridModel> SzakkepzesiMunkaszerzodesModels { get; set; }
    }

    public class TanuloTobbesVallasModel
    {
        [Display(Name = nameof(TanuloResource.Vallasa), ResourceType = typeof(TanuloResource))]
        public int? Vallasa { get; set; }

        [Display(Name = nameof(TanuloResource.Egyhazkozosseg), ResourceType = typeof(TanuloResource))]
        public string Egyhazkozosseg { get; set; }
    }

    public class TanuloTobbesSportModel
    {
        [Display(Name = nameof(TanuloResource.Sportag), ResourceType = typeof(TanuloResource))]
        public string Sportag { get; set; }

        [Display(Name = nameof(TanuloResource.SportedzoNeveElerhetosege), ResourceType = typeof(TanuloResource))]
        public string SportedzoNeve { get; set; }

        [Display(Name = nameof(TanuloResource.Sportklub), ResourceType = typeof(TanuloResource))]
        public string SportKlub { get; set; }
    }

    public class TanuloTobbesModId
    {
        public int TanuloId { get; set; }
        public int? OsztalyId { get; set; }
    }

    public class TanuloTobbesModAdat : TanuloTobbesModId
    {
        public string TanuloNev { get; set; }
    }

    public class TanuloTobbesSzirBeallitasokModel
    {
        [Display(Name = nameof(TanuloResource.KuldhetoErettsegiSzRnek), ResourceType = typeof(TanuloResource))]
        public int? IsKuldhetoErettsegiSzRnek { get; set; }

        [Display(Name = nameof(TanuloResource.KuldhetoMeresiSzRnek), ResourceType = typeof(TanuloResource))]
        public int? IsKuldhetoMeresiSzRnek { get; set; }

        [Display(Name = nameof(TanuloResource.KuldhetoKozepFelveteliSzRnek), ResourceType = typeof(TanuloResource))]
        public int? IsKuldhetoKozepFelveteliSzRnek { get; set; }

        [Display(Name = nameof(TanuloResource.DiakigazolvanyAtadhatoSzRnek), ResourceType = typeof(TanuloResource))]
        public int? IsDiakigazolvanyAtadhatoSzRnek { get; set; }

        [Display(Name = nameof(TanuloResource.IsExternatusiEllatasban), ResourceType = typeof(TanuloResource))]
        public int? IsExternatusiEllatasban { get; set; }

        [Display(Name = nameof(TanuloResource.IsNapkoziotthoniEllatasban), ResourceType = typeof(TanuloResource))]
        public int? IsNapkoziotthoniEllatasban { get; set; }
    }

    public class TanuloTobbesJuttatasModel
    {
        public bool IsAgazatiAlapvizsgaTulajdonsagokVisible { get; set; }
        public bool IsAgazatiAlapvizsgaTulajdonsagokEnabled { get; set; }
        public bool? IsSikeresAgazatiVizsga { get; set; }
        public bool? IsAtlagSzakkepzesi { get; set; }
        [Display(Name = nameof(TanuloResource.BeszamitasosTanulo), ResourceType = typeof(TanuloResource))]
        public int? IsBeszamitasosTanulo { get; set; }
        public bool? IsBeszamitasosFixSzazalek { get; set; }
        [Display(Name = nameof(TanuloResource.IsApaczaiIgenylo), ResourceType = typeof(TanuloResource))]
        public int? IsApaczaiIgenylo { get; set; }
        [Display(Name = nameof(TanuloResource.IsApaczaiSzerzodeses), ResourceType = typeof(TanuloResource))]
        public int? IsApaczaiSzerzodeses { get; set; }
        [Display(Name = nameof(TanuloResource.AllamAltalIngyenesenBiztositottKepzesbenResztvevo), ResourceType = typeof(TanuloResource))]
        public int? IsIngyenesKepzes { get; set; }
    }
}
